import multer from 'multer';
import { Product } from '../service/index.js';
import { Image, Request } from '../util/index.js';
const upload = multer({
    storage: multer.memoryStorage(),
});
class ProductRoutes {
    register(app) {
        app.post('/product', upload.single('file'), async (req, res) => {
            try {
                let productImage = null;
                let productOriginalImage = null;
                if (req.file && req.file.buffer) {
                    const { fileName, originalFile, } = await Image.toWebp(req.file);
                    productImage = fileName;
                    productOriginalImage = originalFile;
                }
                const data = JSON.parse(req.body.data);
                const response = await Product.create({ ...Request.getAllParams(req), ...data, productImage, productOriginalImage });
                res.status(201).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.post('/product/license-sync', async (req, res) => {
            try {
                await Product.licenseSync();
                res.status(200).send({
                    message: 'SUCCESS_SYNC',
                });
            }
            catch (err) {
                console.error(err);
                Request.handleResponseError(res, err);
            }
        });
        app.get('/product', async (req, res) => {
            try {
                const response = await Product.list();
                res.send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.put('/product', upload.single('file'), async (req, res) => {
            try {
                let productImage = null;
                let productOriginalImage = null;
                if (req.file && req.file.buffer) {
                    const { fileName, originalFile, } = await Image.toWebp(req.file);
                    productImage = fileName;
                    productOriginalImage = originalFile;
                }
                const data = JSON.parse(req.body.data);
                const response = await Product.modify({ ...data, productImage, productOriginalImage });
                const status = ('circularDependency' in (response || {})) ? 500 : 200;
                res.status(status).send(response);
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.delete('/product', async (req, res) => {
            try {
                const response = await Product.remove(Request.getAllParams(req));
                if ('error' in response) {
                    res.status(500).send(response);
                }
                else {
                    res.send(response);
                }
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
    }
}
const instance = new ProductRoutes();
export { instance as ProductRoutes };
export default instance;
