import { Request } from '../util/index.js';
import { ReportBuilder, ReportTools } from '../report/index.js';
import { Notification, Report } from '../service/index.js';
import { ReportNotFound } from '../template/index.js';
class ReportRoutes {
    register(app) {
        app.post('/report', async (req, res) => {
            try {
                const { reportName, data, userId, format = 'PDF', } = Request.getAllParams(req);
                const reportFileName = ReportTools.generateReportHashName(reportName, data, format);
                const notificationInfo = {
                    userId,
                    status: 'REPORT_PENDING',
                    description: reportFileName,
                    title: reportName,
                    emit: true,
                };
                const previousNotification = await Notification.findByUserAndDescriptionAndTitle({
                    userId,
                    title: reportName,
                    description: reportFileName,
                });
                const result = await (previousNotification || Notification.create(notificationInfo));
                if (previousNotification && previousNotification.status === 'REPORT_PENDING') {
                    return res.status(200).send({
                        message: 'REPORT_PENDING',
                        data: {
                            id: result.id,
                            duplicate: true,
                        },
                    });
                }
                const { useCache } = await ReportBuilder.generate(reportName, { data, format, notificationId: result.id, reportFileName });
                if (previousNotification) {
                    const status = useCache ? 'REPORT_GENERATED' : 'REPORT_PENDING';
                    await Notification.updateStatus({
                        id: result.id,
                        status,
                        emit: true,
                    });
                    return res.status(200).send({
                        message: status,
                        data: {
                            id: previousNotification.id,
                            useCache,
                        },
                    });
                }
                notificationInfo.description = reportFileName;
                if (useCache) {
                    await Notification.updateStatus({ id: result.id, status: 'REPORT_GENERATED', emit: true });
                    return res.status(200).send({
                        message: 'REPORT_GENERATED',
                        data: {
                            id: result.id,
                            useCache,
                        },
                    });
                }
                res.status(200).send({
                    message: notificationInfo.status,
                    data: {
                        useCache: false,
                    },
                });
            }
            catch (err) {
                Request.handleResponseError(res, err);
            }
        });
        app.get('/report/:fileName', async (req, res) => {
            try {
                await Report.preview(Request.getAllParams(req), res);
            }
            catch (err) {
                res.contentType('text/html');
                res.send(ReportNotFound.getPage());
            }
        });
    }
}
const instance = new ReportRoutes();
export { instance as ReportRoutes };
export default instance;
