import fs from 'fs';
import path from 'path';
export class File {
    constructor(fileName = '', filePath = '') {
        this.fileName = fileName;
        this.filePath = filePath;
    }
    static async isDir(directory) {
        return new Promise((resolve, reject) => {
            fs.stat(directory, (err, stats) => {
                if (err) {
                    return reject(err);
                }
                if (stats.isDirectory()) {
                    return resolve(true);
                }
                resolve(false);
            });
        });
    }
    static async createDir(directory) {
        return new Promise((resolve, reject) => {
            fs.mkdir(directory, { recursive: true }, (err) => {
                if (err)
                    return reject(err);
                resolve(directory);
            });
        });
    }
    getFullPath() {
        return path.join(this.filePath, this.fileName);
    }
    async write(data) {
        return new Promise((resolve, reject) => {
            const fullPath = this.getFullPath();
            fs.writeFile(fullPath, data, {}, (err) => {
                if (err)
                    return reject(err);
                resolve({
                    path: this.filePath,
                    fileName: this.fileName,
                });
            });
        });
    }
    async read() {
        return new Promise((resolve, reject) => {
            fs.readFile(this.getFullPath(), 'utf8', (err, data) => {
                if (err)
                    return reject(new Error(`Erro ao ler o arquivo: ${this.getFullPath()}`));
                resolve(data);
            });
        });
    }
    static async readdir(pathToRead, { onlyType }) {
        const filterDirectory = (item) => item.isDirectory();
        const filterFile = (item) => item.isFile();
        return new Promise((resolve, reject) => {
            fs.readdir(pathToRead, { withFileTypes: true, recursive: false }, (err, data) => {
                if (err)
                    return reject(new Error(`Erro ao ler o diretório: ${pathToRead}\n${err}`));
                if (onlyType === 'directory')
                    return resolve(data.filter(filterDirectory));
                if (onlyType === 'file')
                    return resolve(data.filter(filterFile));
                resolve(data);
            });
        });
    }
    async remove() {
        return new Promise((resolve, reject) => {
            fs.unlink(this.getFullPath(), (err) => {
                if (err)
                    return reject(err);
                resolve({
                    path: this.filePath,
                    fileName: this.fileName,
                });
            });
        });
    }
    getFileName() {
        return this.fileName;
    }
    setFileName(fileName) {
        this.fileName = fileName;
    }
    getFilePath() {
        return this.filePath;
    }
    setFilePath(filePath) {
        this.filePath = filePath;
    }
    exists() {
        return new Promise((resolve, reject) => {
            fs.stat(this.getFullPath(), (err, stats) => {
                if (err)
                    return reject(err);
                resolve(stats.isFile());
            });
        });
    }
    stats() {
        return new Promise((resolve, reject) => {
            fs.stat(this.getFullPath(), (err, stats) => {
                if (err)
                    return reject(err);
                resolve(stats);
            });
        });
    }
}
