
/**
 * Client
**/

import * as runtime from '@prisma/client/runtime/library.js';
import $Types = runtime.Types // general types
import $Public = runtime.Types.Public
import $Utils = runtime.Types.Utils
import $Extensions = runtime.Types.Extensions
import $Result = runtime.Types.Result

export type PrismaPromise<T> = $Public.PrismaPromise<T>


/**
 * Model Server
 * 
 */
export type Server = $Result.DefaultSelection<Prisma.$ServerPayload>
/**
 * Model Product
 * 
 */
export type Product = $Result.DefaultSelection<Prisma.$ProductPayload>
/**
 * Model ProductSetting
 * 
 */
export type ProductSetting = $Result.DefaultSelection<Prisma.$ProductSettingPayload>
/**
 * Model ProductSettingDetail
 * 
 */
export type ProductSettingDetail = $Result.DefaultSelection<Prisma.$ProductSettingDetailPayload>
/**
 * Model UpdaterVersion
 * 
 */
export type UpdaterVersion = $Result.DefaultSelection<Prisma.$UpdaterVersionPayload>
/**
 * Model Customer
 * 
 */
export type Customer = $Result.DefaultSelection<Prisma.$CustomerPayload>
/**
 * Model AssistantMonitoring
 * 
 */
export type AssistantMonitoring = $Result.DefaultSelection<Prisma.$AssistantMonitoringPayload>
/**
 * Model Notification
 * 
 */
export type Notification = $Result.DefaultSelection<Prisma.$NotificationPayload>

/**
 * ##  Prisma Client ʲˢ
 * 
 * Type-safe database client for TypeScript & Node.js
 * @example
 * ```
 * const prisma = new PrismaClient()
 * // Fetch zero or more Servers
 * const servers = await prisma.server.findMany()
 * ```
 *
 * 
 * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client).
 */
export class PrismaClient<
  T extends Prisma.PrismaClientOptions = Prisma.PrismaClientOptions,
  U = 'log' extends keyof T ? T['log'] extends Array<Prisma.LogLevel | Prisma.LogDefinition> ? Prisma.GetEvents<T['log']> : never : never,
  ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs
> {
  [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['other'] }

    /**
   * ##  Prisma Client ʲˢ
   * 
   * Type-safe database client for TypeScript & Node.js
   * @example
   * ```
   * const prisma = new PrismaClient()
   * // Fetch zero or more Servers
   * const servers = await prisma.server.findMany()
   * ```
   *
   * 
   * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client).
   */

  constructor(optionsArg ?: Prisma.Subset<T, Prisma.PrismaClientOptions>);
  $on<V extends U>(eventType: V, callback: (event: V extends 'query' ? Prisma.QueryEvent : Prisma.LogEvent) => void): void;

  /**
   * Connect with the database
   */
  $connect(): $Utils.JsPromise<void>;

  /**
   * Disconnect from the database
   */
  $disconnect(): $Utils.JsPromise<void>;

  /**
   * Add a middleware
   * @deprecated since 4.16.0. For new code, prefer client extensions instead.
   * @see https://pris.ly/d/extensions
   */
  $use(cb: Prisma.Middleware): void

/**
   * Executes a prepared raw query and returns the number of affected rows.
   * @example
   * ```
   * const result = await prisma.$executeRaw`UPDATE User SET cool = ${true} WHERE email = ${'user@email.com'};`
   * ```
   * 
   * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client/raw-database-access).
   */
  $executeRaw<T = unknown>(query: TemplateStringsArray | Prisma.Sql, ...values: any[]): Prisma.PrismaPromise<number>;

  /**
   * Executes a raw query and returns the number of affected rows.
   * Susceptible to SQL injections, see documentation.
   * @example
   * ```
   * const result = await prisma.$executeRawUnsafe('UPDATE User SET cool = $1 WHERE email = $2 ;', true, 'user@email.com')
   * ```
   * 
   * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client/raw-database-access).
   */
  $executeRawUnsafe<T = unknown>(query: string, ...values: any[]): Prisma.PrismaPromise<number>;

  /**
   * Performs a prepared raw query and returns the `SELECT` data.
   * @example
   * ```
   * const result = await prisma.$queryRaw`SELECT * FROM User WHERE id = ${1} OR email = ${'user@email.com'};`
   * ```
   * 
   * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client/raw-database-access).
   */
  $queryRaw<T = unknown>(query: TemplateStringsArray | Prisma.Sql, ...values: any[]): Prisma.PrismaPromise<T>;

  /**
   * Performs a raw query and returns the `SELECT` data.
   * Susceptible to SQL injections, see documentation.
   * @example
   * ```
   * const result = await prisma.$queryRawUnsafe('SELECT * FROM User WHERE id = $1 OR email = $2;', 1, 'user@email.com')
   * ```
   * 
   * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client/raw-database-access).
   */
  $queryRawUnsafe<T = unknown>(query: string, ...values: any[]): Prisma.PrismaPromise<T>;

  /**
   * Allows the running of a sequence of read/write operations that are guaranteed to either succeed or fail as a whole.
   * @example
   * ```
   * const [george, bob, alice] = await prisma.$transaction([
   *   prisma.user.create({ data: { name: 'George' } }),
   *   prisma.user.create({ data: { name: 'Bob' } }),
   *   prisma.user.create({ data: { name: 'Alice' } }),
   * ])
   * ```
   * 
   * Read more in our [docs](https://www.prisma.io/docs/concepts/components/prisma-client/transactions).
   */
  $transaction<P extends Prisma.PrismaPromise<any>[]>(arg: [...P], options?: { isolationLevel?: Prisma.TransactionIsolationLevel }): $Utils.JsPromise<runtime.Types.Utils.UnwrapTuple<P>>

  $transaction<R>(fn: (prisma: Omit<PrismaClient, runtime.ITXClientDenyList>) => $Utils.JsPromise<R>, options?: { maxWait?: number, timeout?: number, isolationLevel?: Prisma.TransactionIsolationLevel }): $Utils.JsPromise<R>


  $extends: $Extensions.ExtendsHook<'extends', Prisma.TypeMapCb, ExtArgs>

      /**
   * `prisma.server`: Exposes CRUD operations for the **Server** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more Servers
    * const servers = await prisma.server.findMany()
    * ```
    */
  get server(): Prisma.ServerDelegate<ExtArgs>;

  /**
   * `prisma.product`: Exposes CRUD operations for the **Product** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more Products
    * const products = await prisma.product.findMany()
    * ```
    */
  get product(): Prisma.ProductDelegate<ExtArgs>;

  /**
   * `prisma.productSetting`: Exposes CRUD operations for the **ProductSetting** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more ProductSettings
    * const productSettings = await prisma.productSetting.findMany()
    * ```
    */
  get productSetting(): Prisma.ProductSettingDelegate<ExtArgs>;

  /**
   * `prisma.productSettingDetail`: Exposes CRUD operations for the **ProductSettingDetail** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more ProductSettingDetails
    * const productSettingDetails = await prisma.productSettingDetail.findMany()
    * ```
    */
  get productSettingDetail(): Prisma.ProductSettingDetailDelegate<ExtArgs>;

  /**
   * `prisma.updaterVersion`: Exposes CRUD operations for the **UpdaterVersion** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more UpdaterVersions
    * const updaterVersions = await prisma.updaterVersion.findMany()
    * ```
    */
  get updaterVersion(): Prisma.UpdaterVersionDelegate<ExtArgs>;

  /**
   * `prisma.customer`: Exposes CRUD operations for the **Customer** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more Customers
    * const customers = await prisma.customer.findMany()
    * ```
    */
  get customer(): Prisma.CustomerDelegate<ExtArgs>;

  /**
   * `prisma.assistantMonitoring`: Exposes CRUD operations for the **AssistantMonitoring** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more AssistantMonitorings
    * const assistantMonitorings = await prisma.assistantMonitoring.findMany()
    * ```
    */
  get assistantMonitoring(): Prisma.AssistantMonitoringDelegate<ExtArgs>;

  /**
   * `prisma.notification`: Exposes CRUD operations for the **Notification** model.
    * Example usage:
    * ```ts
    * // Fetch zero or more Notifications
    * const notifications = await prisma.notification.findMany()
    * ```
    */
  get notification(): Prisma.NotificationDelegate<ExtArgs>;
}

export namespace Prisma {
  export import DMMF = runtime.DMMF

  export type PrismaPromise<T> = $Public.PrismaPromise<T>

  /**
   * Validator
   */
  export import validator = runtime.Public.validator

  /**
   * Prisma Errors
   */
  export import PrismaClientKnownRequestError = runtime.PrismaClientKnownRequestError
  export import PrismaClientUnknownRequestError = runtime.PrismaClientUnknownRequestError
  export import PrismaClientRustPanicError = runtime.PrismaClientRustPanicError
  export import PrismaClientInitializationError = runtime.PrismaClientInitializationError
  export import PrismaClientValidationError = runtime.PrismaClientValidationError
  export import NotFoundError = runtime.NotFoundError

  /**
   * Re-export of sql-template-tag
   */
  export import sql = runtime.sqltag
  export import empty = runtime.empty
  export import join = runtime.join
  export import raw = runtime.raw
  export import Sql = runtime.Sql

  /**
   * Decimal.js
   */
  export import Decimal = runtime.Decimal

  export type DecimalJsLike = runtime.DecimalJsLike

  /**
   * Metrics 
   */
  export type Metrics = runtime.Metrics
  export type Metric<T> = runtime.Metric<T>
  export type MetricHistogram = runtime.MetricHistogram
  export type MetricHistogramBucket = runtime.MetricHistogramBucket

  /**
  * Extensions
  */
  export import Extension = $Extensions.UserArgs
  export import getExtensionContext = runtime.Extensions.getExtensionContext
  export import Args = $Public.Args
  export import Payload = $Public.Payload
  export import Result = $Public.Result
  export import Exact = $Public.Exact

  /**
   * Prisma Client JS version: 5.12.1
   * Query Engine version: 4bc8b6e1b66cb932731fb1bdbbc550d1e010de81
   */
  export type PrismaVersion = {
    client: string
  }

  export const prismaVersion: PrismaVersion 

  /**
   * Utility Types
   */

  /**
   * From https://github.com/sindresorhus/type-fest/
   * Matches a JSON object.
   * This type can be useful to enforce some input to be JSON-compatible or as a super-type to be extended from. 
   */
  export type JsonObject = {[Key in string]?: JsonValue}

  /**
   * From https://github.com/sindresorhus/type-fest/
   * Matches a JSON array.
   */
  export interface JsonArray extends Array<JsonValue> {}

  /**
   * From https://github.com/sindresorhus/type-fest/
   * Matches any valid JSON value.
   */
  export type JsonValue = string | number | boolean | JsonObject | JsonArray | null

  /**
   * Matches a JSON object.
   * Unlike `JsonObject`, this type allows undefined and read-only properties.
   */
  export type InputJsonObject = {readonly [Key in string]?: InputJsonValue | null}

  /**
   * Matches a JSON array.
   * Unlike `JsonArray`, readonly arrays are assignable to this type.
   */
  export interface InputJsonArray extends ReadonlyArray<InputJsonValue | null> {}

  /**
   * Matches any valid value that can be used as an input for operations like
   * create and update as the value of a JSON field. Unlike `JsonValue`, this
   * type allows read-only arrays and read-only object properties and disallows
   * `null` at the top level.
   *
   * `null` cannot be used as the value of a JSON field because its meaning
   * would be ambiguous. Use `Prisma.JsonNull` to store the JSON null value or
   * `Prisma.DbNull` to clear the JSON value and set the field to the database
   * NULL value instead.
   *
   * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-by-null-values
   */
  export type InputJsonValue = string | number | boolean | InputJsonObject | InputJsonArray | { toJSON(): unknown }

  /**
   * Types of the values used to represent different kinds of `null` values when working with JSON fields.
   * 
   * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
   */
  namespace NullTypes {
    /**
    * Type of `Prisma.DbNull`.
    * 
    * You cannot use other instances of this class. Please use the `Prisma.DbNull` value.
    * 
    * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
    */
    class DbNull {
      private DbNull: never
      private constructor()
    }

    /**
    * Type of `Prisma.JsonNull`.
    * 
    * You cannot use other instances of this class. Please use the `Prisma.JsonNull` value.
    * 
    * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
    */
    class JsonNull {
      private JsonNull: never
      private constructor()
    }

    /**
    * Type of `Prisma.AnyNull`.
    * 
    * You cannot use other instances of this class. Please use the `Prisma.AnyNull` value.
    * 
    * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
    */
    class AnyNull {
      private AnyNull: never
      private constructor()
    }
  }

  /**
   * Helper for filtering JSON entries that have `null` on the database (empty on the db)
   * 
   * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
   */
  export const DbNull: NullTypes.DbNull

  /**
   * Helper for filtering JSON entries that have JSON `null` values (not empty on the db)
   * 
   * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
   */
  export const JsonNull: NullTypes.JsonNull

  /**
   * Helper for filtering JSON entries that are `Prisma.DbNull` or `Prisma.JsonNull`
   * 
   * @see https://www.prisma.io/docs/concepts/components/prisma-client/working-with-fields/working-with-json-fields#filtering-on-a-json-field
   */
  export const AnyNull: NullTypes.AnyNull

  type SelectAndInclude = {
    select: any
    include: any
  }

  /**
   * Get the type of the value, that the Promise holds.
   */
  export type PromiseType<T extends PromiseLike<any>> = T extends PromiseLike<infer U> ? U : T;

  /**
   * Get the return type of a function which returns a Promise.
   */
  export type PromiseReturnType<T extends (...args: any) => $Utils.JsPromise<any>> = PromiseType<ReturnType<T>>

  /**
   * From T, pick a set of properties whose keys are in the union K
   */
  type Prisma__Pick<T, K extends keyof T> = {
      [P in K]: T[P];
  };


  export type Enumerable<T> = T | Array<T>;

  export type RequiredKeys<T> = {
    [K in keyof T]-?: {} extends Prisma__Pick<T, K> ? never : K
  }[keyof T]

  export type TruthyKeys<T> = keyof {
    [K in keyof T as T[K] extends false | undefined | null ? never : K]: K
  }

  export type TrueKeys<T> = TruthyKeys<Prisma__Pick<T, RequiredKeys<T>>>

  /**
   * Subset
   * @desc From `T` pick properties that exist in `U`. Simple version of Intersection
   */
  export type Subset<T, U> = {
    [key in keyof T]: key extends keyof U ? T[key] : never;
  };

  /**
   * SelectSubset
   * @desc From `T` pick properties that exist in `U`. Simple version of Intersection.
   * Additionally, it validates, if both select and include are present. If the case, it errors.
   */
  export type SelectSubset<T, U> = {
    [key in keyof T]: key extends keyof U ? T[key] : never
  } &
    (T extends SelectAndInclude
      ? 'Please either choose `select` or `include`.'
      : {})

  /**
   * Subset + Intersection
   * @desc From `T` pick properties that exist in `U` and intersect `K`
   */
  export type SubsetIntersection<T, U, K> = {
    [key in keyof T]: key extends keyof U ? T[key] : never
  } &
    K

  type Without<T, U> = { [P in Exclude<keyof T, keyof U>]?: never };

  /**
   * XOR is needed to have a real mutually exclusive union type
   * https://stackoverflow.com/questions/42123407/does-typescript-support-mutually-exclusive-types
   */
  type XOR<T, U> =
    T extends object ?
    U extends object ?
      (Without<T, U> & U) | (Without<U, T> & T)
    : U : T


  /**
   * Is T a Record?
   */
  type IsObject<T extends any> = T extends Array<any>
  ? False
  : T extends Date
  ? False
  : T extends Uint8Array
  ? False
  : T extends BigInt
  ? False
  : T extends object
  ? True
  : False


  /**
   * If it's T[], return T
   */
  export type UnEnumerate<T extends unknown> = T extends Array<infer U> ? U : T

  /**
   * From ts-toolbelt
   */

  type __Either<O extends object, K extends Key> = Omit<O, K> &
    {
      // Merge all but K
      [P in K]: Prisma__Pick<O, P & keyof O> // With K possibilities
    }[K]

  type EitherStrict<O extends object, K extends Key> = Strict<__Either<O, K>>

  type EitherLoose<O extends object, K extends Key> = ComputeRaw<__Either<O, K>>

  type _Either<
    O extends object,
    K extends Key,
    strict extends Boolean
  > = {
    1: EitherStrict<O, K>
    0: EitherLoose<O, K>
  }[strict]

  type Either<
    O extends object,
    K extends Key,
    strict extends Boolean = 1
  > = O extends unknown ? _Either<O, K, strict> : never

  export type Union = any

  type PatchUndefined<O extends object, O1 extends object> = {
    [K in keyof O]: O[K] extends undefined ? At<O1, K> : O[K]
  } & {}

  /** Helper Types for "Merge" **/
  export type IntersectOf<U extends Union> = (
    U extends unknown ? (k: U) => void : never
  ) extends (k: infer I) => void
    ? I
    : never

  export type Overwrite<O extends object, O1 extends object> = {
      [K in keyof O]: K extends keyof O1 ? O1[K] : O[K];
  } & {};

  type _Merge<U extends object> = IntersectOf<Overwrite<U, {
      [K in keyof U]-?: At<U, K>;
  }>>;

  type Key = string | number | symbol;
  type AtBasic<O extends object, K extends Key> = K extends keyof O ? O[K] : never;
  type AtStrict<O extends object, K extends Key> = O[K & keyof O];
  type AtLoose<O extends object, K extends Key> = O extends unknown ? AtStrict<O, K> : never;
  export type At<O extends object, K extends Key, strict extends Boolean = 1> = {
      1: AtStrict<O, K>;
      0: AtLoose<O, K>;
  }[strict];

  export type ComputeRaw<A extends any> = A extends Function ? A : {
    [K in keyof A]: A[K];
  } & {};

  export type OptionalFlat<O> = {
    [K in keyof O]?: O[K];
  } & {};

  type _Record<K extends keyof any, T> = {
    [P in K]: T;
  };

  // cause typescript not to expand types and preserve names
  type NoExpand<T> = T extends unknown ? T : never;

  // this type assumes the passed object is entirely optional
  type AtLeast<O extends object, K extends string> = NoExpand<
    O extends unknown
    ? | (K extends keyof O ? { [P in K]: O[P] } & O : O)
      | {[P in keyof O as P extends K ? K : never]-?: O[P]} & O
    : never>;

  type _Strict<U, _U = U> = U extends unknown ? U & OptionalFlat<_Record<Exclude<Keys<_U>, keyof U>, never>> : never;

  export type Strict<U extends object> = ComputeRaw<_Strict<U>>;
  /** End Helper Types for "Merge" **/

  export type Merge<U extends object> = ComputeRaw<_Merge<Strict<U>>>;

  /**
  A [[Boolean]]
  */
  export type Boolean = True | False

  // /**
  // 1
  // */
  export type True = 1

  /**
  0
  */
  export type False = 0

  export type Not<B extends Boolean> = {
    0: 1
    1: 0
  }[B]

  export type Extends<A1 extends any, A2 extends any> = [A1] extends [never]
    ? 0 // anything `never` is false
    : A1 extends A2
    ? 1
    : 0

  export type Has<U extends Union, U1 extends Union> = Not<
    Extends<Exclude<U1, U>, U1>
  >

  export type Or<B1 extends Boolean, B2 extends Boolean> = {
    0: {
      0: 0
      1: 1
    }
    1: {
      0: 1
      1: 1
    }
  }[B1][B2]

  export type Keys<U extends Union> = U extends unknown ? keyof U : never

  type Cast<A, B> = A extends B ? A : B;

  export const type: unique symbol;



  /**
   * Used by group by
   */

  export type GetScalarType<T, O> = O extends object ? {
    [P in keyof T]: P extends keyof O
      ? O[P]
      : never
  } : never

  type FieldPaths<
    T,
    U = Omit<T, '_avg' | '_sum' | '_count' | '_min' | '_max'>
  > = IsObject<T> extends True ? U : T

  type GetHavingFields<T> = {
    [K in keyof T]: Or<
      Or<Extends<'OR', K>, Extends<'AND', K>>,
      Extends<'NOT', K>
    > extends True
      ? // infer is only needed to not hit TS limit
        // based on the brilliant idea of Pierre-Antoine Mills
        // https://github.com/microsoft/TypeScript/issues/30188#issuecomment-478938437
        T[K] extends infer TK
        ? GetHavingFields<UnEnumerate<TK> extends object ? Merge<UnEnumerate<TK>> : never>
        : never
      : {} extends FieldPaths<T[K]>
      ? never
      : K
  }[keyof T]

  /**
   * Convert tuple to union
   */
  type _TupleToUnion<T> = T extends (infer E)[] ? E : never
  type TupleToUnion<K extends readonly any[]> = _TupleToUnion<K>
  type MaybeTupleToUnion<T> = T extends any[] ? TupleToUnion<T> : T

  /**
   * Like `Pick`, but additionally can also accept an array of keys
   */
  type PickEnumerable<T, K extends Enumerable<keyof T> | keyof T> = Prisma__Pick<T, MaybeTupleToUnion<K>>

  /**
   * Exclude all keys with underscores
   */
  type ExcludeUnderscoreKeys<T extends string> = T extends `_${string}` ? never : T


  export type FieldRef<Model, FieldType> = runtime.FieldRef<Model, FieldType>

  type FieldRefInputType<Model, FieldType> = Model extends never ? never : FieldRef<Model, FieldType>


  export const ModelName: {
    Server: 'Server',
    Product: 'Product',
    ProductSetting: 'ProductSetting',
    ProductSettingDetail: 'ProductSettingDetail',
    UpdaterVersion: 'UpdaterVersion',
    Customer: 'Customer',
    AssistantMonitoring: 'AssistantMonitoring',
    Notification: 'Notification'
  };

  export type ModelName = (typeof ModelName)[keyof typeof ModelName]


  export type Datasources = {
    db?: Datasource
  }


  interface TypeMapCb extends $Utils.Fn<{extArgs: $Extensions.InternalArgs}, $Utils.Record<string, any>> {
    returns: Prisma.TypeMap<this['params']['extArgs']>
  }

  export type TypeMap<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    meta: {
      modelProps: 'server' | 'product' | 'productSetting' | 'productSettingDetail' | 'updaterVersion' | 'customer' | 'assistantMonitoring' | 'notification'
      txIsolationLevel: Prisma.TransactionIsolationLevel
    },
    model: {
      Server: {
        payload: Prisma.$ServerPayload<ExtArgs>
        fields: Prisma.ServerFieldRefs
        operations: {
          findUnique: {
            args: Prisma.ServerFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.ServerFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>
          }
          findFirst: {
            args: Prisma.ServerFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.ServerFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>
          }
          findMany: {
            args: Prisma.ServerFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>[]
          }
          create: {
            args: Prisma.ServerCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>
          }
          delete: {
            args: Prisma.ServerDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>
          }
          update: {
            args: Prisma.ServerUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>
          }
          deleteMany: {
            args: Prisma.ServerDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.ServerUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.ServerUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ServerPayload>
          }
          aggregate: {
            args: Prisma.ServerAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateServer>
          }
          groupBy: {
            args: Prisma.ServerGroupByArgs<ExtArgs>,
            result: $Utils.Optional<ServerGroupByOutputType>[]
          }
          count: {
            args: Prisma.ServerCountArgs<ExtArgs>,
            result: $Utils.Optional<ServerCountAggregateOutputType> | number
          }
        }
      }
      Product: {
        payload: Prisma.$ProductPayload<ExtArgs>
        fields: Prisma.ProductFieldRefs
        operations: {
          findUnique: {
            args: Prisma.ProductFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.ProductFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>
          }
          findFirst: {
            args: Prisma.ProductFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.ProductFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>
          }
          findMany: {
            args: Prisma.ProductFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>[]
          }
          create: {
            args: Prisma.ProductCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>
          }
          delete: {
            args: Prisma.ProductDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>
          }
          update: {
            args: Prisma.ProductUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>
          }
          deleteMany: {
            args: Prisma.ProductDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.ProductUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.ProductUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductPayload>
          }
          aggregate: {
            args: Prisma.ProductAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateProduct>
          }
          groupBy: {
            args: Prisma.ProductGroupByArgs<ExtArgs>,
            result: $Utils.Optional<ProductGroupByOutputType>[]
          }
          count: {
            args: Prisma.ProductCountArgs<ExtArgs>,
            result: $Utils.Optional<ProductCountAggregateOutputType> | number
          }
        }
      }
      ProductSetting: {
        payload: Prisma.$ProductSettingPayload<ExtArgs>
        fields: Prisma.ProductSettingFieldRefs
        operations: {
          findUnique: {
            args: Prisma.ProductSettingFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.ProductSettingFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>
          }
          findFirst: {
            args: Prisma.ProductSettingFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.ProductSettingFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>
          }
          findMany: {
            args: Prisma.ProductSettingFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>[]
          }
          create: {
            args: Prisma.ProductSettingCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>
          }
          delete: {
            args: Prisma.ProductSettingDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>
          }
          update: {
            args: Prisma.ProductSettingUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>
          }
          deleteMany: {
            args: Prisma.ProductSettingDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.ProductSettingUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.ProductSettingUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingPayload>
          }
          aggregate: {
            args: Prisma.ProductSettingAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateProductSetting>
          }
          groupBy: {
            args: Prisma.ProductSettingGroupByArgs<ExtArgs>,
            result: $Utils.Optional<ProductSettingGroupByOutputType>[]
          }
          count: {
            args: Prisma.ProductSettingCountArgs<ExtArgs>,
            result: $Utils.Optional<ProductSettingCountAggregateOutputType> | number
          }
        }
      }
      ProductSettingDetail: {
        payload: Prisma.$ProductSettingDetailPayload<ExtArgs>
        fields: Prisma.ProductSettingDetailFieldRefs
        operations: {
          findUnique: {
            args: Prisma.ProductSettingDetailFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.ProductSettingDetailFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>
          }
          findFirst: {
            args: Prisma.ProductSettingDetailFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.ProductSettingDetailFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>
          }
          findMany: {
            args: Prisma.ProductSettingDetailFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>[]
          }
          create: {
            args: Prisma.ProductSettingDetailCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>
          }
          delete: {
            args: Prisma.ProductSettingDetailDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>
          }
          update: {
            args: Prisma.ProductSettingDetailUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>
          }
          deleteMany: {
            args: Prisma.ProductSettingDetailDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.ProductSettingDetailUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.ProductSettingDetailUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$ProductSettingDetailPayload>
          }
          aggregate: {
            args: Prisma.ProductSettingDetailAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateProductSettingDetail>
          }
          groupBy: {
            args: Prisma.ProductSettingDetailGroupByArgs<ExtArgs>,
            result: $Utils.Optional<ProductSettingDetailGroupByOutputType>[]
          }
          count: {
            args: Prisma.ProductSettingDetailCountArgs<ExtArgs>,
            result: $Utils.Optional<ProductSettingDetailCountAggregateOutputType> | number
          }
        }
      }
      UpdaterVersion: {
        payload: Prisma.$UpdaterVersionPayload<ExtArgs>
        fields: Prisma.UpdaterVersionFieldRefs
        operations: {
          findUnique: {
            args: Prisma.UpdaterVersionFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.UpdaterVersionFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>
          }
          findFirst: {
            args: Prisma.UpdaterVersionFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.UpdaterVersionFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>
          }
          findMany: {
            args: Prisma.UpdaterVersionFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>[]
          }
          create: {
            args: Prisma.UpdaterVersionCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>
          }
          delete: {
            args: Prisma.UpdaterVersionDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>
          }
          update: {
            args: Prisma.UpdaterVersionUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>
          }
          deleteMany: {
            args: Prisma.UpdaterVersionDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.UpdaterVersionUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.UpdaterVersionUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$UpdaterVersionPayload>
          }
          aggregate: {
            args: Prisma.UpdaterVersionAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateUpdaterVersion>
          }
          groupBy: {
            args: Prisma.UpdaterVersionGroupByArgs<ExtArgs>,
            result: $Utils.Optional<UpdaterVersionGroupByOutputType>[]
          }
          count: {
            args: Prisma.UpdaterVersionCountArgs<ExtArgs>,
            result: $Utils.Optional<UpdaterVersionCountAggregateOutputType> | number
          }
        }
      }
      Customer: {
        payload: Prisma.$CustomerPayload<ExtArgs>
        fields: Prisma.CustomerFieldRefs
        operations: {
          findUnique: {
            args: Prisma.CustomerFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.CustomerFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>
          }
          findFirst: {
            args: Prisma.CustomerFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.CustomerFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>
          }
          findMany: {
            args: Prisma.CustomerFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>[]
          }
          create: {
            args: Prisma.CustomerCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>
          }
          delete: {
            args: Prisma.CustomerDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>
          }
          update: {
            args: Prisma.CustomerUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>
          }
          deleteMany: {
            args: Prisma.CustomerDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.CustomerUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.CustomerUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$CustomerPayload>
          }
          aggregate: {
            args: Prisma.CustomerAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateCustomer>
          }
          groupBy: {
            args: Prisma.CustomerGroupByArgs<ExtArgs>,
            result: $Utils.Optional<CustomerGroupByOutputType>[]
          }
          count: {
            args: Prisma.CustomerCountArgs<ExtArgs>,
            result: $Utils.Optional<CustomerCountAggregateOutputType> | number
          }
        }
      }
      AssistantMonitoring: {
        payload: Prisma.$AssistantMonitoringPayload<ExtArgs>
        fields: Prisma.AssistantMonitoringFieldRefs
        operations: {
          findUnique: {
            args: Prisma.AssistantMonitoringFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.AssistantMonitoringFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>
          }
          findFirst: {
            args: Prisma.AssistantMonitoringFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.AssistantMonitoringFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>
          }
          findMany: {
            args: Prisma.AssistantMonitoringFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>[]
          }
          create: {
            args: Prisma.AssistantMonitoringCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>
          }
          delete: {
            args: Prisma.AssistantMonitoringDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>
          }
          update: {
            args: Prisma.AssistantMonitoringUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>
          }
          deleteMany: {
            args: Prisma.AssistantMonitoringDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.AssistantMonitoringUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.AssistantMonitoringUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$AssistantMonitoringPayload>
          }
          aggregate: {
            args: Prisma.AssistantMonitoringAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateAssistantMonitoring>
          }
          groupBy: {
            args: Prisma.AssistantMonitoringGroupByArgs<ExtArgs>,
            result: $Utils.Optional<AssistantMonitoringGroupByOutputType>[]
          }
          count: {
            args: Prisma.AssistantMonitoringCountArgs<ExtArgs>,
            result: $Utils.Optional<AssistantMonitoringCountAggregateOutputType> | number
          }
        }
      }
      Notification: {
        payload: Prisma.$NotificationPayload<ExtArgs>
        fields: Prisma.NotificationFieldRefs
        operations: {
          findUnique: {
            args: Prisma.NotificationFindUniqueArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload> | null
          }
          findUniqueOrThrow: {
            args: Prisma.NotificationFindUniqueOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>
          }
          findFirst: {
            args: Prisma.NotificationFindFirstArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload> | null
          }
          findFirstOrThrow: {
            args: Prisma.NotificationFindFirstOrThrowArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>
          }
          findMany: {
            args: Prisma.NotificationFindManyArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>[]
          }
          create: {
            args: Prisma.NotificationCreateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>
          }
          delete: {
            args: Prisma.NotificationDeleteArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>
          }
          update: {
            args: Prisma.NotificationUpdateArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>
          }
          deleteMany: {
            args: Prisma.NotificationDeleteManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          updateMany: {
            args: Prisma.NotificationUpdateManyArgs<ExtArgs>,
            result: Prisma.BatchPayload
          }
          upsert: {
            args: Prisma.NotificationUpsertArgs<ExtArgs>,
            result: $Utils.PayloadToResult<Prisma.$NotificationPayload>
          }
          aggregate: {
            args: Prisma.NotificationAggregateArgs<ExtArgs>,
            result: $Utils.Optional<AggregateNotification>
          }
          groupBy: {
            args: Prisma.NotificationGroupByArgs<ExtArgs>,
            result: $Utils.Optional<NotificationGroupByOutputType>[]
          }
          count: {
            args: Prisma.NotificationCountArgs<ExtArgs>,
            result: $Utils.Optional<NotificationCountAggregateOutputType> | number
          }
        }
      }
    }
  } & {
    other: {
      payload: any
      operations: {
        $executeRawUnsafe: {
          args: [query: string, ...values: any[]],
          result: any
        }
        $executeRaw: {
          args: [query: TemplateStringsArray | Prisma.Sql, ...values: any[]],
          result: any
        }
        $queryRawUnsafe: {
          args: [query: string, ...values: any[]],
          result: any
        }
        $queryRaw: {
          args: [query: TemplateStringsArray | Prisma.Sql, ...values: any[]],
          result: any
        }
      }
    }
  }
  export const defineExtension: $Extensions.ExtendsHook<'define', Prisma.TypeMapCb, $Extensions.DefaultArgs>
  export type DefaultPrismaClient = PrismaClient
  export type ErrorFormat = 'pretty' | 'colorless' | 'minimal'
  export interface PrismaClientOptions {
    /**
     * Overwrites the datasource url from your schema.prisma file
     */
    datasources?: Datasources
    /**
     * Overwrites the datasource url from your schema.prisma file
     */
    datasourceUrl?: string
    /**
     * @default "colorless"
     */
    errorFormat?: ErrorFormat
    /**
     * @example
     * ```
     * // Defaults to stdout
     * log: ['query', 'info', 'warn', 'error']
     * 
     * // Emit as events
     * log: [
     *   { emit: 'stdout', level: 'query' },
     *   { emit: 'stdout', level: 'info' },
     *   { emit: 'stdout', level: 'warn' }
     *   { emit: 'stdout', level: 'error' }
     * ]
     * ```
     * Read more in our [docs](https://www.prisma.io/docs/reference/tools-and-interfaces/prisma-client/logging#the-log-option).
     */
    log?: (LogLevel | LogDefinition)[]
    /**
     * The default values for transactionOptions
     * maxWait ?= 2000
     * timeout ?= 5000
     */
    transactionOptions?: {
      maxWait?: number
      timeout?: number
      isolationLevel?: Prisma.TransactionIsolationLevel
    }
  }

  /* Types for Logging */
  export type LogLevel = 'info' | 'query' | 'warn' | 'error'
  export type LogDefinition = {
    level: LogLevel
    emit: 'stdout' | 'event'
  }

  export type GetLogType<T extends LogLevel | LogDefinition> = T extends LogDefinition ? T['emit'] extends 'event' ? T['level'] : never : never
  export type GetEvents<T extends any> = T extends Array<LogLevel | LogDefinition> ?
    GetLogType<T[0]> | GetLogType<T[1]> | GetLogType<T[2]> | GetLogType<T[3]>
    : never

  export type QueryEvent = {
    timestamp: Date
    query: string
    params: string
    duration: number
    target: string
  }

  export type LogEvent = {
    timestamp: Date
    message: string
    target: string
  }
  /* End Types for Logging */


  export type PrismaAction =
    | 'findUnique'
    | 'findUniqueOrThrow'
    | 'findMany'
    | 'findFirst'
    | 'findFirstOrThrow'
    | 'create'
    | 'createMany'
    | 'update'
    | 'updateMany'
    | 'upsert'
    | 'delete'
    | 'deleteMany'
    | 'executeRaw'
    | 'queryRaw'
    | 'aggregate'
    | 'count'
    | 'runCommandRaw'
    | 'findRaw'
    | 'groupBy'

  /**
   * These options are being passed into the middleware as "params"
   */
  export type MiddlewareParams = {
    model?: ModelName
    action: PrismaAction
    args: any
    dataPath: string[]
    runInTransaction: boolean
  }

  /**
   * The `T` type makes sure, that the `return proceed` is not forgotten in the middleware implementation
   */
  export type Middleware<T = any> = (
    params: MiddlewareParams,
    next: (params: MiddlewareParams) => $Utils.JsPromise<T>,
  ) => $Utils.JsPromise<T>

  // tested in getLogLevel.test.ts
  export function getLogLevel(log: Array<LogLevel | LogDefinition>): LogLevel | undefined;

  /**
   * `PrismaClient` proxy available in interactive transactions.
   */
  export type TransactionClient = Omit<Prisma.DefaultPrismaClient, runtime.ITXClientDenyList>

  export type Datasource = {
    url?: string
  }

  /**
   * Count Types
   */


  /**
   * Count Type ProductCountOutputType
   */

  export type ProductCountOutputType = {
    requiredProducts: number
    requiredByProducts: number
  }

  export type ProductCountOutputTypeSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    requiredProducts?: boolean | ProductCountOutputTypeCountRequiredProductsArgs
    requiredByProducts?: boolean | ProductCountOutputTypeCountRequiredByProductsArgs
  }

  // Custom InputTypes

  /**
   * ProductCountOutputType without action
   */
  export type ProductCountOutputTypeDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductCountOutputType
     */
    select?: ProductCountOutputTypeSelect<ExtArgs> | null
  }


  /**
   * ProductCountOutputType without action
   */
  export type ProductCountOutputTypeCountRequiredProductsArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: ProductWhereInput
  }


  /**
   * ProductCountOutputType without action
   */
  export type ProductCountOutputTypeCountRequiredByProductsArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: ProductWhereInput
  }



  /**
   * Models
   */

  /**
   * Model Server
   */

  export type AggregateServer = {
    _count: ServerCountAggregateOutputType | null
    _avg: ServerAvgAggregateOutputType | null
    _sum: ServerSumAggregateOutputType | null
    _min: ServerMinAggregateOutputType | null
    _max: ServerMaxAggregateOutputType | null
  }

  export type ServerAvgAggregateOutputType = {
    port: number | null
  }

  export type ServerSumAggregateOutputType = {
    port: number | null
  }

  export type ServerMinAggregateOutputType = {
    id: string | null
    name: string | null
    protocol: string | null
    host: string | null
    port: number | null
    isActive: string | null
    deployEnabled: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type ServerMaxAggregateOutputType = {
    id: string | null
    name: string | null
    protocol: string | null
    host: string | null
    port: number | null
    isActive: string | null
    deployEnabled: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type ServerCountAggregateOutputType = {
    id: number
    name: number
    protocol: number
    host: number
    port: number
    isActive: number
    deployEnabled: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type ServerAvgAggregateInputType = {
    port?: true
  }

  export type ServerSumAggregateInputType = {
    port?: true
  }

  export type ServerMinAggregateInputType = {
    id?: true
    name?: true
    protocol?: true
    host?: true
    port?: true
    isActive?: true
    deployEnabled?: true
    createdAt?: true
    updatedAt?: true
  }

  export type ServerMaxAggregateInputType = {
    id?: true
    name?: true
    protocol?: true
    host?: true
    port?: true
    isActive?: true
    deployEnabled?: true
    createdAt?: true
    updatedAt?: true
  }

  export type ServerCountAggregateInputType = {
    id?: true
    name?: true
    protocol?: true
    host?: true
    port?: true
    isActive?: true
    deployEnabled?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type ServerAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Server to aggregate.
     */
    where?: ServerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Servers to fetch.
     */
    orderBy?: ServerOrderByWithRelationInput | ServerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: ServerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Servers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Servers.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned Servers
    **/
    _count?: true | ServerCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to average
    **/
    _avg?: ServerAvgAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to sum
    **/
    _sum?: ServerSumAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: ServerMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: ServerMaxAggregateInputType
  }

  export type GetServerAggregateType<T extends ServerAggregateArgs> = {
        [P in keyof T & keyof AggregateServer]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateServer[P]>
      : GetScalarType<T[P], AggregateServer[P]>
  }




  export type ServerGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: ServerWhereInput
    orderBy?: ServerOrderByWithAggregationInput | ServerOrderByWithAggregationInput[]
    by: ServerScalarFieldEnum[] | ServerScalarFieldEnum
    having?: ServerScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: ServerCountAggregateInputType | true
    _avg?: ServerAvgAggregateInputType
    _sum?: ServerSumAggregateInputType
    _min?: ServerMinAggregateInputType
    _max?: ServerMaxAggregateInputType
  }

  export type ServerGroupByOutputType = {
    id: string
    name: string
    protocol: string
    host: string
    port: number
    isActive: string
    deployEnabled: string
    createdAt: Date
    updatedAt: Date
    _count: ServerCountAggregateOutputType | null
    _avg: ServerAvgAggregateOutputType | null
    _sum: ServerSumAggregateOutputType | null
    _min: ServerMinAggregateOutputType | null
    _max: ServerMaxAggregateOutputType | null
  }

  type GetServerGroupByPayload<T extends ServerGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<ServerGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof ServerGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], ServerGroupByOutputType[P]>
            : GetScalarType<T[P], ServerGroupByOutputType[P]>
        }
      >
    >


  export type ServerSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    name?: boolean
    protocol?: boolean
    host?: boolean
    port?: boolean
    isActive?: boolean
    deployEnabled?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }, ExtArgs["result"]["server"]>

  export type ServerSelectScalar = {
    id?: boolean
    name?: boolean
    protocol?: boolean
    host?: boolean
    port?: boolean
    isActive?: boolean
    deployEnabled?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }


  export type $ServerPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "Server"
    objects: {}
    scalars: $Extensions.GetPayloadResult<{
      id: string
      name: string
      protocol: string
      host: string
      port: number
      isActive: string
      deployEnabled: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["server"]>
    composites: {}
  }


  type ServerGetPayload<S extends boolean | null | undefined | ServerDefaultArgs> = $Result.GetResult<Prisma.$ServerPayload, S>

  type ServerCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<ServerFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: ServerCountAggregateInputType | true
    }

  export interface ServerDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['Server'], meta: { name: 'Server' } }
    /**
     * Find zero or one Server that matches the filter.
     * @param {ServerFindUniqueArgs} args - Arguments to find a Server
     * @example
     * // Get one Server
     * const server = await prisma.server.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends ServerFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, ServerFindUniqueArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one Server that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {ServerFindUniqueOrThrowArgs} args - Arguments to find a Server
     * @example
     * // Get one Server
     * const server = await prisma.server.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends ServerFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ServerFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first Server that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerFindFirstArgs} args - Arguments to find a Server
     * @example
     * // Get one Server
     * const server = await prisma.server.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends ServerFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, ServerFindFirstArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first Server that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerFindFirstOrThrowArgs} args - Arguments to find a Server
     * @example
     * // Get one Server
     * const server = await prisma.server.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends ServerFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ServerFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more Servers that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all Servers
     * const servers = await prisma.server.findMany()
     * 
     * // Get first 10 Servers
     * const servers = await prisma.server.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const serverWithIdOnly = await prisma.server.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends ServerFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ServerFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a Server.
     * @param {ServerCreateArgs} args - Arguments to create a Server.
     * @example
     * // Create one Server
     * const Server = await prisma.server.create({
     *   data: {
     *     // ... data to create a Server
     *   }
     * })
     * 
    **/
    create<T extends ServerCreateArgs<ExtArgs>>(
      args: SelectSubset<T, ServerCreateArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a Server.
     * @param {ServerDeleteArgs} args - Arguments to delete one Server.
     * @example
     * // Delete one Server
     * const Server = await prisma.server.delete({
     *   where: {
     *     // ... filter to delete one Server
     *   }
     * })
     * 
    **/
    delete<T extends ServerDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, ServerDeleteArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one Server.
     * @param {ServerUpdateArgs} args - Arguments to update one Server.
     * @example
     * // Update one Server
     * const server = await prisma.server.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends ServerUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, ServerUpdateArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more Servers.
     * @param {ServerDeleteManyArgs} args - Arguments to filter Servers to delete.
     * @example
     * // Delete a few Servers
     * const { count } = await prisma.server.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends ServerDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ServerDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more Servers.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many Servers
     * const server = await prisma.server.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends ServerUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, ServerUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one Server.
     * @param {ServerUpsertArgs} args - Arguments to update or create a Server.
     * @example
     * // Update or create a Server
     * const server = await prisma.server.upsert({
     *   create: {
     *     // ... data to create a Server
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the Server we want to update
     *   }
     * })
    **/
    upsert<T extends ServerUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, ServerUpsertArgs<ExtArgs>>
    ): Prisma__ServerClient<$Result.GetResult<Prisma.$ServerPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of Servers.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerCountArgs} args - Arguments to filter Servers to count.
     * @example
     * // Count the number of Servers
     * const count = await prisma.server.count({
     *   where: {
     *     // ... the filter for the Servers we want to count
     *   }
     * })
    **/
    count<T extends ServerCountArgs>(
      args?: Subset<T, ServerCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], ServerCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a Server.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends ServerAggregateArgs>(args: Subset<T, ServerAggregateArgs>): Prisma.PrismaPromise<GetServerAggregateType<T>>

    /**
     * Group by Server.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ServerGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends ServerGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: ServerGroupByArgs['orderBy'] }
        : { orderBy?: ServerGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, ServerGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetServerGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the Server model
   */
  readonly fields: ServerFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for Server.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__ServerClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';


    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the Server model
   */ 
  interface ServerFieldRefs {
    readonly id: FieldRef<"Server", 'String'>
    readonly name: FieldRef<"Server", 'String'>
    readonly protocol: FieldRef<"Server", 'String'>
    readonly host: FieldRef<"Server", 'String'>
    readonly port: FieldRef<"Server", 'Int'>
    readonly isActive: FieldRef<"Server", 'String'>
    readonly deployEnabled: FieldRef<"Server", 'String'>
    readonly createdAt: FieldRef<"Server", 'DateTime'>
    readonly updatedAt: FieldRef<"Server", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * Server findUnique
   */
  export type ServerFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * Filter, which Server to fetch.
     */
    where: ServerWhereUniqueInput
  }


  /**
   * Server findUniqueOrThrow
   */
  export type ServerFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * Filter, which Server to fetch.
     */
    where: ServerWhereUniqueInput
  }


  /**
   * Server findFirst
   */
  export type ServerFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * Filter, which Server to fetch.
     */
    where?: ServerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Servers to fetch.
     */
    orderBy?: ServerOrderByWithRelationInput | ServerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Servers.
     */
    cursor?: ServerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Servers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Servers.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Servers.
     */
    distinct?: ServerScalarFieldEnum | ServerScalarFieldEnum[]
  }


  /**
   * Server findFirstOrThrow
   */
  export type ServerFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * Filter, which Server to fetch.
     */
    where?: ServerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Servers to fetch.
     */
    orderBy?: ServerOrderByWithRelationInput | ServerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Servers.
     */
    cursor?: ServerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Servers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Servers.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Servers.
     */
    distinct?: ServerScalarFieldEnum | ServerScalarFieldEnum[]
  }


  /**
   * Server findMany
   */
  export type ServerFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * Filter, which Servers to fetch.
     */
    where?: ServerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Servers to fetch.
     */
    orderBy?: ServerOrderByWithRelationInput | ServerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing Servers.
     */
    cursor?: ServerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Servers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Servers.
     */
    skip?: number
    distinct?: ServerScalarFieldEnum | ServerScalarFieldEnum[]
  }


  /**
   * Server create
   */
  export type ServerCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * The data needed to create a Server.
     */
    data: XOR<ServerCreateInput, ServerUncheckedCreateInput>
  }


  /**
   * Server update
   */
  export type ServerUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * The data needed to update a Server.
     */
    data: XOR<ServerUpdateInput, ServerUncheckedUpdateInput>
    /**
     * Choose, which Server to update.
     */
    where: ServerWhereUniqueInput
  }


  /**
   * Server updateMany
   */
  export type ServerUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update Servers.
     */
    data: XOR<ServerUpdateManyMutationInput, ServerUncheckedUpdateManyInput>
    /**
     * Filter which Servers to update
     */
    where?: ServerWhereInput
  }


  /**
   * Server upsert
   */
  export type ServerUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * The filter to search for the Server to update in case it exists.
     */
    where: ServerWhereUniqueInput
    /**
     * In case the Server found by the `where` argument doesn't exist, create a new Server with this data.
     */
    create: XOR<ServerCreateInput, ServerUncheckedCreateInput>
    /**
     * In case the Server was found with the provided `where` argument, update it with this data.
     */
    update: XOR<ServerUpdateInput, ServerUncheckedUpdateInput>
  }


  /**
   * Server delete
   */
  export type ServerDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
    /**
     * Filter which Server to delete.
     */
    where: ServerWhereUniqueInput
  }


  /**
   * Server deleteMany
   */
  export type ServerDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Servers to delete
     */
    where?: ServerWhereInput
  }


  /**
   * Server without action
   */
  export type ServerDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Server
     */
    select?: ServerSelect<ExtArgs> | null
  }



  /**
   * Model Product
   */

  export type AggregateProduct = {
    _count: ProductCountAggregateOutputType | null
    _avg: ProductAvgAggregateOutputType | null
    _sum: ProductSumAggregateOutputType | null
    _min: ProductMinAggregateOutputType | null
    _max: ProductMaxAggregateOutputType | null
  }

  export type ProductAvgAggregateOutputType = {
    devopsId: number | null
  }

  export type ProductSumAggregateOutputType = {
    devopsId: number | null
  }

  export type ProductMinAggregateOutputType = {
    id: string | null
    devopsId: number | null
    productName: string | null
    description: string | null
    requirements: string | null
    productImage: string | null
    productOriginalImage: string | null
    isActive: string | null
    createdAt: Date | null
    updatedAt: Date | null
    guideUrl: string | null
  }

  export type ProductMaxAggregateOutputType = {
    id: string | null
    devopsId: number | null
    productName: string | null
    description: string | null
    requirements: string | null
    productImage: string | null
    productOriginalImage: string | null
    isActive: string | null
    createdAt: Date | null
    updatedAt: Date | null
    guideUrl: string | null
  }

  export type ProductCountAggregateOutputType = {
    id: number
    devopsId: number
    productName: number
    description: number
    requirements: number
    productImage: number
    productOriginalImage: number
    isActive: number
    createdAt: number
    updatedAt: number
    guideUrl: number
    _all: number
  }


  export type ProductAvgAggregateInputType = {
    devopsId?: true
  }

  export type ProductSumAggregateInputType = {
    devopsId?: true
  }

  export type ProductMinAggregateInputType = {
    id?: true
    devopsId?: true
    productName?: true
    description?: true
    requirements?: true
    productImage?: true
    productOriginalImage?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
    guideUrl?: true
  }

  export type ProductMaxAggregateInputType = {
    id?: true
    devopsId?: true
    productName?: true
    description?: true
    requirements?: true
    productImage?: true
    productOriginalImage?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
    guideUrl?: true
  }

  export type ProductCountAggregateInputType = {
    id?: true
    devopsId?: true
    productName?: true
    description?: true
    requirements?: true
    productImage?: true
    productOriginalImage?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
    guideUrl?: true
    _all?: true
  }

  export type ProductAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Product to aggregate.
     */
    where?: ProductWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Products to fetch.
     */
    orderBy?: ProductOrderByWithRelationInput | ProductOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: ProductWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Products from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Products.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned Products
    **/
    _count?: true | ProductCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to average
    **/
    _avg?: ProductAvgAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to sum
    **/
    _sum?: ProductSumAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: ProductMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: ProductMaxAggregateInputType
  }

  export type GetProductAggregateType<T extends ProductAggregateArgs> = {
        [P in keyof T & keyof AggregateProduct]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateProduct[P]>
      : GetScalarType<T[P], AggregateProduct[P]>
  }




  export type ProductGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: ProductWhereInput
    orderBy?: ProductOrderByWithAggregationInput | ProductOrderByWithAggregationInput[]
    by: ProductScalarFieldEnum[] | ProductScalarFieldEnum
    having?: ProductScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: ProductCountAggregateInputType | true
    _avg?: ProductAvgAggregateInputType
    _sum?: ProductSumAggregateInputType
    _min?: ProductMinAggregateInputType
    _max?: ProductMaxAggregateInputType
  }

  export type ProductGroupByOutputType = {
    id: string
    devopsId: number
    productName: string
    description: string | null
    requirements: string | null
    productImage: string | null
    productOriginalImage: string | null
    isActive: string
    createdAt: Date
    updatedAt: Date
    guideUrl: string | null
    _count: ProductCountAggregateOutputType | null
    _avg: ProductAvgAggregateOutputType | null
    _sum: ProductSumAggregateOutputType | null
    _min: ProductMinAggregateOutputType | null
    _max: ProductMaxAggregateOutputType | null
  }

  type GetProductGroupByPayload<T extends ProductGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<ProductGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof ProductGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], ProductGroupByOutputType[P]>
            : GetScalarType<T[P], ProductGroupByOutputType[P]>
        }
      >
    >


  export type ProductSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    devopsId?: boolean
    productName?: boolean
    description?: boolean
    requirements?: boolean
    productImage?: boolean
    productOriginalImage?: boolean
    isActive?: boolean
    createdAt?: boolean
    updatedAt?: boolean
    guideUrl?: boolean
    config?: boolean | ProductSettingDefaultArgs<ExtArgs>
    requiredProducts?: boolean | Product$requiredProductsArgs<ExtArgs>
    requiredByProducts?: boolean | Product$requiredByProductsArgs<ExtArgs>
    _count?: boolean | ProductCountOutputTypeDefaultArgs<ExtArgs>
  }, ExtArgs["result"]["product"]>

  export type ProductSelectScalar = {
    id?: boolean
    devopsId?: boolean
    productName?: boolean
    description?: boolean
    requirements?: boolean
    productImage?: boolean
    productOriginalImage?: boolean
    isActive?: boolean
    createdAt?: boolean
    updatedAt?: boolean
    guideUrl?: boolean
  }

  export type ProductInclude<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    config?: boolean | ProductSettingDefaultArgs<ExtArgs>
    requiredProducts?: boolean | Product$requiredProductsArgs<ExtArgs>
    requiredByProducts?: boolean | Product$requiredByProductsArgs<ExtArgs>
    _count?: boolean | ProductCountOutputTypeDefaultArgs<ExtArgs>
  }


  export type $ProductPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "Product"
    objects: {
      config: Prisma.$ProductSettingPayload<ExtArgs> | null
      requiredProducts: Prisma.$ProductPayload<ExtArgs>[]
      requiredByProducts: Prisma.$ProductPayload<ExtArgs>[]
    }
    scalars: $Extensions.GetPayloadResult<{
      id: string
      devopsId: number
      productName: string
      description: string | null
      requirements: string | null
      productImage: string | null
      productOriginalImage: string | null
      isActive: string
      createdAt: Date
      updatedAt: Date
      guideUrl: string | null
    }, ExtArgs["result"]["product"]>
    composites: {}
  }


  type ProductGetPayload<S extends boolean | null | undefined | ProductDefaultArgs> = $Result.GetResult<Prisma.$ProductPayload, S>

  type ProductCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<ProductFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: ProductCountAggregateInputType | true
    }

  export interface ProductDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['Product'], meta: { name: 'Product' } }
    /**
     * Find zero or one Product that matches the filter.
     * @param {ProductFindUniqueArgs} args - Arguments to find a Product
     * @example
     * // Get one Product
     * const product = await prisma.product.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends ProductFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, ProductFindUniqueArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one Product that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {ProductFindUniqueOrThrowArgs} args - Arguments to find a Product
     * @example
     * // Get one Product
     * const product = await prisma.product.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends ProductFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first Product that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductFindFirstArgs} args - Arguments to find a Product
     * @example
     * // Get one Product
     * const product = await prisma.product.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends ProductFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductFindFirstArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first Product that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductFindFirstOrThrowArgs} args - Arguments to find a Product
     * @example
     * // Get one Product
     * const product = await prisma.product.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends ProductFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more Products that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all Products
     * const products = await prisma.product.findMany()
     * 
     * // Get first 10 Products
     * const products = await prisma.product.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const productWithIdOnly = await prisma.product.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends ProductFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a Product.
     * @param {ProductCreateArgs} args - Arguments to create a Product.
     * @example
     * // Create one Product
     * const Product = await prisma.product.create({
     *   data: {
     *     // ... data to create a Product
     *   }
     * })
     * 
    **/
    create<T extends ProductCreateArgs<ExtArgs>>(
      args: SelectSubset<T, ProductCreateArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a Product.
     * @param {ProductDeleteArgs} args - Arguments to delete one Product.
     * @example
     * // Delete one Product
     * const Product = await prisma.product.delete({
     *   where: {
     *     // ... filter to delete one Product
     *   }
     * })
     * 
    **/
    delete<T extends ProductDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, ProductDeleteArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one Product.
     * @param {ProductUpdateArgs} args - Arguments to update one Product.
     * @example
     * // Update one Product
     * const product = await prisma.product.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends ProductUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, ProductUpdateArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more Products.
     * @param {ProductDeleteManyArgs} args - Arguments to filter Products to delete.
     * @example
     * // Delete a few Products
     * const { count } = await prisma.product.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends ProductDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more Products.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many Products
     * const product = await prisma.product.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends ProductUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, ProductUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one Product.
     * @param {ProductUpsertArgs} args - Arguments to update or create a Product.
     * @example
     * // Update or create a Product
     * const product = await prisma.product.upsert({
     *   create: {
     *     // ... data to create a Product
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the Product we want to update
     *   }
     * })
    **/
    upsert<T extends ProductUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, ProductUpsertArgs<ExtArgs>>
    ): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of Products.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductCountArgs} args - Arguments to filter Products to count.
     * @example
     * // Count the number of Products
     * const count = await prisma.product.count({
     *   where: {
     *     // ... the filter for the Products we want to count
     *   }
     * })
    **/
    count<T extends ProductCountArgs>(
      args?: Subset<T, ProductCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], ProductCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a Product.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends ProductAggregateArgs>(args: Subset<T, ProductAggregateArgs>): Prisma.PrismaPromise<GetProductAggregateType<T>>

    /**
     * Group by Product.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends ProductGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: ProductGroupByArgs['orderBy'] }
        : { orderBy?: ProductGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, ProductGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetProductGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the Product model
   */
  readonly fields: ProductFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for Product.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__ProductClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';

    config<T extends ProductSettingDefaultArgs<ExtArgs> = {}>(args?: Subset<T, ProductSettingDefaultArgs<ExtArgs>>): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findUniqueOrThrow'> | null, null, ExtArgs>;

    requiredProducts<T extends Product$requiredProductsArgs<ExtArgs> = {}>(args?: Subset<T, Product$requiredProductsArgs<ExtArgs>>): Prisma.PrismaPromise<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findMany'> | Null>;

    requiredByProducts<T extends Product$requiredByProductsArgs<ExtArgs> = {}>(args?: Subset<T, Product$requiredByProductsArgs<ExtArgs>>): Prisma.PrismaPromise<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findMany'> | Null>;

    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the Product model
   */ 
  interface ProductFieldRefs {
    readonly id: FieldRef<"Product", 'String'>
    readonly devopsId: FieldRef<"Product", 'Int'>
    readonly productName: FieldRef<"Product", 'String'>
    readonly description: FieldRef<"Product", 'String'>
    readonly requirements: FieldRef<"Product", 'String'>
    readonly productImage: FieldRef<"Product", 'String'>
    readonly productOriginalImage: FieldRef<"Product", 'String'>
    readonly isActive: FieldRef<"Product", 'String'>
    readonly createdAt: FieldRef<"Product", 'DateTime'>
    readonly updatedAt: FieldRef<"Product", 'DateTime'>
    readonly guideUrl: FieldRef<"Product", 'String'>
  }
    

  // Custom InputTypes

  /**
   * Product findUnique
   */
  export type ProductFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * Filter, which Product to fetch.
     */
    where: ProductWhereUniqueInput
  }


  /**
   * Product findUniqueOrThrow
   */
  export type ProductFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * Filter, which Product to fetch.
     */
    where: ProductWhereUniqueInput
  }


  /**
   * Product findFirst
   */
  export type ProductFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * Filter, which Product to fetch.
     */
    where?: ProductWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Products to fetch.
     */
    orderBy?: ProductOrderByWithRelationInput | ProductOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Products.
     */
    cursor?: ProductWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Products from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Products.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Products.
     */
    distinct?: ProductScalarFieldEnum | ProductScalarFieldEnum[]
  }


  /**
   * Product findFirstOrThrow
   */
  export type ProductFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * Filter, which Product to fetch.
     */
    where?: ProductWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Products to fetch.
     */
    orderBy?: ProductOrderByWithRelationInput | ProductOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Products.
     */
    cursor?: ProductWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Products from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Products.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Products.
     */
    distinct?: ProductScalarFieldEnum | ProductScalarFieldEnum[]
  }


  /**
   * Product findMany
   */
  export type ProductFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * Filter, which Products to fetch.
     */
    where?: ProductWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Products to fetch.
     */
    orderBy?: ProductOrderByWithRelationInput | ProductOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing Products.
     */
    cursor?: ProductWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Products from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Products.
     */
    skip?: number
    distinct?: ProductScalarFieldEnum | ProductScalarFieldEnum[]
  }


  /**
   * Product create
   */
  export type ProductCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * The data needed to create a Product.
     */
    data: XOR<ProductCreateInput, ProductUncheckedCreateInput>
  }


  /**
   * Product update
   */
  export type ProductUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * The data needed to update a Product.
     */
    data: XOR<ProductUpdateInput, ProductUncheckedUpdateInput>
    /**
     * Choose, which Product to update.
     */
    where: ProductWhereUniqueInput
  }


  /**
   * Product updateMany
   */
  export type ProductUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update Products.
     */
    data: XOR<ProductUpdateManyMutationInput, ProductUncheckedUpdateManyInput>
    /**
     * Filter which Products to update
     */
    where?: ProductWhereInput
  }


  /**
   * Product upsert
   */
  export type ProductUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * The filter to search for the Product to update in case it exists.
     */
    where: ProductWhereUniqueInput
    /**
     * In case the Product found by the `where` argument doesn't exist, create a new Product with this data.
     */
    create: XOR<ProductCreateInput, ProductUncheckedCreateInput>
    /**
     * In case the Product was found with the provided `where` argument, update it with this data.
     */
    update: XOR<ProductUpdateInput, ProductUncheckedUpdateInput>
  }


  /**
   * Product delete
   */
  export type ProductDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    /**
     * Filter which Product to delete.
     */
    where: ProductWhereUniqueInput
  }


  /**
   * Product deleteMany
   */
  export type ProductDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Products to delete
     */
    where?: ProductWhereInput
  }


  /**
   * Product.requiredProducts
   */
  export type Product$requiredProductsArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    where?: ProductWhereInput
    orderBy?: ProductOrderByWithRelationInput | ProductOrderByWithRelationInput[]
    cursor?: ProductWhereUniqueInput
    take?: number
    skip?: number
    distinct?: ProductScalarFieldEnum | ProductScalarFieldEnum[]
  }


  /**
   * Product.requiredByProducts
   */
  export type Product$requiredByProductsArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
    where?: ProductWhereInput
    orderBy?: ProductOrderByWithRelationInput | ProductOrderByWithRelationInput[]
    cursor?: ProductWhereUniqueInput
    take?: number
    skip?: number
    distinct?: ProductScalarFieldEnum | ProductScalarFieldEnum[]
  }


  /**
   * Product without action
   */
  export type ProductDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Product
     */
    select?: ProductSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductInclude<ExtArgs> | null
  }



  /**
   * Model ProductSetting
   */

  export type AggregateProductSetting = {
    _count: ProductSettingCountAggregateOutputType | null
    _avg: ProductSettingAvgAggregateOutputType | null
    _sum: ProductSettingSumAggregateOutputType | null
    _min: ProductSettingMinAggregateOutputType | null
    _max: ProductSettingMaxAggregateOutputType | null
  }

  export type ProductSettingAvgAggregateOutputType = {
    devopsId: number | null
  }

  export type ProductSettingSumAggregateOutputType = {
    devopsId: number | null
  }

  export type ProductSettingMinAggregateOutputType = {
    id: string | null
    devopsId: number | null
    config: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type ProductSettingMaxAggregateOutputType = {
    id: string | null
    devopsId: number | null
    config: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type ProductSettingCountAggregateOutputType = {
    id: number
    devopsId: number
    config: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type ProductSettingAvgAggregateInputType = {
    devopsId?: true
  }

  export type ProductSettingSumAggregateInputType = {
    devopsId?: true
  }

  export type ProductSettingMinAggregateInputType = {
    id?: true
    devopsId?: true
    config?: true
    createdAt?: true
    updatedAt?: true
  }

  export type ProductSettingMaxAggregateInputType = {
    id?: true
    devopsId?: true
    config?: true
    createdAt?: true
    updatedAt?: true
  }

  export type ProductSettingCountAggregateInputType = {
    id?: true
    devopsId?: true
    config?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type ProductSettingAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which ProductSetting to aggregate.
     */
    where?: ProductSettingWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettings to fetch.
     */
    orderBy?: ProductSettingOrderByWithRelationInput | ProductSettingOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: ProductSettingWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettings.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned ProductSettings
    **/
    _count?: true | ProductSettingCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to average
    **/
    _avg?: ProductSettingAvgAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to sum
    **/
    _sum?: ProductSettingSumAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: ProductSettingMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: ProductSettingMaxAggregateInputType
  }

  export type GetProductSettingAggregateType<T extends ProductSettingAggregateArgs> = {
        [P in keyof T & keyof AggregateProductSetting]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateProductSetting[P]>
      : GetScalarType<T[P], AggregateProductSetting[P]>
  }




  export type ProductSettingGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: ProductSettingWhereInput
    orderBy?: ProductSettingOrderByWithAggregationInput | ProductSettingOrderByWithAggregationInput[]
    by: ProductSettingScalarFieldEnum[] | ProductSettingScalarFieldEnum
    having?: ProductSettingScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: ProductSettingCountAggregateInputType | true
    _avg?: ProductSettingAvgAggregateInputType
    _sum?: ProductSettingSumAggregateInputType
    _min?: ProductSettingMinAggregateInputType
    _max?: ProductSettingMaxAggregateInputType
  }

  export type ProductSettingGroupByOutputType = {
    id: string
    devopsId: number
    config: string
    createdAt: Date
    updatedAt: Date
    _count: ProductSettingCountAggregateOutputType | null
    _avg: ProductSettingAvgAggregateOutputType | null
    _sum: ProductSettingSumAggregateOutputType | null
    _min: ProductSettingMinAggregateOutputType | null
    _max: ProductSettingMaxAggregateOutputType | null
  }

  type GetProductSettingGroupByPayload<T extends ProductSettingGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<ProductSettingGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof ProductSettingGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], ProductSettingGroupByOutputType[P]>
            : GetScalarType<T[P], ProductSettingGroupByOutputType[P]>
        }
      >
    >


  export type ProductSettingSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    devopsId?: boolean
    config?: boolean
    createdAt?: boolean
    updatedAt?: boolean
    product?: boolean | ProductDefaultArgs<ExtArgs>
    detail?: boolean | ProductSettingDetailDefaultArgs<ExtArgs>
  }, ExtArgs["result"]["productSetting"]>

  export type ProductSettingSelectScalar = {
    id?: boolean
    devopsId?: boolean
    config?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }

  export type ProductSettingInclude<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    product?: boolean | ProductDefaultArgs<ExtArgs>
    detail?: boolean | ProductSettingDetailDefaultArgs<ExtArgs>
  }


  export type $ProductSettingPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "ProductSetting"
    objects: {
      product: Prisma.$ProductPayload<ExtArgs>
      detail: Prisma.$ProductSettingDetailPayload<ExtArgs> | null
    }
    scalars: $Extensions.GetPayloadResult<{
      id: string
      devopsId: number
      config: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["productSetting"]>
    composites: {}
  }


  type ProductSettingGetPayload<S extends boolean | null | undefined | ProductSettingDefaultArgs> = $Result.GetResult<Prisma.$ProductSettingPayload, S>

  type ProductSettingCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<ProductSettingFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: ProductSettingCountAggregateInputType | true
    }

  export interface ProductSettingDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['ProductSetting'], meta: { name: 'ProductSetting' } }
    /**
     * Find zero or one ProductSetting that matches the filter.
     * @param {ProductSettingFindUniqueArgs} args - Arguments to find a ProductSetting
     * @example
     * // Get one ProductSetting
     * const productSetting = await prisma.productSetting.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends ProductSettingFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingFindUniqueArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one ProductSetting that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {ProductSettingFindUniqueOrThrowArgs} args - Arguments to find a ProductSetting
     * @example
     * // Get one ProductSetting
     * const productSetting = await prisma.productSetting.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends ProductSettingFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first ProductSetting that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingFindFirstArgs} args - Arguments to find a ProductSetting
     * @example
     * // Get one ProductSetting
     * const productSetting = await prisma.productSetting.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends ProductSettingFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingFindFirstArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first ProductSetting that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingFindFirstOrThrowArgs} args - Arguments to find a ProductSetting
     * @example
     * // Get one ProductSetting
     * const productSetting = await prisma.productSetting.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends ProductSettingFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more ProductSettings that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all ProductSettings
     * const productSettings = await prisma.productSetting.findMany()
     * 
     * // Get first 10 ProductSettings
     * const productSettings = await prisma.productSetting.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const productSettingWithIdOnly = await prisma.productSetting.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends ProductSettingFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a ProductSetting.
     * @param {ProductSettingCreateArgs} args - Arguments to create a ProductSetting.
     * @example
     * // Create one ProductSetting
     * const ProductSetting = await prisma.productSetting.create({
     *   data: {
     *     // ... data to create a ProductSetting
     *   }
     * })
     * 
    **/
    create<T extends ProductSettingCreateArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingCreateArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a ProductSetting.
     * @param {ProductSettingDeleteArgs} args - Arguments to delete one ProductSetting.
     * @example
     * // Delete one ProductSetting
     * const ProductSetting = await prisma.productSetting.delete({
     *   where: {
     *     // ... filter to delete one ProductSetting
     *   }
     * })
     * 
    **/
    delete<T extends ProductSettingDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDeleteArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one ProductSetting.
     * @param {ProductSettingUpdateArgs} args - Arguments to update one ProductSetting.
     * @example
     * // Update one ProductSetting
     * const productSetting = await prisma.productSetting.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends ProductSettingUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingUpdateArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more ProductSettings.
     * @param {ProductSettingDeleteManyArgs} args - Arguments to filter ProductSettings to delete.
     * @example
     * // Delete a few ProductSettings
     * const { count } = await prisma.productSetting.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends ProductSettingDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more ProductSettings.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many ProductSettings
     * const productSetting = await prisma.productSetting.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends ProductSettingUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one ProductSetting.
     * @param {ProductSettingUpsertArgs} args - Arguments to update or create a ProductSetting.
     * @example
     * // Update or create a ProductSetting
     * const productSetting = await prisma.productSetting.upsert({
     *   create: {
     *     // ... data to create a ProductSetting
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the ProductSetting we want to update
     *   }
     * })
    **/
    upsert<T extends ProductSettingUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingUpsertArgs<ExtArgs>>
    ): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of ProductSettings.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingCountArgs} args - Arguments to filter ProductSettings to count.
     * @example
     * // Count the number of ProductSettings
     * const count = await prisma.productSetting.count({
     *   where: {
     *     // ... the filter for the ProductSettings we want to count
     *   }
     * })
    **/
    count<T extends ProductSettingCountArgs>(
      args?: Subset<T, ProductSettingCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], ProductSettingCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a ProductSetting.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends ProductSettingAggregateArgs>(args: Subset<T, ProductSettingAggregateArgs>): Prisma.PrismaPromise<GetProductSettingAggregateType<T>>

    /**
     * Group by ProductSetting.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends ProductSettingGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: ProductSettingGroupByArgs['orderBy'] }
        : { orderBy?: ProductSettingGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, ProductSettingGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetProductSettingGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the ProductSetting model
   */
  readonly fields: ProductSettingFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for ProductSetting.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__ProductSettingClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';

    product<T extends ProductDefaultArgs<ExtArgs> = {}>(args?: Subset<T, ProductDefaultArgs<ExtArgs>>): Prisma__ProductClient<$Result.GetResult<Prisma.$ProductPayload<ExtArgs>, T, 'findUniqueOrThrow'> | Null, Null, ExtArgs>;

    detail<T extends ProductSettingDetailDefaultArgs<ExtArgs> = {}>(args?: Subset<T, ProductSettingDetailDefaultArgs<ExtArgs>>): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'findUniqueOrThrow'> | null, null, ExtArgs>;

    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the ProductSetting model
   */ 
  interface ProductSettingFieldRefs {
    readonly id: FieldRef<"ProductSetting", 'String'>
    readonly devopsId: FieldRef<"ProductSetting", 'Int'>
    readonly config: FieldRef<"ProductSetting", 'String'>
    readonly createdAt: FieldRef<"ProductSetting", 'DateTime'>
    readonly updatedAt: FieldRef<"ProductSetting", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * ProductSetting findUnique
   */
  export type ProductSettingFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * Filter, which ProductSetting to fetch.
     */
    where: ProductSettingWhereUniqueInput
  }


  /**
   * ProductSetting findUniqueOrThrow
   */
  export type ProductSettingFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * Filter, which ProductSetting to fetch.
     */
    where: ProductSettingWhereUniqueInput
  }


  /**
   * ProductSetting findFirst
   */
  export type ProductSettingFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * Filter, which ProductSetting to fetch.
     */
    where?: ProductSettingWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettings to fetch.
     */
    orderBy?: ProductSettingOrderByWithRelationInput | ProductSettingOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for ProductSettings.
     */
    cursor?: ProductSettingWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettings.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of ProductSettings.
     */
    distinct?: ProductSettingScalarFieldEnum | ProductSettingScalarFieldEnum[]
  }


  /**
   * ProductSetting findFirstOrThrow
   */
  export type ProductSettingFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * Filter, which ProductSetting to fetch.
     */
    where?: ProductSettingWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettings to fetch.
     */
    orderBy?: ProductSettingOrderByWithRelationInput | ProductSettingOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for ProductSettings.
     */
    cursor?: ProductSettingWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettings.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of ProductSettings.
     */
    distinct?: ProductSettingScalarFieldEnum | ProductSettingScalarFieldEnum[]
  }


  /**
   * ProductSetting findMany
   */
  export type ProductSettingFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * Filter, which ProductSettings to fetch.
     */
    where?: ProductSettingWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettings to fetch.
     */
    orderBy?: ProductSettingOrderByWithRelationInput | ProductSettingOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing ProductSettings.
     */
    cursor?: ProductSettingWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettings.
     */
    skip?: number
    distinct?: ProductSettingScalarFieldEnum | ProductSettingScalarFieldEnum[]
  }


  /**
   * ProductSetting create
   */
  export type ProductSettingCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * The data needed to create a ProductSetting.
     */
    data: XOR<ProductSettingCreateInput, ProductSettingUncheckedCreateInput>
  }


  /**
   * ProductSetting update
   */
  export type ProductSettingUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * The data needed to update a ProductSetting.
     */
    data: XOR<ProductSettingUpdateInput, ProductSettingUncheckedUpdateInput>
    /**
     * Choose, which ProductSetting to update.
     */
    where: ProductSettingWhereUniqueInput
  }


  /**
   * ProductSetting updateMany
   */
  export type ProductSettingUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update ProductSettings.
     */
    data: XOR<ProductSettingUpdateManyMutationInput, ProductSettingUncheckedUpdateManyInput>
    /**
     * Filter which ProductSettings to update
     */
    where?: ProductSettingWhereInput
  }


  /**
   * ProductSetting upsert
   */
  export type ProductSettingUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * The filter to search for the ProductSetting to update in case it exists.
     */
    where: ProductSettingWhereUniqueInput
    /**
     * In case the ProductSetting found by the `where` argument doesn't exist, create a new ProductSetting with this data.
     */
    create: XOR<ProductSettingCreateInput, ProductSettingUncheckedCreateInput>
    /**
     * In case the ProductSetting was found with the provided `where` argument, update it with this data.
     */
    update: XOR<ProductSettingUpdateInput, ProductSettingUncheckedUpdateInput>
  }


  /**
   * ProductSetting delete
   */
  export type ProductSettingDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
    /**
     * Filter which ProductSetting to delete.
     */
    where: ProductSettingWhereUniqueInput
  }


  /**
   * ProductSetting deleteMany
   */
  export type ProductSettingDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which ProductSettings to delete
     */
    where?: ProductSettingWhereInput
  }


  /**
   * ProductSetting without action
   */
  export type ProductSettingDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSetting
     */
    select?: ProductSettingSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingInclude<ExtArgs> | null
  }



  /**
   * Model ProductSettingDetail
   */

  export type AggregateProductSettingDetail = {
    _count: ProductSettingDetailCountAggregateOutputType | null
    _avg: ProductSettingDetailAvgAggregateOutputType | null
    _sum: ProductSettingDetailSumAggregateOutputType | null
    _min: ProductSettingDetailMinAggregateOutputType | null
    _max: ProductSettingDetailMaxAggregateOutputType | null
  }

  export type ProductSettingDetailAvgAggregateOutputType = {
    devopsId: number | null
  }

  export type ProductSettingDetailSumAggregateOutputType = {
    devopsId: number | null
  }

  export type ProductSettingDetailMinAggregateOutputType = {
    id: string | null
    config: string | null
    devopsId: number | null
    productSettingId: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type ProductSettingDetailMaxAggregateOutputType = {
    id: string | null
    config: string | null
    devopsId: number | null
    productSettingId: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type ProductSettingDetailCountAggregateOutputType = {
    id: number
    config: number
    devopsId: number
    productSettingId: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type ProductSettingDetailAvgAggregateInputType = {
    devopsId?: true
  }

  export type ProductSettingDetailSumAggregateInputType = {
    devopsId?: true
  }

  export type ProductSettingDetailMinAggregateInputType = {
    id?: true
    config?: true
    devopsId?: true
    productSettingId?: true
    createdAt?: true
    updatedAt?: true
  }

  export type ProductSettingDetailMaxAggregateInputType = {
    id?: true
    config?: true
    devopsId?: true
    productSettingId?: true
    createdAt?: true
    updatedAt?: true
  }

  export type ProductSettingDetailCountAggregateInputType = {
    id?: true
    config?: true
    devopsId?: true
    productSettingId?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type ProductSettingDetailAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which ProductSettingDetail to aggregate.
     */
    where?: ProductSettingDetailWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettingDetails to fetch.
     */
    orderBy?: ProductSettingDetailOrderByWithRelationInput | ProductSettingDetailOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: ProductSettingDetailWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettingDetails from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettingDetails.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned ProductSettingDetails
    **/
    _count?: true | ProductSettingDetailCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to average
    **/
    _avg?: ProductSettingDetailAvgAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to sum
    **/
    _sum?: ProductSettingDetailSumAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: ProductSettingDetailMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: ProductSettingDetailMaxAggregateInputType
  }

  export type GetProductSettingDetailAggregateType<T extends ProductSettingDetailAggregateArgs> = {
        [P in keyof T & keyof AggregateProductSettingDetail]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateProductSettingDetail[P]>
      : GetScalarType<T[P], AggregateProductSettingDetail[P]>
  }




  export type ProductSettingDetailGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: ProductSettingDetailWhereInput
    orderBy?: ProductSettingDetailOrderByWithAggregationInput | ProductSettingDetailOrderByWithAggregationInput[]
    by: ProductSettingDetailScalarFieldEnum[] | ProductSettingDetailScalarFieldEnum
    having?: ProductSettingDetailScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: ProductSettingDetailCountAggregateInputType | true
    _avg?: ProductSettingDetailAvgAggregateInputType
    _sum?: ProductSettingDetailSumAggregateInputType
    _min?: ProductSettingDetailMinAggregateInputType
    _max?: ProductSettingDetailMaxAggregateInputType
  }

  export type ProductSettingDetailGroupByOutputType = {
    id: string
    config: string
    devopsId: number
    productSettingId: string
    createdAt: Date
    updatedAt: Date
    _count: ProductSettingDetailCountAggregateOutputType | null
    _avg: ProductSettingDetailAvgAggregateOutputType | null
    _sum: ProductSettingDetailSumAggregateOutputType | null
    _min: ProductSettingDetailMinAggregateOutputType | null
    _max: ProductSettingDetailMaxAggregateOutputType | null
  }

  type GetProductSettingDetailGroupByPayload<T extends ProductSettingDetailGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<ProductSettingDetailGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof ProductSettingDetailGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], ProductSettingDetailGroupByOutputType[P]>
            : GetScalarType<T[P], ProductSettingDetailGroupByOutputType[P]>
        }
      >
    >


  export type ProductSettingDetailSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    config?: boolean
    devopsId?: boolean
    productSettingId?: boolean
    createdAt?: boolean
    updatedAt?: boolean
    productSetting?: boolean | ProductSettingDefaultArgs<ExtArgs>
  }, ExtArgs["result"]["productSettingDetail"]>

  export type ProductSettingDetailSelectScalar = {
    id?: boolean
    config?: boolean
    devopsId?: boolean
    productSettingId?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }

  export type ProductSettingDetailInclude<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    productSetting?: boolean | ProductSettingDefaultArgs<ExtArgs>
  }


  export type $ProductSettingDetailPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "ProductSettingDetail"
    objects: {
      productSetting: Prisma.$ProductSettingPayload<ExtArgs>
    }
    scalars: $Extensions.GetPayloadResult<{
      id: string
      config: string
      devopsId: number
      productSettingId: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["productSettingDetail"]>
    composites: {}
  }


  type ProductSettingDetailGetPayload<S extends boolean | null | undefined | ProductSettingDetailDefaultArgs> = $Result.GetResult<Prisma.$ProductSettingDetailPayload, S>

  type ProductSettingDetailCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<ProductSettingDetailFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: ProductSettingDetailCountAggregateInputType | true
    }

  export interface ProductSettingDetailDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['ProductSettingDetail'], meta: { name: 'ProductSettingDetail' } }
    /**
     * Find zero or one ProductSettingDetail that matches the filter.
     * @param {ProductSettingDetailFindUniqueArgs} args - Arguments to find a ProductSettingDetail
     * @example
     * // Get one ProductSettingDetail
     * const productSettingDetail = await prisma.productSettingDetail.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends ProductSettingDetailFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDetailFindUniqueArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one ProductSettingDetail that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {ProductSettingDetailFindUniqueOrThrowArgs} args - Arguments to find a ProductSettingDetail
     * @example
     * // Get one ProductSettingDetail
     * const productSettingDetail = await prisma.productSettingDetail.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends ProductSettingDetailFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingDetailFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first ProductSettingDetail that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailFindFirstArgs} args - Arguments to find a ProductSettingDetail
     * @example
     * // Get one ProductSettingDetail
     * const productSettingDetail = await prisma.productSettingDetail.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends ProductSettingDetailFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingDetailFindFirstArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first ProductSettingDetail that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailFindFirstOrThrowArgs} args - Arguments to find a ProductSettingDetail
     * @example
     * // Get one ProductSettingDetail
     * const productSettingDetail = await prisma.productSettingDetail.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends ProductSettingDetailFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingDetailFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more ProductSettingDetails that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all ProductSettingDetails
     * const productSettingDetails = await prisma.productSettingDetail.findMany()
     * 
     * // Get first 10 ProductSettingDetails
     * const productSettingDetails = await prisma.productSettingDetail.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const productSettingDetailWithIdOnly = await prisma.productSettingDetail.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends ProductSettingDetailFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingDetailFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a ProductSettingDetail.
     * @param {ProductSettingDetailCreateArgs} args - Arguments to create a ProductSettingDetail.
     * @example
     * // Create one ProductSettingDetail
     * const ProductSettingDetail = await prisma.productSettingDetail.create({
     *   data: {
     *     // ... data to create a ProductSettingDetail
     *   }
     * })
     * 
    **/
    create<T extends ProductSettingDetailCreateArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDetailCreateArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a ProductSettingDetail.
     * @param {ProductSettingDetailDeleteArgs} args - Arguments to delete one ProductSettingDetail.
     * @example
     * // Delete one ProductSettingDetail
     * const ProductSettingDetail = await prisma.productSettingDetail.delete({
     *   where: {
     *     // ... filter to delete one ProductSettingDetail
     *   }
     * })
     * 
    **/
    delete<T extends ProductSettingDetailDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDetailDeleteArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one ProductSettingDetail.
     * @param {ProductSettingDetailUpdateArgs} args - Arguments to update one ProductSettingDetail.
     * @example
     * // Update one ProductSettingDetail
     * const productSettingDetail = await prisma.productSettingDetail.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends ProductSettingDetailUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDetailUpdateArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more ProductSettingDetails.
     * @param {ProductSettingDetailDeleteManyArgs} args - Arguments to filter ProductSettingDetails to delete.
     * @example
     * // Delete a few ProductSettingDetails
     * const { count } = await prisma.productSettingDetail.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends ProductSettingDetailDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, ProductSettingDetailDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more ProductSettingDetails.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many ProductSettingDetails
     * const productSettingDetail = await prisma.productSettingDetail.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends ProductSettingDetailUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDetailUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one ProductSettingDetail.
     * @param {ProductSettingDetailUpsertArgs} args - Arguments to update or create a ProductSettingDetail.
     * @example
     * // Update or create a ProductSettingDetail
     * const productSettingDetail = await prisma.productSettingDetail.upsert({
     *   create: {
     *     // ... data to create a ProductSettingDetail
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the ProductSettingDetail we want to update
     *   }
     * })
    **/
    upsert<T extends ProductSettingDetailUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, ProductSettingDetailUpsertArgs<ExtArgs>>
    ): Prisma__ProductSettingDetailClient<$Result.GetResult<Prisma.$ProductSettingDetailPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of ProductSettingDetails.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailCountArgs} args - Arguments to filter ProductSettingDetails to count.
     * @example
     * // Count the number of ProductSettingDetails
     * const count = await prisma.productSettingDetail.count({
     *   where: {
     *     // ... the filter for the ProductSettingDetails we want to count
     *   }
     * })
    **/
    count<T extends ProductSettingDetailCountArgs>(
      args?: Subset<T, ProductSettingDetailCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], ProductSettingDetailCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a ProductSettingDetail.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends ProductSettingDetailAggregateArgs>(args: Subset<T, ProductSettingDetailAggregateArgs>): Prisma.PrismaPromise<GetProductSettingDetailAggregateType<T>>

    /**
     * Group by ProductSettingDetail.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {ProductSettingDetailGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends ProductSettingDetailGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: ProductSettingDetailGroupByArgs['orderBy'] }
        : { orderBy?: ProductSettingDetailGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, ProductSettingDetailGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetProductSettingDetailGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the ProductSettingDetail model
   */
  readonly fields: ProductSettingDetailFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for ProductSettingDetail.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__ProductSettingDetailClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';

    productSetting<T extends ProductSettingDefaultArgs<ExtArgs> = {}>(args?: Subset<T, ProductSettingDefaultArgs<ExtArgs>>): Prisma__ProductSettingClient<$Result.GetResult<Prisma.$ProductSettingPayload<ExtArgs>, T, 'findUniqueOrThrow'> | Null, Null, ExtArgs>;

    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the ProductSettingDetail model
   */ 
  interface ProductSettingDetailFieldRefs {
    readonly id: FieldRef<"ProductSettingDetail", 'String'>
    readonly config: FieldRef<"ProductSettingDetail", 'String'>
    readonly devopsId: FieldRef<"ProductSettingDetail", 'Int'>
    readonly productSettingId: FieldRef<"ProductSettingDetail", 'String'>
    readonly createdAt: FieldRef<"ProductSettingDetail", 'DateTime'>
    readonly updatedAt: FieldRef<"ProductSettingDetail", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * ProductSettingDetail findUnique
   */
  export type ProductSettingDetailFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * Filter, which ProductSettingDetail to fetch.
     */
    where: ProductSettingDetailWhereUniqueInput
  }


  /**
   * ProductSettingDetail findUniqueOrThrow
   */
  export type ProductSettingDetailFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * Filter, which ProductSettingDetail to fetch.
     */
    where: ProductSettingDetailWhereUniqueInput
  }


  /**
   * ProductSettingDetail findFirst
   */
  export type ProductSettingDetailFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * Filter, which ProductSettingDetail to fetch.
     */
    where?: ProductSettingDetailWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettingDetails to fetch.
     */
    orderBy?: ProductSettingDetailOrderByWithRelationInput | ProductSettingDetailOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for ProductSettingDetails.
     */
    cursor?: ProductSettingDetailWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettingDetails from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettingDetails.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of ProductSettingDetails.
     */
    distinct?: ProductSettingDetailScalarFieldEnum | ProductSettingDetailScalarFieldEnum[]
  }


  /**
   * ProductSettingDetail findFirstOrThrow
   */
  export type ProductSettingDetailFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * Filter, which ProductSettingDetail to fetch.
     */
    where?: ProductSettingDetailWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettingDetails to fetch.
     */
    orderBy?: ProductSettingDetailOrderByWithRelationInput | ProductSettingDetailOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for ProductSettingDetails.
     */
    cursor?: ProductSettingDetailWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettingDetails from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettingDetails.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of ProductSettingDetails.
     */
    distinct?: ProductSettingDetailScalarFieldEnum | ProductSettingDetailScalarFieldEnum[]
  }


  /**
   * ProductSettingDetail findMany
   */
  export type ProductSettingDetailFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * Filter, which ProductSettingDetails to fetch.
     */
    where?: ProductSettingDetailWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of ProductSettingDetails to fetch.
     */
    orderBy?: ProductSettingDetailOrderByWithRelationInput | ProductSettingDetailOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing ProductSettingDetails.
     */
    cursor?: ProductSettingDetailWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` ProductSettingDetails from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` ProductSettingDetails.
     */
    skip?: number
    distinct?: ProductSettingDetailScalarFieldEnum | ProductSettingDetailScalarFieldEnum[]
  }


  /**
   * ProductSettingDetail create
   */
  export type ProductSettingDetailCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * The data needed to create a ProductSettingDetail.
     */
    data: XOR<ProductSettingDetailCreateInput, ProductSettingDetailUncheckedCreateInput>
  }


  /**
   * ProductSettingDetail update
   */
  export type ProductSettingDetailUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * The data needed to update a ProductSettingDetail.
     */
    data: XOR<ProductSettingDetailUpdateInput, ProductSettingDetailUncheckedUpdateInput>
    /**
     * Choose, which ProductSettingDetail to update.
     */
    where: ProductSettingDetailWhereUniqueInput
  }


  /**
   * ProductSettingDetail updateMany
   */
  export type ProductSettingDetailUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update ProductSettingDetails.
     */
    data: XOR<ProductSettingDetailUpdateManyMutationInput, ProductSettingDetailUncheckedUpdateManyInput>
    /**
     * Filter which ProductSettingDetails to update
     */
    where?: ProductSettingDetailWhereInput
  }


  /**
   * ProductSettingDetail upsert
   */
  export type ProductSettingDetailUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * The filter to search for the ProductSettingDetail to update in case it exists.
     */
    where: ProductSettingDetailWhereUniqueInput
    /**
     * In case the ProductSettingDetail found by the `where` argument doesn't exist, create a new ProductSettingDetail with this data.
     */
    create: XOR<ProductSettingDetailCreateInput, ProductSettingDetailUncheckedCreateInput>
    /**
     * In case the ProductSettingDetail was found with the provided `where` argument, update it with this data.
     */
    update: XOR<ProductSettingDetailUpdateInput, ProductSettingDetailUncheckedUpdateInput>
  }


  /**
   * ProductSettingDetail delete
   */
  export type ProductSettingDetailDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
    /**
     * Filter which ProductSettingDetail to delete.
     */
    where: ProductSettingDetailWhereUniqueInput
  }


  /**
   * ProductSettingDetail deleteMany
   */
  export type ProductSettingDetailDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which ProductSettingDetails to delete
     */
    where?: ProductSettingDetailWhereInput
  }


  /**
   * ProductSettingDetail without action
   */
  export type ProductSettingDetailDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the ProductSettingDetail
     */
    select?: ProductSettingDetailSelect<ExtArgs> | null
    /**
     * Choose, which related nodes to fetch as well.
     */
    include?: ProductSettingDetailInclude<ExtArgs> | null
  }



  /**
   * Model UpdaterVersion
   */

  export type AggregateUpdaterVersion = {
    _count: UpdaterVersionCountAggregateOutputType | null
    _avg: UpdaterVersionAvgAggregateOutputType | null
    _sum: UpdaterVersionSumAggregateOutputType | null
    _min: UpdaterVersionMinAggregateOutputType | null
    _max: UpdaterVersionMaxAggregateOutputType | null
  }

  export type UpdaterVersionAvgAggregateOutputType = {
    downloads: number | null
  }

  export type UpdaterVersionSumAggregateOutputType = {
    downloads: number | null
  }

  export type UpdaterVersionMinAggregateOutputType = {
    id: string | null
    version: string | null
    approvedVersion: string | null
    downloads: number | null
    isActive: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type UpdaterVersionMaxAggregateOutputType = {
    id: string | null
    version: string | null
    approvedVersion: string | null
    downloads: number | null
    isActive: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type UpdaterVersionCountAggregateOutputType = {
    id: number
    version: number
    approvedVersion: number
    downloads: number
    isActive: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type UpdaterVersionAvgAggregateInputType = {
    downloads?: true
  }

  export type UpdaterVersionSumAggregateInputType = {
    downloads?: true
  }

  export type UpdaterVersionMinAggregateInputType = {
    id?: true
    version?: true
    approvedVersion?: true
    downloads?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
  }

  export type UpdaterVersionMaxAggregateInputType = {
    id?: true
    version?: true
    approvedVersion?: true
    downloads?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
  }

  export type UpdaterVersionCountAggregateInputType = {
    id?: true
    version?: true
    approvedVersion?: true
    downloads?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type UpdaterVersionAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which UpdaterVersion to aggregate.
     */
    where?: UpdaterVersionWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of UpdaterVersions to fetch.
     */
    orderBy?: UpdaterVersionOrderByWithRelationInput | UpdaterVersionOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: UpdaterVersionWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` UpdaterVersions from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` UpdaterVersions.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned UpdaterVersions
    **/
    _count?: true | UpdaterVersionCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to average
    **/
    _avg?: UpdaterVersionAvgAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to sum
    **/
    _sum?: UpdaterVersionSumAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: UpdaterVersionMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: UpdaterVersionMaxAggregateInputType
  }

  export type GetUpdaterVersionAggregateType<T extends UpdaterVersionAggregateArgs> = {
        [P in keyof T & keyof AggregateUpdaterVersion]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateUpdaterVersion[P]>
      : GetScalarType<T[P], AggregateUpdaterVersion[P]>
  }




  export type UpdaterVersionGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: UpdaterVersionWhereInput
    orderBy?: UpdaterVersionOrderByWithAggregationInput | UpdaterVersionOrderByWithAggregationInput[]
    by: UpdaterVersionScalarFieldEnum[] | UpdaterVersionScalarFieldEnum
    having?: UpdaterVersionScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: UpdaterVersionCountAggregateInputType | true
    _avg?: UpdaterVersionAvgAggregateInputType
    _sum?: UpdaterVersionSumAggregateInputType
    _min?: UpdaterVersionMinAggregateInputType
    _max?: UpdaterVersionMaxAggregateInputType
  }

  export type UpdaterVersionGroupByOutputType = {
    id: string
    version: string
    approvedVersion: string
    downloads: number
    isActive: string
    createdAt: Date
    updatedAt: Date
    _count: UpdaterVersionCountAggregateOutputType | null
    _avg: UpdaterVersionAvgAggregateOutputType | null
    _sum: UpdaterVersionSumAggregateOutputType | null
    _min: UpdaterVersionMinAggregateOutputType | null
    _max: UpdaterVersionMaxAggregateOutputType | null
  }

  type GetUpdaterVersionGroupByPayload<T extends UpdaterVersionGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<UpdaterVersionGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof UpdaterVersionGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], UpdaterVersionGroupByOutputType[P]>
            : GetScalarType<T[P], UpdaterVersionGroupByOutputType[P]>
        }
      >
    >


  export type UpdaterVersionSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    version?: boolean
    approvedVersion?: boolean
    downloads?: boolean
    isActive?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }, ExtArgs["result"]["updaterVersion"]>

  export type UpdaterVersionSelectScalar = {
    id?: boolean
    version?: boolean
    approvedVersion?: boolean
    downloads?: boolean
    isActive?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }


  export type $UpdaterVersionPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "UpdaterVersion"
    objects: {}
    scalars: $Extensions.GetPayloadResult<{
      id: string
      version: string
      approvedVersion: string
      downloads: number
      isActive: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["updaterVersion"]>
    composites: {}
  }


  type UpdaterVersionGetPayload<S extends boolean | null | undefined | UpdaterVersionDefaultArgs> = $Result.GetResult<Prisma.$UpdaterVersionPayload, S>

  type UpdaterVersionCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<UpdaterVersionFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: UpdaterVersionCountAggregateInputType | true
    }

  export interface UpdaterVersionDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['UpdaterVersion'], meta: { name: 'UpdaterVersion' } }
    /**
     * Find zero or one UpdaterVersion that matches the filter.
     * @param {UpdaterVersionFindUniqueArgs} args - Arguments to find a UpdaterVersion
     * @example
     * // Get one UpdaterVersion
     * const updaterVersion = await prisma.updaterVersion.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends UpdaterVersionFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, UpdaterVersionFindUniqueArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one UpdaterVersion that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {UpdaterVersionFindUniqueOrThrowArgs} args - Arguments to find a UpdaterVersion
     * @example
     * // Get one UpdaterVersion
     * const updaterVersion = await prisma.updaterVersion.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends UpdaterVersionFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, UpdaterVersionFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first UpdaterVersion that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionFindFirstArgs} args - Arguments to find a UpdaterVersion
     * @example
     * // Get one UpdaterVersion
     * const updaterVersion = await prisma.updaterVersion.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends UpdaterVersionFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, UpdaterVersionFindFirstArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first UpdaterVersion that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionFindFirstOrThrowArgs} args - Arguments to find a UpdaterVersion
     * @example
     * // Get one UpdaterVersion
     * const updaterVersion = await prisma.updaterVersion.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends UpdaterVersionFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, UpdaterVersionFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more UpdaterVersions that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all UpdaterVersions
     * const updaterVersions = await prisma.updaterVersion.findMany()
     * 
     * // Get first 10 UpdaterVersions
     * const updaterVersions = await prisma.updaterVersion.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const updaterVersionWithIdOnly = await prisma.updaterVersion.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends UpdaterVersionFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, UpdaterVersionFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a UpdaterVersion.
     * @param {UpdaterVersionCreateArgs} args - Arguments to create a UpdaterVersion.
     * @example
     * // Create one UpdaterVersion
     * const UpdaterVersion = await prisma.updaterVersion.create({
     *   data: {
     *     // ... data to create a UpdaterVersion
     *   }
     * })
     * 
    **/
    create<T extends UpdaterVersionCreateArgs<ExtArgs>>(
      args: SelectSubset<T, UpdaterVersionCreateArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a UpdaterVersion.
     * @param {UpdaterVersionDeleteArgs} args - Arguments to delete one UpdaterVersion.
     * @example
     * // Delete one UpdaterVersion
     * const UpdaterVersion = await prisma.updaterVersion.delete({
     *   where: {
     *     // ... filter to delete one UpdaterVersion
     *   }
     * })
     * 
    **/
    delete<T extends UpdaterVersionDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, UpdaterVersionDeleteArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one UpdaterVersion.
     * @param {UpdaterVersionUpdateArgs} args - Arguments to update one UpdaterVersion.
     * @example
     * // Update one UpdaterVersion
     * const updaterVersion = await prisma.updaterVersion.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends UpdaterVersionUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, UpdaterVersionUpdateArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more UpdaterVersions.
     * @param {UpdaterVersionDeleteManyArgs} args - Arguments to filter UpdaterVersions to delete.
     * @example
     * // Delete a few UpdaterVersions
     * const { count } = await prisma.updaterVersion.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends UpdaterVersionDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, UpdaterVersionDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more UpdaterVersions.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many UpdaterVersions
     * const updaterVersion = await prisma.updaterVersion.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends UpdaterVersionUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, UpdaterVersionUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one UpdaterVersion.
     * @param {UpdaterVersionUpsertArgs} args - Arguments to update or create a UpdaterVersion.
     * @example
     * // Update or create a UpdaterVersion
     * const updaterVersion = await prisma.updaterVersion.upsert({
     *   create: {
     *     // ... data to create a UpdaterVersion
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the UpdaterVersion we want to update
     *   }
     * })
    **/
    upsert<T extends UpdaterVersionUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, UpdaterVersionUpsertArgs<ExtArgs>>
    ): Prisma__UpdaterVersionClient<$Result.GetResult<Prisma.$UpdaterVersionPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of UpdaterVersions.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionCountArgs} args - Arguments to filter UpdaterVersions to count.
     * @example
     * // Count the number of UpdaterVersions
     * const count = await prisma.updaterVersion.count({
     *   where: {
     *     // ... the filter for the UpdaterVersions we want to count
     *   }
     * })
    **/
    count<T extends UpdaterVersionCountArgs>(
      args?: Subset<T, UpdaterVersionCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], UpdaterVersionCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a UpdaterVersion.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends UpdaterVersionAggregateArgs>(args: Subset<T, UpdaterVersionAggregateArgs>): Prisma.PrismaPromise<GetUpdaterVersionAggregateType<T>>

    /**
     * Group by UpdaterVersion.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {UpdaterVersionGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends UpdaterVersionGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: UpdaterVersionGroupByArgs['orderBy'] }
        : { orderBy?: UpdaterVersionGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, UpdaterVersionGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetUpdaterVersionGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the UpdaterVersion model
   */
  readonly fields: UpdaterVersionFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for UpdaterVersion.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__UpdaterVersionClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';


    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the UpdaterVersion model
   */ 
  interface UpdaterVersionFieldRefs {
    readonly id: FieldRef<"UpdaterVersion", 'String'>
    readonly version: FieldRef<"UpdaterVersion", 'String'>
    readonly approvedVersion: FieldRef<"UpdaterVersion", 'String'>
    readonly downloads: FieldRef<"UpdaterVersion", 'Int'>
    readonly isActive: FieldRef<"UpdaterVersion", 'String'>
    readonly createdAt: FieldRef<"UpdaterVersion", 'DateTime'>
    readonly updatedAt: FieldRef<"UpdaterVersion", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * UpdaterVersion findUnique
   */
  export type UpdaterVersionFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * Filter, which UpdaterVersion to fetch.
     */
    where: UpdaterVersionWhereUniqueInput
  }


  /**
   * UpdaterVersion findUniqueOrThrow
   */
  export type UpdaterVersionFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * Filter, which UpdaterVersion to fetch.
     */
    where: UpdaterVersionWhereUniqueInput
  }


  /**
   * UpdaterVersion findFirst
   */
  export type UpdaterVersionFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * Filter, which UpdaterVersion to fetch.
     */
    where?: UpdaterVersionWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of UpdaterVersions to fetch.
     */
    orderBy?: UpdaterVersionOrderByWithRelationInput | UpdaterVersionOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for UpdaterVersions.
     */
    cursor?: UpdaterVersionWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` UpdaterVersions from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` UpdaterVersions.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of UpdaterVersions.
     */
    distinct?: UpdaterVersionScalarFieldEnum | UpdaterVersionScalarFieldEnum[]
  }


  /**
   * UpdaterVersion findFirstOrThrow
   */
  export type UpdaterVersionFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * Filter, which UpdaterVersion to fetch.
     */
    where?: UpdaterVersionWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of UpdaterVersions to fetch.
     */
    orderBy?: UpdaterVersionOrderByWithRelationInput | UpdaterVersionOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for UpdaterVersions.
     */
    cursor?: UpdaterVersionWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` UpdaterVersions from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` UpdaterVersions.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of UpdaterVersions.
     */
    distinct?: UpdaterVersionScalarFieldEnum | UpdaterVersionScalarFieldEnum[]
  }


  /**
   * UpdaterVersion findMany
   */
  export type UpdaterVersionFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * Filter, which UpdaterVersions to fetch.
     */
    where?: UpdaterVersionWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of UpdaterVersions to fetch.
     */
    orderBy?: UpdaterVersionOrderByWithRelationInput | UpdaterVersionOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing UpdaterVersions.
     */
    cursor?: UpdaterVersionWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` UpdaterVersions from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` UpdaterVersions.
     */
    skip?: number
    distinct?: UpdaterVersionScalarFieldEnum | UpdaterVersionScalarFieldEnum[]
  }


  /**
   * UpdaterVersion create
   */
  export type UpdaterVersionCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * The data needed to create a UpdaterVersion.
     */
    data: XOR<UpdaterVersionCreateInput, UpdaterVersionUncheckedCreateInput>
  }


  /**
   * UpdaterVersion update
   */
  export type UpdaterVersionUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * The data needed to update a UpdaterVersion.
     */
    data: XOR<UpdaterVersionUpdateInput, UpdaterVersionUncheckedUpdateInput>
    /**
     * Choose, which UpdaterVersion to update.
     */
    where: UpdaterVersionWhereUniqueInput
  }


  /**
   * UpdaterVersion updateMany
   */
  export type UpdaterVersionUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update UpdaterVersions.
     */
    data: XOR<UpdaterVersionUpdateManyMutationInput, UpdaterVersionUncheckedUpdateManyInput>
    /**
     * Filter which UpdaterVersions to update
     */
    where?: UpdaterVersionWhereInput
  }


  /**
   * UpdaterVersion upsert
   */
  export type UpdaterVersionUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * The filter to search for the UpdaterVersion to update in case it exists.
     */
    where: UpdaterVersionWhereUniqueInput
    /**
     * In case the UpdaterVersion found by the `where` argument doesn't exist, create a new UpdaterVersion with this data.
     */
    create: XOR<UpdaterVersionCreateInput, UpdaterVersionUncheckedCreateInput>
    /**
     * In case the UpdaterVersion was found with the provided `where` argument, update it with this data.
     */
    update: XOR<UpdaterVersionUpdateInput, UpdaterVersionUncheckedUpdateInput>
  }


  /**
   * UpdaterVersion delete
   */
  export type UpdaterVersionDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
    /**
     * Filter which UpdaterVersion to delete.
     */
    where: UpdaterVersionWhereUniqueInput
  }


  /**
   * UpdaterVersion deleteMany
   */
  export type UpdaterVersionDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which UpdaterVersions to delete
     */
    where?: UpdaterVersionWhereInput
  }


  /**
   * UpdaterVersion without action
   */
  export type UpdaterVersionDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the UpdaterVersion
     */
    select?: UpdaterVersionSelect<ExtArgs> | null
  }



  /**
   * Model Customer
   */

  export type AggregateCustomer = {
    _count: CustomerCountAggregateOutputType | null
    _min: CustomerMinAggregateOutputType | null
    _max: CustomerMaxAggregateOutputType | null
  }

  export type CustomerMinAggregateOutputType = {
    id: string | null
    name: string | null
    assistantUrl: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type CustomerMaxAggregateOutputType = {
    id: string | null
    name: string | null
    assistantUrl: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type CustomerCountAggregateOutputType = {
    id: number
    name: number
    assistantUrl: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type CustomerMinAggregateInputType = {
    id?: true
    name?: true
    assistantUrl?: true
    createdAt?: true
    updatedAt?: true
  }

  export type CustomerMaxAggregateInputType = {
    id?: true
    name?: true
    assistantUrl?: true
    createdAt?: true
    updatedAt?: true
  }

  export type CustomerCountAggregateInputType = {
    id?: true
    name?: true
    assistantUrl?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type CustomerAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Customer to aggregate.
     */
    where?: CustomerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Customers to fetch.
     */
    orderBy?: CustomerOrderByWithRelationInput | CustomerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: CustomerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Customers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Customers.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned Customers
    **/
    _count?: true | CustomerCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: CustomerMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: CustomerMaxAggregateInputType
  }

  export type GetCustomerAggregateType<T extends CustomerAggregateArgs> = {
        [P in keyof T & keyof AggregateCustomer]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateCustomer[P]>
      : GetScalarType<T[P], AggregateCustomer[P]>
  }




  export type CustomerGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: CustomerWhereInput
    orderBy?: CustomerOrderByWithAggregationInput | CustomerOrderByWithAggregationInput[]
    by: CustomerScalarFieldEnum[] | CustomerScalarFieldEnum
    having?: CustomerScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: CustomerCountAggregateInputType | true
    _min?: CustomerMinAggregateInputType
    _max?: CustomerMaxAggregateInputType
  }

  export type CustomerGroupByOutputType = {
    id: string
    name: string
    assistantUrl: string
    createdAt: Date
    updatedAt: Date
    _count: CustomerCountAggregateOutputType | null
    _min: CustomerMinAggregateOutputType | null
    _max: CustomerMaxAggregateOutputType | null
  }

  type GetCustomerGroupByPayload<T extends CustomerGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<CustomerGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof CustomerGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], CustomerGroupByOutputType[P]>
            : GetScalarType<T[P], CustomerGroupByOutputType[P]>
        }
      >
    >


  export type CustomerSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    name?: boolean
    assistantUrl?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }, ExtArgs["result"]["customer"]>

  export type CustomerSelectScalar = {
    id?: boolean
    name?: boolean
    assistantUrl?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }


  export type $CustomerPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "Customer"
    objects: {}
    scalars: $Extensions.GetPayloadResult<{
      id: string
      name: string
      assistantUrl: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["customer"]>
    composites: {}
  }


  type CustomerGetPayload<S extends boolean | null | undefined | CustomerDefaultArgs> = $Result.GetResult<Prisma.$CustomerPayload, S>

  type CustomerCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<CustomerFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: CustomerCountAggregateInputType | true
    }

  export interface CustomerDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['Customer'], meta: { name: 'Customer' } }
    /**
     * Find zero or one Customer that matches the filter.
     * @param {CustomerFindUniqueArgs} args - Arguments to find a Customer
     * @example
     * // Get one Customer
     * const customer = await prisma.customer.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends CustomerFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, CustomerFindUniqueArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one Customer that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {CustomerFindUniqueOrThrowArgs} args - Arguments to find a Customer
     * @example
     * // Get one Customer
     * const customer = await prisma.customer.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends CustomerFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, CustomerFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first Customer that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerFindFirstArgs} args - Arguments to find a Customer
     * @example
     * // Get one Customer
     * const customer = await prisma.customer.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends CustomerFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, CustomerFindFirstArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first Customer that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerFindFirstOrThrowArgs} args - Arguments to find a Customer
     * @example
     * // Get one Customer
     * const customer = await prisma.customer.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends CustomerFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, CustomerFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more Customers that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all Customers
     * const customers = await prisma.customer.findMany()
     * 
     * // Get first 10 Customers
     * const customers = await prisma.customer.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const customerWithIdOnly = await prisma.customer.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends CustomerFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, CustomerFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a Customer.
     * @param {CustomerCreateArgs} args - Arguments to create a Customer.
     * @example
     * // Create one Customer
     * const Customer = await prisma.customer.create({
     *   data: {
     *     // ... data to create a Customer
     *   }
     * })
     * 
    **/
    create<T extends CustomerCreateArgs<ExtArgs>>(
      args: SelectSubset<T, CustomerCreateArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a Customer.
     * @param {CustomerDeleteArgs} args - Arguments to delete one Customer.
     * @example
     * // Delete one Customer
     * const Customer = await prisma.customer.delete({
     *   where: {
     *     // ... filter to delete one Customer
     *   }
     * })
     * 
    **/
    delete<T extends CustomerDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, CustomerDeleteArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one Customer.
     * @param {CustomerUpdateArgs} args - Arguments to update one Customer.
     * @example
     * // Update one Customer
     * const customer = await prisma.customer.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends CustomerUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, CustomerUpdateArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more Customers.
     * @param {CustomerDeleteManyArgs} args - Arguments to filter Customers to delete.
     * @example
     * // Delete a few Customers
     * const { count } = await prisma.customer.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends CustomerDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, CustomerDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more Customers.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many Customers
     * const customer = await prisma.customer.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends CustomerUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, CustomerUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one Customer.
     * @param {CustomerUpsertArgs} args - Arguments to update or create a Customer.
     * @example
     * // Update or create a Customer
     * const customer = await prisma.customer.upsert({
     *   create: {
     *     // ... data to create a Customer
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the Customer we want to update
     *   }
     * })
    **/
    upsert<T extends CustomerUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, CustomerUpsertArgs<ExtArgs>>
    ): Prisma__CustomerClient<$Result.GetResult<Prisma.$CustomerPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of Customers.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerCountArgs} args - Arguments to filter Customers to count.
     * @example
     * // Count the number of Customers
     * const count = await prisma.customer.count({
     *   where: {
     *     // ... the filter for the Customers we want to count
     *   }
     * })
    **/
    count<T extends CustomerCountArgs>(
      args?: Subset<T, CustomerCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], CustomerCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a Customer.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends CustomerAggregateArgs>(args: Subset<T, CustomerAggregateArgs>): Prisma.PrismaPromise<GetCustomerAggregateType<T>>

    /**
     * Group by Customer.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {CustomerGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends CustomerGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: CustomerGroupByArgs['orderBy'] }
        : { orderBy?: CustomerGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, CustomerGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetCustomerGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the Customer model
   */
  readonly fields: CustomerFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for Customer.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__CustomerClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';


    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the Customer model
   */ 
  interface CustomerFieldRefs {
    readonly id: FieldRef<"Customer", 'String'>
    readonly name: FieldRef<"Customer", 'String'>
    readonly assistantUrl: FieldRef<"Customer", 'String'>
    readonly createdAt: FieldRef<"Customer", 'DateTime'>
    readonly updatedAt: FieldRef<"Customer", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * Customer findUnique
   */
  export type CustomerFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * Filter, which Customer to fetch.
     */
    where: CustomerWhereUniqueInput
  }


  /**
   * Customer findUniqueOrThrow
   */
  export type CustomerFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * Filter, which Customer to fetch.
     */
    where: CustomerWhereUniqueInput
  }


  /**
   * Customer findFirst
   */
  export type CustomerFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * Filter, which Customer to fetch.
     */
    where?: CustomerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Customers to fetch.
     */
    orderBy?: CustomerOrderByWithRelationInput | CustomerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Customers.
     */
    cursor?: CustomerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Customers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Customers.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Customers.
     */
    distinct?: CustomerScalarFieldEnum | CustomerScalarFieldEnum[]
  }


  /**
   * Customer findFirstOrThrow
   */
  export type CustomerFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * Filter, which Customer to fetch.
     */
    where?: CustomerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Customers to fetch.
     */
    orderBy?: CustomerOrderByWithRelationInput | CustomerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Customers.
     */
    cursor?: CustomerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Customers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Customers.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Customers.
     */
    distinct?: CustomerScalarFieldEnum | CustomerScalarFieldEnum[]
  }


  /**
   * Customer findMany
   */
  export type CustomerFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * Filter, which Customers to fetch.
     */
    where?: CustomerWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Customers to fetch.
     */
    orderBy?: CustomerOrderByWithRelationInput | CustomerOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing Customers.
     */
    cursor?: CustomerWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Customers from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Customers.
     */
    skip?: number
    distinct?: CustomerScalarFieldEnum | CustomerScalarFieldEnum[]
  }


  /**
   * Customer create
   */
  export type CustomerCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * The data needed to create a Customer.
     */
    data: XOR<CustomerCreateInput, CustomerUncheckedCreateInput>
  }


  /**
   * Customer update
   */
  export type CustomerUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * The data needed to update a Customer.
     */
    data: XOR<CustomerUpdateInput, CustomerUncheckedUpdateInput>
    /**
     * Choose, which Customer to update.
     */
    where: CustomerWhereUniqueInput
  }


  /**
   * Customer updateMany
   */
  export type CustomerUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update Customers.
     */
    data: XOR<CustomerUpdateManyMutationInput, CustomerUncheckedUpdateManyInput>
    /**
     * Filter which Customers to update
     */
    where?: CustomerWhereInput
  }


  /**
   * Customer upsert
   */
  export type CustomerUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * The filter to search for the Customer to update in case it exists.
     */
    where: CustomerWhereUniqueInput
    /**
     * In case the Customer found by the `where` argument doesn't exist, create a new Customer with this data.
     */
    create: XOR<CustomerCreateInput, CustomerUncheckedCreateInput>
    /**
     * In case the Customer was found with the provided `where` argument, update it with this data.
     */
    update: XOR<CustomerUpdateInput, CustomerUncheckedUpdateInput>
  }


  /**
   * Customer delete
   */
  export type CustomerDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
    /**
     * Filter which Customer to delete.
     */
    where: CustomerWhereUniqueInput
  }


  /**
   * Customer deleteMany
   */
  export type CustomerDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Customers to delete
     */
    where?: CustomerWhereInput
  }


  /**
   * Customer without action
   */
  export type CustomerDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Customer
     */
    select?: CustomerSelect<ExtArgs> | null
  }



  /**
   * Model AssistantMonitoring
   */

  export type AggregateAssistantMonitoring = {
    _count: AssistantMonitoringCountAggregateOutputType | null
    _avg: AssistantMonitoringAvgAggregateOutputType | null
    _sum: AssistantMonitoringSumAggregateOutputType | null
    _min: AssistantMonitoringMinAggregateOutputType | null
    _max: AssistantMonitoringMaxAggregateOutputType | null
  }

  export type AssistantMonitoringAvgAggregateOutputType = {
    interval: number | null
  }

  export type AssistantMonitoringSumAggregateOutputType = {
    interval: number | null
  }

  export type AssistantMonitoringMinAggregateOutputType = {
    id: string | null
    monitoringId: string | null
    name: string | null
    content: string | null
    description: string | null
    interval: number | null
    isActive: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type AssistantMonitoringMaxAggregateOutputType = {
    id: string | null
    monitoringId: string | null
    name: string | null
    content: string | null
    description: string | null
    interval: number | null
    isActive: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type AssistantMonitoringCountAggregateOutputType = {
    id: number
    monitoringId: number
    name: number
    content: number
    description: number
    interval: number
    isActive: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type AssistantMonitoringAvgAggregateInputType = {
    interval?: true
  }

  export type AssistantMonitoringSumAggregateInputType = {
    interval?: true
  }

  export type AssistantMonitoringMinAggregateInputType = {
    id?: true
    monitoringId?: true
    name?: true
    content?: true
    description?: true
    interval?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
  }

  export type AssistantMonitoringMaxAggregateInputType = {
    id?: true
    monitoringId?: true
    name?: true
    content?: true
    description?: true
    interval?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
  }

  export type AssistantMonitoringCountAggregateInputType = {
    id?: true
    monitoringId?: true
    name?: true
    content?: true
    description?: true
    interval?: true
    isActive?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type AssistantMonitoringAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which AssistantMonitoring to aggregate.
     */
    where?: AssistantMonitoringWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of AssistantMonitorings to fetch.
     */
    orderBy?: AssistantMonitoringOrderByWithRelationInput | AssistantMonitoringOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: AssistantMonitoringWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` AssistantMonitorings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` AssistantMonitorings.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned AssistantMonitorings
    **/
    _count?: true | AssistantMonitoringCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to average
    **/
    _avg?: AssistantMonitoringAvgAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to sum
    **/
    _sum?: AssistantMonitoringSumAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: AssistantMonitoringMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: AssistantMonitoringMaxAggregateInputType
  }

  export type GetAssistantMonitoringAggregateType<T extends AssistantMonitoringAggregateArgs> = {
        [P in keyof T & keyof AggregateAssistantMonitoring]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateAssistantMonitoring[P]>
      : GetScalarType<T[P], AggregateAssistantMonitoring[P]>
  }




  export type AssistantMonitoringGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: AssistantMonitoringWhereInput
    orderBy?: AssistantMonitoringOrderByWithAggregationInput | AssistantMonitoringOrderByWithAggregationInput[]
    by: AssistantMonitoringScalarFieldEnum[] | AssistantMonitoringScalarFieldEnum
    having?: AssistantMonitoringScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: AssistantMonitoringCountAggregateInputType | true
    _avg?: AssistantMonitoringAvgAggregateInputType
    _sum?: AssistantMonitoringSumAggregateInputType
    _min?: AssistantMonitoringMinAggregateInputType
    _max?: AssistantMonitoringMaxAggregateInputType
  }

  export type AssistantMonitoringGroupByOutputType = {
    id: string
    monitoringId: string
    name: string
    content: string
    description: string
    interval: number
    isActive: string
    createdAt: Date
    updatedAt: Date
    _count: AssistantMonitoringCountAggregateOutputType | null
    _avg: AssistantMonitoringAvgAggregateOutputType | null
    _sum: AssistantMonitoringSumAggregateOutputType | null
    _min: AssistantMonitoringMinAggregateOutputType | null
    _max: AssistantMonitoringMaxAggregateOutputType | null
  }

  type GetAssistantMonitoringGroupByPayload<T extends AssistantMonitoringGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<AssistantMonitoringGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof AssistantMonitoringGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], AssistantMonitoringGroupByOutputType[P]>
            : GetScalarType<T[P], AssistantMonitoringGroupByOutputType[P]>
        }
      >
    >


  export type AssistantMonitoringSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    monitoringId?: boolean
    name?: boolean
    content?: boolean
    description?: boolean
    interval?: boolean
    isActive?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }, ExtArgs["result"]["assistantMonitoring"]>

  export type AssistantMonitoringSelectScalar = {
    id?: boolean
    monitoringId?: boolean
    name?: boolean
    content?: boolean
    description?: boolean
    interval?: boolean
    isActive?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }


  export type $AssistantMonitoringPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "AssistantMonitoring"
    objects: {}
    scalars: $Extensions.GetPayloadResult<{
      id: string
      monitoringId: string
      name: string
      content: string
      description: string
      interval: number
      isActive: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["assistantMonitoring"]>
    composites: {}
  }


  type AssistantMonitoringGetPayload<S extends boolean | null | undefined | AssistantMonitoringDefaultArgs> = $Result.GetResult<Prisma.$AssistantMonitoringPayload, S>

  type AssistantMonitoringCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<AssistantMonitoringFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: AssistantMonitoringCountAggregateInputType | true
    }

  export interface AssistantMonitoringDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['AssistantMonitoring'], meta: { name: 'AssistantMonitoring' } }
    /**
     * Find zero or one AssistantMonitoring that matches the filter.
     * @param {AssistantMonitoringFindUniqueArgs} args - Arguments to find a AssistantMonitoring
     * @example
     * // Get one AssistantMonitoring
     * const assistantMonitoring = await prisma.assistantMonitoring.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends AssistantMonitoringFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, AssistantMonitoringFindUniqueArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one AssistantMonitoring that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {AssistantMonitoringFindUniqueOrThrowArgs} args - Arguments to find a AssistantMonitoring
     * @example
     * // Get one AssistantMonitoring
     * const assistantMonitoring = await prisma.assistantMonitoring.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends AssistantMonitoringFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, AssistantMonitoringFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first AssistantMonitoring that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringFindFirstArgs} args - Arguments to find a AssistantMonitoring
     * @example
     * // Get one AssistantMonitoring
     * const assistantMonitoring = await prisma.assistantMonitoring.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends AssistantMonitoringFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, AssistantMonitoringFindFirstArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first AssistantMonitoring that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringFindFirstOrThrowArgs} args - Arguments to find a AssistantMonitoring
     * @example
     * // Get one AssistantMonitoring
     * const assistantMonitoring = await prisma.assistantMonitoring.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends AssistantMonitoringFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, AssistantMonitoringFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more AssistantMonitorings that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all AssistantMonitorings
     * const assistantMonitorings = await prisma.assistantMonitoring.findMany()
     * 
     * // Get first 10 AssistantMonitorings
     * const assistantMonitorings = await prisma.assistantMonitoring.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const assistantMonitoringWithIdOnly = await prisma.assistantMonitoring.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends AssistantMonitoringFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, AssistantMonitoringFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a AssistantMonitoring.
     * @param {AssistantMonitoringCreateArgs} args - Arguments to create a AssistantMonitoring.
     * @example
     * // Create one AssistantMonitoring
     * const AssistantMonitoring = await prisma.assistantMonitoring.create({
     *   data: {
     *     // ... data to create a AssistantMonitoring
     *   }
     * })
     * 
    **/
    create<T extends AssistantMonitoringCreateArgs<ExtArgs>>(
      args: SelectSubset<T, AssistantMonitoringCreateArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a AssistantMonitoring.
     * @param {AssistantMonitoringDeleteArgs} args - Arguments to delete one AssistantMonitoring.
     * @example
     * // Delete one AssistantMonitoring
     * const AssistantMonitoring = await prisma.assistantMonitoring.delete({
     *   where: {
     *     // ... filter to delete one AssistantMonitoring
     *   }
     * })
     * 
    **/
    delete<T extends AssistantMonitoringDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, AssistantMonitoringDeleteArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one AssistantMonitoring.
     * @param {AssistantMonitoringUpdateArgs} args - Arguments to update one AssistantMonitoring.
     * @example
     * // Update one AssistantMonitoring
     * const assistantMonitoring = await prisma.assistantMonitoring.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends AssistantMonitoringUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, AssistantMonitoringUpdateArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more AssistantMonitorings.
     * @param {AssistantMonitoringDeleteManyArgs} args - Arguments to filter AssistantMonitorings to delete.
     * @example
     * // Delete a few AssistantMonitorings
     * const { count } = await prisma.assistantMonitoring.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends AssistantMonitoringDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, AssistantMonitoringDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more AssistantMonitorings.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many AssistantMonitorings
     * const assistantMonitoring = await prisma.assistantMonitoring.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends AssistantMonitoringUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, AssistantMonitoringUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one AssistantMonitoring.
     * @param {AssistantMonitoringUpsertArgs} args - Arguments to update or create a AssistantMonitoring.
     * @example
     * // Update or create a AssistantMonitoring
     * const assistantMonitoring = await prisma.assistantMonitoring.upsert({
     *   create: {
     *     // ... data to create a AssistantMonitoring
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the AssistantMonitoring we want to update
     *   }
     * })
    **/
    upsert<T extends AssistantMonitoringUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, AssistantMonitoringUpsertArgs<ExtArgs>>
    ): Prisma__AssistantMonitoringClient<$Result.GetResult<Prisma.$AssistantMonitoringPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of AssistantMonitorings.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringCountArgs} args - Arguments to filter AssistantMonitorings to count.
     * @example
     * // Count the number of AssistantMonitorings
     * const count = await prisma.assistantMonitoring.count({
     *   where: {
     *     // ... the filter for the AssistantMonitorings we want to count
     *   }
     * })
    **/
    count<T extends AssistantMonitoringCountArgs>(
      args?: Subset<T, AssistantMonitoringCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], AssistantMonitoringCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a AssistantMonitoring.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends AssistantMonitoringAggregateArgs>(args: Subset<T, AssistantMonitoringAggregateArgs>): Prisma.PrismaPromise<GetAssistantMonitoringAggregateType<T>>

    /**
     * Group by AssistantMonitoring.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {AssistantMonitoringGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends AssistantMonitoringGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: AssistantMonitoringGroupByArgs['orderBy'] }
        : { orderBy?: AssistantMonitoringGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, AssistantMonitoringGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetAssistantMonitoringGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the AssistantMonitoring model
   */
  readonly fields: AssistantMonitoringFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for AssistantMonitoring.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__AssistantMonitoringClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';


    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the AssistantMonitoring model
   */ 
  interface AssistantMonitoringFieldRefs {
    readonly id: FieldRef<"AssistantMonitoring", 'String'>
    readonly monitoringId: FieldRef<"AssistantMonitoring", 'String'>
    readonly name: FieldRef<"AssistantMonitoring", 'String'>
    readonly content: FieldRef<"AssistantMonitoring", 'String'>
    readonly description: FieldRef<"AssistantMonitoring", 'String'>
    readonly interval: FieldRef<"AssistantMonitoring", 'Int'>
    readonly isActive: FieldRef<"AssistantMonitoring", 'String'>
    readonly createdAt: FieldRef<"AssistantMonitoring", 'DateTime'>
    readonly updatedAt: FieldRef<"AssistantMonitoring", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * AssistantMonitoring findUnique
   */
  export type AssistantMonitoringFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * Filter, which AssistantMonitoring to fetch.
     */
    where: AssistantMonitoringWhereUniqueInput
  }


  /**
   * AssistantMonitoring findUniqueOrThrow
   */
  export type AssistantMonitoringFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * Filter, which AssistantMonitoring to fetch.
     */
    where: AssistantMonitoringWhereUniqueInput
  }


  /**
   * AssistantMonitoring findFirst
   */
  export type AssistantMonitoringFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * Filter, which AssistantMonitoring to fetch.
     */
    where?: AssistantMonitoringWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of AssistantMonitorings to fetch.
     */
    orderBy?: AssistantMonitoringOrderByWithRelationInput | AssistantMonitoringOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for AssistantMonitorings.
     */
    cursor?: AssistantMonitoringWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` AssistantMonitorings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` AssistantMonitorings.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of AssistantMonitorings.
     */
    distinct?: AssistantMonitoringScalarFieldEnum | AssistantMonitoringScalarFieldEnum[]
  }


  /**
   * AssistantMonitoring findFirstOrThrow
   */
  export type AssistantMonitoringFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * Filter, which AssistantMonitoring to fetch.
     */
    where?: AssistantMonitoringWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of AssistantMonitorings to fetch.
     */
    orderBy?: AssistantMonitoringOrderByWithRelationInput | AssistantMonitoringOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for AssistantMonitorings.
     */
    cursor?: AssistantMonitoringWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` AssistantMonitorings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` AssistantMonitorings.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of AssistantMonitorings.
     */
    distinct?: AssistantMonitoringScalarFieldEnum | AssistantMonitoringScalarFieldEnum[]
  }


  /**
   * AssistantMonitoring findMany
   */
  export type AssistantMonitoringFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * Filter, which AssistantMonitorings to fetch.
     */
    where?: AssistantMonitoringWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of AssistantMonitorings to fetch.
     */
    orderBy?: AssistantMonitoringOrderByWithRelationInput | AssistantMonitoringOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing AssistantMonitorings.
     */
    cursor?: AssistantMonitoringWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` AssistantMonitorings from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` AssistantMonitorings.
     */
    skip?: number
    distinct?: AssistantMonitoringScalarFieldEnum | AssistantMonitoringScalarFieldEnum[]
  }


  /**
   * AssistantMonitoring create
   */
  export type AssistantMonitoringCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * The data needed to create a AssistantMonitoring.
     */
    data: XOR<AssistantMonitoringCreateInput, AssistantMonitoringUncheckedCreateInput>
  }


  /**
   * AssistantMonitoring update
   */
  export type AssistantMonitoringUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * The data needed to update a AssistantMonitoring.
     */
    data: XOR<AssistantMonitoringUpdateInput, AssistantMonitoringUncheckedUpdateInput>
    /**
     * Choose, which AssistantMonitoring to update.
     */
    where: AssistantMonitoringWhereUniqueInput
  }


  /**
   * AssistantMonitoring updateMany
   */
  export type AssistantMonitoringUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update AssistantMonitorings.
     */
    data: XOR<AssistantMonitoringUpdateManyMutationInput, AssistantMonitoringUncheckedUpdateManyInput>
    /**
     * Filter which AssistantMonitorings to update
     */
    where?: AssistantMonitoringWhereInput
  }


  /**
   * AssistantMonitoring upsert
   */
  export type AssistantMonitoringUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * The filter to search for the AssistantMonitoring to update in case it exists.
     */
    where: AssistantMonitoringWhereUniqueInput
    /**
     * In case the AssistantMonitoring found by the `where` argument doesn't exist, create a new AssistantMonitoring with this data.
     */
    create: XOR<AssistantMonitoringCreateInput, AssistantMonitoringUncheckedCreateInput>
    /**
     * In case the AssistantMonitoring was found with the provided `where` argument, update it with this data.
     */
    update: XOR<AssistantMonitoringUpdateInput, AssistantMonitoringUncheckedUpdateInput>
  }


  /**
   * AssistantMonitoring delete
   */
  export type AssistantMonitoringDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
    /**
     * Filter which AssistantMonitoring to delete.
     */
    where: AssistantMonitoringWhereUniqueInput
  }


  /**
   * AssistantMonitoring deleteMany
   */
  export type AssistantMonitoringDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which AssistantMonitorings to delete
     */
    where?: AssistantMonitoringWhereInput
  }


  /**
   * AssistantMonitoring without action
   */
  export type AssistantMonitoringDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the AssistantMonitoring
     */
    select?: AssistantMonitoringSelect<ExtArgs> | null
  }



  /**
   * Model Notification
   */

  export type AggregateNotification = {
    _count: NotificationCountAggregateOutputType | null
    _min: NotificationMinAggregateOutputType | null
    _max: NotificationMaxAggregateOutputType | null
  }

  export type NotificationMinAggregateOutputType = {
    id: string | null
    title: string | null
    description: string | null
    status: string | null
    userId: string | null
    isAlreadyRead: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type NotificationMaxAggregateOutputType = {
    id: string | null
    title: string | null
    description: string | null
    status: string | null
    userId: string | null
    isAlreadyRead: string | null
    createdAt: Date | null
    updatedAt: Date | null
  }

  export type NotificationCountAggregateOutputType = {
    id: number
    title: number
    description: number
    status: number
    userId: number
    isAlreadyRead: number
    createdAt: number
    updatedAt: number
    _all: number
  }


  export type NotificationMinAggregateInputType = {
    id?: true
    title?: true
    description?: true
    status?: true
    userId?: true
    isAlreadyRead?: true
    createdAt?: true
    updatedAt?: true
  }

  export type NotificationMaxAggregateInputType = {
    id?: true
    title?: true
    description?: true
    status?: true
    userId?: true
    isAlreadyRead?: true
    createdAt?: true
    updatedAt?: true
  }

  export type NotificationCountAggregateInputType = {
    id?: true
    title?: true
    description?: true
    status?: true
    userId?: true
    isAlreadyRead?: true
    createdAt?: true
    updatedAt?: true
    _all?: true
  }

  export type NotificationAggregateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Notification to aggregate.
     */
    where?: NotificationWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Notifications to fetch.
     */
    orderBy?: NotificationOrderByWithRelationInput | NotificationOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the start position
     */
    cursor?: NotificationWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Notifications from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Notifications.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Count returned Notifications
    **/
    _count?: true | NotificationCountAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the minimum value
    **/
    _min?: NotificationMinAggregateInputType
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/aggregations Aggregation Docs}
     * 
     * Select which fields to find the maximum value
    **/
    _max?: NotificationMaxAggregateInputType
  }

  export type GetNotificationAggregateType<T extends NotificationAggregateArgs> = {
        [P in keyof T & keyof AggregateNotification]: P extends '_count' | 'count'
      ? T[P] extends true
        ? number
        : GetScalarType<T[P], AggregateNotification[P]>
      : GetScalarType<T[P], AggregateNotification[P]>
  }




  export type NotificationGroupByArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    where?: NotificationWhereInput
    orderBy?: NotificationOrderByWithAggregationInput | NotificationOrderByWithAggregationInput[]
    by: NotificationScalarFieldEnum[] | NotificationScalarFieldEnum
    having?: NotificationScalarWhereWithAggregatesInput
    take?: number
    skip?: number
    _count?: NotificationCountAggregateInputType | true
    _min?: NotificationMinAggregateInputType
    _max?: NotificationMaxAggregateInputType
  }

  export type NotificationGroupByOutputType = {
    id: string
    title: string
    description: string
    status: string
    userId: string
    isAlreadyRead: string
    createdAt: Date
    updatedAt: Date
    _count: NotificationCountAggregateOutputType | null
    _min: NotificationMinAggregateOutputType | null
    _max: NotificationMaxAggregateOutputType | null
  }

  type GetNotificationGroupByPayload<T extends NotificationGroupByArgs> = Prisma.PrismaPromise<
    Array<
      PickEnumerable<NotificationGroupByOutputType, T['by']> &
        {
          [P in ((keyof T) & (keyof NotificationGroupByOutputType))]: P extends '_count'
            ? T[P] extends boolean
              ? number
              : GetScalarType<T[P], NotificationGroupByOutputType[P]>
            : GetScalarType<T[P], NotificationGroupByOutputType[P]>
        }
      >
    >


  export type NotificationSelect<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = $Extensions.GetSelect<{
    id?: boolean
    title?: boolean
    description?: boolean
    status?: boolean
    userId?: boolean
    isAlreadyRead?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }, ExtArgs["result"]["notification"]>

  export type NotificationSelectScalar = {
    id?: boolean
    title?: boolean
    description?: boolean
    status?: boolean
    userId?: boolean
    isAlreadyRead?: boolean
    createdAt?: boolean
    updatedAt?: boolean
  }


  export type $NotificationPayload<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    name: "Notification"
    objects: {}
    scalars: $Extensions.GetPayloadResult<{
      id: string
      title: string
      description: string
      status: string
      userId: string
      isAlreadyRead: string
      createdAt: Date
      updatedAt: Date
    }, ExtArgs["result"]["notification"]>
    composites: {}
  }


  type NotificationGetPayload<S extends boolean | null | undefined | NotificationDefaultArgs> = $Result.GetResult<Prisma.$NotificationPayload, S>

  type NotificationCountArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = 
    Omit<NotificationFindManyArgs, 'select' | 'include' | 'distinct'> & {
      select?: NotificationCountAggregateInputType | true
    }

  export interface NotificationDelegate<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> {
    [K: symbol]: { types: Prisma.TypeMap<ExtArgs>['model']['Notification'], meta: { name: 'Notification' } }
    /**
     * Find zero or one Notification that matches the filter.
     * @param {NotificationFindUniqueArgs} args - Arguments to find a Notification
     * @example
     * // Get one Notification
     * const notification = await prisma.notification.findUnique({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUnique<T extends NotificationFindUniqueArgs<ExtArgs>>(
      args: SelectSubset<T, NotificationFindUniqueArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'findUnique'> | null, null, ExtArgs>

    /**
     * Find one Notification that matches the filter or throw an error  with `error.code='P2025'` 
     *     if no matches were found.
     * @param {NotificationFindUniqueOrThrowArgs} args - Arguments to find a Notification
     * @example
     * // Get one Notification
     * const notification = await prisma.notification.findUniqueOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findUniqueOrThrow<T extends NotificationFindUniqueOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, NotificationFindUniqueOrThrowArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'findUniqueOrThrow'>, never, ExtArgs>

    /**
     * Find the first Notification that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationFindFirstArgs} args - Arguments to find a Notification
     * @example
     * // Get one Notification
     * const notification = await prisma.notification.findFirst({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirst<T extends NotificationFindFirstArgs<ExtArgs>>(
      args?: SelectSubset<T, NotificationFindFirstArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'findFirst'> | null, null, ExtArgs>

    /**
     * Find the first Notification that matches the filter or
     * throw `PrismaKnownClientError` with `P2025` code if no matches were found.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationFindFirstOrThrowArgs} args - Arguments to find a Notification
     * @example
     * // Get one Notification
     * const notification = await prisma.notification.findFirstOrThrow({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
    **/
    findFirstOrThrow<T extends NotificationFindFirstOrThrowArgs<ExtArgs>>(
      args?: SelectSubset<T, NotificationFindFirstOrThrowArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'findFirstOrThrow'>, never, ExtArgs>

    /**
     * Find zero or more Notifications that matches the filter.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationFindManyArgs=} args - Arguments to filter and select certain fields only.
     * @example
     * // Get all Notifications
     * const notifications = await prisma.notification.findMany()
     * 
     * // Get first 10 Notifications
     * const notifications = await prisma.notification.findMany({ take: 10 })
     * 
     * // Only select the `id`
     * const notificationWithIdOnly = await prisma.notification.findMany({ select: { id: true } })
     * 
    **/
    findMany<T extends NotificationFindManyArgs<ExtArgs>>(
      args?: SelectSubset<T, NotificationFindManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'findMany'>>

    /**
     * Create a Notification.
     * @param {NotificationCreateArgs} args - Arguments to create a Notification.
     * @example
     * // Create one Notification
     * const Notification = await prisma.notification.create({
     *   data: {
     *     // ... data to create a Notification
     *   }
     * })
     * 
    **/
    create<T extends NotificationCreateArgs<ExtArgs>>(
      args: SelectSubset<T, NotificationCreateArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'create'>, never, ExtArgs>

    /**
     * Delete a Notification.
     * @param {NotificationDeleteArgs} args - Arguments to delete one Notification.
     * @example
     * // Delete one Notification
     * const Notification = await prisma.notification.delete({
     *   where: {
     *     // ... filter to delete one Notification
     *   }
     * })
     * 
    **/
    delete<T extends NotificationDeleteArgs<ExtArgs>>(
      args: SelectSubset<T, NotificationDeleteArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'delete'>, never, ExtArgs>

    /**
     * Update one Notification.
     * @param {NotificationUpdateArgs} args - Arguments to update one Notification.
     * @example
     * // Update one Notification
     * const notification = await prisma.notification.update({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    update<T extends NotificationUpdateArgs<ExtArgs>>(
      args: SelectSubset<T, NotificationUpdateArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'update'>, never, ExtArgs>

    /**
     * Delete zero or more Notifications.
     * @param {NotificationDeleteManyArgs} args - Arguments to filter Notifications to delete.
     * @example
     * // Delete a few Notifications
     * const { count } = await prisma.notification.deleteMany({
     *   where: {
     *     // ... provide filter here
     *   }
     * })
     * 
    **/
    deleteMany<T extends NotificationDeleteManyArgs<ExtArgs>>(
      args?: SelectSubset<T, NotificationDeleteManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Update zero or more Notifications.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationUpdateManyArgs} args - Arguments to update one or more rows.
     * @example
     * // Update many Notifications
     * const notification = await prisma.notification.updateMany({
     *   where: {
     *     // ... provide filter here
     *   },
     *   data: {
     *     // ... provide data here
     *   }
     * })
     * 
    **/
    updateMany<T extends NotificationUpdateManyArgs<ExtArgs>>(
      args: SelectSubset<T, NotificationUpdateManyArgs<ExtArgs>>
    ): Prisma.PrismaPromise<BatchPayload>

    /**
     * Create or update one Notification.
     * @param {NotificationUpsertArgs} args - Arguments to update or create a Notification.
     * @example
     * // Update or create a Notification
     * const notification = await prisma.notification.upsert({
     *   create: {
     *     // ... data to create a Notification
     *   },
     *   update: {
     *     // ... in case it already exists, update
     *   },
     *   where: {
     *     // ... the filter for the Notification we want to update
     *   }
     * })
    **/
    upsert<T extends NotificationUpsertArgs<ExtArgs>>(
      args: SelectSubset<T, NotificationUpsertArgs<ExtArgs>>
    ): Prisma__NotificationClient<$Result.GetResult<Prisma.$NotificationPayload<ExtArgs>, T, 'upsert'>, never, ExtArgs>

    /**
     * Count the number of Notifications.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationCountArgs} args - Arguments to filter Notifications to count.
     * @example
     * // Count the number of Notifications
     * const count = await prisma.notification.count({
     *   where: {
     *     // ... the filter for the Notifications we want to count
     *   }
     * })
    **/
    count<T extends NotificationCountArgs>(
      args?: Subset<T, NotificationCountArgs>,
    ): Prisma.PrismaPromise<
      T extends $Utils.Record<'select', any>
        ? T['select'] extends true
          ? number
          : GetScalarType<T['select'], NotificationCountAggregateOutputType>
        : number
    >

    /**
     * Allows you to perform aggregations operations on a Notification.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationAggregateArgs} args - Select which aggregations you would like to apply and on what fields.
     * @example
     * // Ordered by age ascending
     * // Where email contains prisma.io
     * // Limited to the 10 users
     * const aggregations = await prisma.user.aggregate({
     *   _avg: {
     *     age: true,
     *   },
     *   where: {
     *     email: {
     *       contains: "prisma.io",
     *     },
     *   },
     *   orderBy: {
     *     age: "asc",
     *   },
     *   take: 10,
     * })
    **/
    aggregate<T extends NotificationAggregateArgs>(args: Subset<T, NotificationAggregateArgs>): Prisma.PrismaPromise<GetNotificationAggregateType<T>>

    /**
     * Group by Notification.
     * Note, that providing `undefined` is treated as the value not being there.
     * Read more here: https://pris.ly/d/null-undefined
     * @param {NotificationGroupByArgs} args - Group by arguments.
     * @example
     * // Group by city, order by createdAt, get count
     * const result = await prisma.user.groupBy({
     *   by: ['city', 'createdAt'],
     *   orderBy: {
     *     createdAt: true
     *   },
     *   _count: {
     *     _all: true
     *   },
     * })
     * 
    **/
    groupBy<
      T extends NotificationGroupByArgs,
      HasSelectOrTake extends Or<
        Extends<'skip', Keys<T>>,
        Extends<'take', Keys<T>>
      >,
      OrderByArg extends True extends HasSelectOrTake
        ? { orderBy: NotificationGroupByArgs['orderBy'] }
        : { orderBy?: NotificationGroupByArgs['orderBy'] },
      OrderFields extends ExcludeUnderscoreKeys<Keys<MaybeTupleToUnion<T['orderBy']>>>,
      ByFields extends MaybeTupleToUnion<T['by']>,
      ByValid extends Has<ByFields, OrderFields>,
      HavingFields extends GetHavingFields<T['having']>,
      HavingValid extends Has<ByFields, HavingFields>,
      ByEmpty extends T['by'] extends never[] ? True : False,
      InputErrors extends ByEmpty extends True
      ? `Error: "by" must not be empty.`
      : HavingValid extends False
      ? {
          [P in HavingFields]: P extends ByFields
            ? never
            : P extends string
            ? `Error: Field "${P}" used in "having" needs to be provided in "by".`
            : [
                Error,
                'Field ',
                P,
                ` in "having" needs to be provided in "by"`,
              ]
        }[HavingFields]
      : 'take' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "take", you also need to provide "orderBy"'
      : 'skip' extends Keys<T>
      ? 'orderBy' extends Keys<T>
        ? ByValid extends True
          ? {}
          : {
              [P in OrderFields]: P extends ByFields
                ? never
                : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
            }[OrderFields]
        : 'Error: If you provide "skip", you also need to provide "orderBy"'
      : ByValid extends True
      ? {}
      : {
          [P in OrderFields]: P extends ByFields
            ? never
            : `Error: Field "${P}" in "orderBy" needs to be provided in "by"`
        }[OrderFields]
    >(args: SubsetIntersection<T, NotificationGroupByArgs, OrderByArg> & InputErrors): {} extends InputErrors ? GetNotificationGroupByPayload<T> : Prisma.PrismaPromise<InputErrors>
  /**
   * Fields of the Notification model
   */
  readonly fields: NotificationFieldRefs;
  }

  /**
   * The delegate class that acts as a "Promise-like" for Notification.
   * Why is this prefixed with `Prisma__`?
   * Because we want to prevent naming conflicts as mentioned in
   * https://github.com/prisma/prisma-client-js/issues/707
   */
  export interface Prisma__NotificationClient<T, Null = never, ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> extends Prisma.PrismaPromise<T> {
    readonly [Symbol.toStringTag]: 'PrismaPromise';


    /**
     * Attaches callbacks for the resolution and/or rejection of the Promise.
     * @param onfulfilled The callback to execute when the Promise is resolved.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of which ever callback is executed.
     */
    then<TResult1 = T, TResult2 = never>(onfulfilled?: ((value: T) => TResult1 | PromiseLike<TResult1>) | undefined | null, onrejected?: ((reason: any) => TResult2 | PromiseLike<TResult2>) | undefined | null): $Utils.JsPromise<TResult1 | TResult2>;
    /**
     * Attaches a callback for only the rejection of the Promise.
     * @param onrejected The callback to execute when the Promise is rejected.
     * @returns A Promise for the completion of the callback.
     */
    catch<TResult = never>(onrejected?: ((reason: any) => TResult | PromiseLike<TResult>) | undefined | null): $Utils.JsPromise<T | TResult>;
    /**
     * Attaches a callback that is invoked when the Promise is settled (fulfilled or rejected). The
     * resolved value cannot be modified from the callback.
     * @param onfinally The callback to execute when the Promise is settled (fulfilled or rejected).
     * @returns A Promise for the completion of the callback.
     */
    finally(onfinally?: (() => void) | undefined | null): $Utils.JsPromise<T>;
  }



  /**
   * Fields of the Notification model
   */ 
  interface NotificationFieldRefs {
    readonly id: FieldRef<"Notification", 'String'>
    readonly title: FieldRef<"Notification", 'String'>
    readonly description: FieldRef<"Notification", 'String'>
    readonly status: FieldRef<"Notification", 'String'>
    readonly userId: FieldRef<"Notification", 'String'>
    readonly isAlreadyRead: FieldRef<"Notification", 'String'>
    readonly createdAt: FieldRef<"Notification", 'DateTime'>
    readonly updatedAt: FieldRef<"Notification", 'DateTime'>
  }
    

  // Custom InputTypes

  /**
   * Notification findUnique
   */
  export type NotificationFindUniqueArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * Filter, which Notification to fetch.
     */
    where: NotificationWhereUniqueInput
  }


  /**
   * Notification findUniqueOrThrow
   */
  export type NotificationFindUniqueOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * Filter, which Notification to fetch.
     */
    where: NotificationWhereUniqueInput
  }


  /**
   * Notification findFirst
   */
  export type NotificationFindFirstArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * Filter, which Notification to fetch.
     */
    where?: NotificationWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Notifications to fetch.
     */
    orderBy?: NotificationOrderByWithRelationInput | NotificationOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Notifications.
     */
    cursor?: NotificationWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Notifications from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Notifications.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Notifications.
     */
    distinct?: NotificationScalarFieldEnum | NotificationScalarFieldEnum[]
  }


  /**
   * Notification findFirstOrThrow
   */
  export type NotificationFindFirstOrThrowArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * Filter, which Notification to fetch.
     */
    where?: NotificationWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Notifications to fetch.
     */
    orderBy?: NotificationOrderByWithRelationInput | NotificationOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for searching for Notifications.
     */
    cursor?: NotificationWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Notifications from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Notifications.
     */
    skip?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/distinct Distinct Docs}
     * 
     * Filter by unique combinations of Notifications.
     */
    distinct?: NotificationScalarFieldEnum | NotificationScalarFieldEnum[]
  }


  /**
   * Notification findMany
   */
  export type NotificationFindManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * Filter, which Notifications to fetch.
     */
    where?: NotificationWhereInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/sorting Sorting Docs}
     * 
     * Determine the order of Notifications to fetch.
     */
    orderBy?: NotificationOrderByWithRelationInput | NotificationOrderByWithRelationInput[]
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination#cursor-based-pagination Cursor Docs}
     * 
     * Sets the position for listing Notifications.
     */
    cursor?: NotificationWhereUniqueInput
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Take `±n` Notifications from the position of the cursor.
     */
    take?: number
    /**
     * {@link https://www.prisma.io/docs/concepts/components/prisma-client/pagination Pagination Docs}
     * 
     * Skip the first `n` Notifications.
     */
    skip?: number
    distinct?: NotificationScalarFieldEnum | NotificationScalarFieldEnum[]
  }


  /**
   * Notification create
   */
  export type NotificationCreateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * The data needed to create a Notification.
     */
    data: XOR<NotificationCreateInput, NotificationUncheckedCreateInput>
  }


  /**
   * Notification update
   */
  export type NotificationUpdateArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * The data needed to update a Notification.
     */
    data: XOR<NotificationUpdateInput, NotificationUncheckedUpdateInput>
    /**
     * Choose, which Notification to update.
     */
    where: NotificationWhereUniqueInput
  }


  /**
   * Notification updateMany
   */
  export type NotificationUpdateManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * The data used to update Notifications.
     */
    data: XOR<NotificationUpdateManyMutationInput, NotificationUncheckedUpdateManyInput>
    /**
     * Filter which Notifications to update
     */
    where?: NotificationWhereInput
  }


  /**
   * Notification upsert
   */
  export type NotificationUpsertArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * The filter to search for the Notification to update in case it exists.
     */
    where: NotificationWhereUniqueInput
    /**
     * In case the Notification found by the `where` argument doesn't exist, create a new Notification with this data.
     */
    create: XOR<NotificationCreateInput, NotificationUncheckedCreateInput>
    /**
     * In case the Notification was found with the provided `where` argument, update it with this data.
     */
    update: XOR<NotificationUpdateInput, NotificationUncheckedUpdateInput>
  }


  /**
   * Notification delete
   */
  export type NotificationDeleteArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
    /**
     * Filter which Notification to delete.
     */
    where: NotificationWhereUniqueInput
  }


  /**
   * Notification deleteMany
   */
  export type NotificationDeleteManyArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Filter which Notifications to delete
     */
    where?: NotificationWhereInput
  }


  /**
   * Notification without action
   */
  export type NotificationDefaultArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = {
    /**
     * Select specific fields to fetch from the Notification
     */
    select?: NotificationSelect<ExtArgs> | null
  }



  /**
   * Enums
   */

  export const TransactionIsolationLevel: {
    Serializable: 'Serializable'
  };

  export type TransactionIsolationLevel = (typeof TransactionIsolationLevel)[keyof typeof TransactionIsolationLevel]


  export const ServerScalarFieldEnum: {
    id: 'id',
    name: 'name',
    protocol: 'protocol',
    host: 'host',
    port: 'port',
    isActive: 'isActive',
    deployEnabled: 'deployEnabled',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type ServerScalarFieldEnum = (typeof ServerScalarFieldEnum)[keyof typeof ServerScalarFieldEnum]


  export const ProductScalarFieldEnum: {
    id: 'id',
    devopsId: 'devopsId',
    productName: 'productName',
    description: 'description',
    requirements: 'requirements',
    productImage: 'productImage',
    productOriginalImage: 'productOriginalImage',
    isActive: 'isActive',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt',
    guideUrl: 'guideUrl'
  };

  export type ProductScalarFieldEnum = (typeof ProductScalarFieldEnum)[keyof typeof ProductScalarFieldEnum]


  export const ProductSettingScalarFieldEnum: {
    id: 'id',
    devopsId: 'devopsId',
    config: 'config',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type ProductSettingScalarFieldEnum = (typeof ProductSettingScalarFieldEnum)[keyof typeof ProductSettingScalarFieldEnum]


  export const ProductSettingDetailScalarFieldEnum: {
    id: 'id',
    config: 'config',
    devopsId: 'devopsId',
    productSettingId: 'productSettingId',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type ProductSettingDetailScalarFieldEnum = (typeof ProductSettingDetailScalarFieldEnum)[keyof typeof ProductSettingDetailScalarFieldEnum]


  export const UpdaterVersionScalarFieldEnum: {
    id: 'id',
    version: 'version',
    approvedVersion: 'approvedVersion',
    downloads: 'downloads',
    isActive: 'isActive',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type UpdaterVersionScalarFieldEnum = (typeof UpdaterVersionScalarFieldEnum)[keyof typeof UpdaterVersionScalarFieldEnum]


  export const CustomerScalarFieldEnum: {
    id: 'id',
    name: 'name',
    assistantUrl: 'assistantUrl',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type CustomerScalarFieldEnum = (typeof CustomerScalarFieldEnum)[keyof typeof CustomerScalarFieldEnum]


  export const AssistantMonitoringScalarFieldEnum: {
    id: 'id',
    monitoringId: 'monitoringId',
    name: 'name',
    content: 'content',
    description: 'description',
    interval: 'interval',
    isActive: 'isActive',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type AssistantMonitoringScalarFieldEnum = (typeof AssistantMonitoringScalarFieldEnum)[keyof typeof AssistantMonitoringScalarFieldEnum]


  export const NotificationScalarFieldEnum: {
    id: 'id',
    title: 'title',
    description: 'description',
    status: 'status',
    userId: 'userId',
    isAlreadyRead: 'isAlreadyRead',
    createdAt: 'createdAt',
    updatedAt: 'updatedAt'
  };

  export type NotificationScalarFieldEnum = (typeof NotificationScalarFieldEnum)[keyof typeof NotificationScalarFieldEnum]


  export const SortOrder: {
    asc: 'asc',
    desc: 'desc'
  };

  export type SortOrder = (typeof SortOrder)[keyof typeof SortOrder]


  export const NullsOrder: {
    first: 'first',
    last: 'last'
  };

  export type NullsOrder = (typeof NullsOrder)[keyof typeof NullsOrder]


  /**
   * Deep Input Types
   */


  export type ServerWhereInput = {
    AND?: ServerWhereInput | ServerWhereInput[]
    OR?: ServerWhereInput[]
    NOT?: ServerWhereInput | ServerWhereInput[]
    id?: StringFilter | string
    name?: StringFilter | string
    protocol?: StringFilter | string
    host?: StringFilter | string
    port?: IntFilter | number
    isActive?: StringFilter | string
    deployEnabled?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
  }

  export type ServerOrderByWithRelationInput = {
    id?: SortOrder
    name?: SortOrder
    protocol?: SortOrder
    host?: SortOrder
    port?: SortOrder
    isActive?: SortOrder
    deployEnabled?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ServerWhereUniqueInput = {
    id?: string
    name?: string
  }

  export type ServerOrderByWithAggregationInput = {
    id?: SortOrder
    name?: SortOrder
    protocol?: SortOrder
    host?: SortOrder
    port?: SortOrder
    isActive?: SortOrder
    deployEnabled?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: ServerCountOrderByAggregateInput
    _avg?: ServerAvgOrderByAggregateInput
    _max?: ServerMaxOrderByAggregateInput
    _min?: ServerMinOrderByAggregateInput
    _sum?: ServerSumOrderByAggregateInput
  }

  export type ServerScalarWhereWithAggregatesInput = {
    AND?: ServerScalarWhereWithAggregatesInput | ServerScalarWhereWithAggregatesInput[]
    OR?: ServerScalarWhereWithAggregatesInput[]
    NOT?: ServerScalarWhereWithAggregatesInput | ServerScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    name?: StringWithAggregatesFilter | string
    protocol?: StringWithAggregatesFilter | string
    host?: StringWithAggregatesFilter | string
    port?: IntWithAggregatesFilter | number
    isActive?: StringWithAggregatesFilter | string
    deployEnabled?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type ProductWhereInput = {
    AND?: ProductWhereInput | ProductWhereInput[]
    OR?: ProductWhereInput[]
    NOT?: ProductWhereInput | ProductWhereInput[]
    id?: StringFilter | string
    devopsId?: IntFilter | number
    productName?: StringFilter | string
    description?: StringNullableFilter | string | null
    requirements?: StringNullableFilter | string | null
    productImage?: StringNullableFilter | string | null
    productOriginalImage?: StringNullableFilter | string | null
    isActive?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
    guideUrl?: StringNullableFilter | string | null
    config?: XOR<ProductSettingRelationFilter, ProductSettingWhereInput> | null
    requiredProducts?: ProductListRelationFilter
    requiredByProducts?: ProductListRelationFilter
  }

  export type ProductOrderByWithRelationInput = {
    id?: SortOrder
    devopsId?: SortOrder
    productName?: SortOrder
    description?: SortOrderInput | SortOrder
    requirements?: SortOrderInput | SortOrder
    productImage?: SortOrderInput | SortOrder
    productOriginalImage?: SortOrderInput | SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    guideUrl?: SortOrderInput | SortOrder
    config?: ProductSettingOrderByWithRelationInput
    requiredProducts?: ProductOrderByRelationAggregateInput
    requiredByProducts?: ProductOrderByRelationAggregateInput
  }

  export type ProductWhereUniqueInput = {
    id?: string
    devopsId?: number
  }

  export type ProductOrderByWithAggregationInput = {
    id?: SortOrder
    devopsId?: SortOrder
    productName?: SortOrder
    description?: SortOrderInput | SortOrder
    requirements?: SortOrderInput | SortOrder
    productImage?: SortOrderInput | SortOrder
    productOriginalImage?: SortOrderInput | SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    guideUrl?: SortOrderInput | SortOrder
    _count?: ProductCountOrderByAggregateInput
    _avg?: ProductAvgOrderByAggregateInput
    _max?: ProductMaxOrderByAggregateInput
    _min?: ProductMinOrderByAggregateInput
    _sum?: ProductSumOrderByAggregateInput
  }

  export type ProductScalarWhereWithAggregatesInput = {
    AND?: ProductScalarWhereWithAggregatesInput | ProductScalarWhereWithAggregatesInput[]
    OR?: ProductScalarWhereWithAggregatesInput[]
    NOT?: ProductScalarWhereWithAggregatesInput | ProductScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    devopsId?: IntWithAggregatesFilter | number
    productName?: StringWithAggregatesFilter | string
    description?: StringNullableWithAggregatesFilter | string | null
    requirements?: StringNullableWithAggregatesFilter | string | null
    productImage?: StringNullableWithAggregatesFilter | string | null
    productOriginalImage?: StringNullableWithAggregatesFilter | string | null
    isActive?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
    guideUrl?: StringNullableWithAggregatesFilter | string | null
  }

  export type ProductSettingWhereInput = {
    AND?: ProductSettingWhereInput | ProductSettingWhereInput[]
    OR?: ProductSettingWhereInput[]
    NOT?: ProductSettingWhereInput | ProductSettingWhereInput[]
    id?: StringFilter | string
    devopsId?: IntFilter | number
    config?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
    product?: XOR<ProductRelationFilter, ProductWhereInput>
    detail?: XOR<ProductSettingDetailRelationFilter, ProductSettingDetailWhereInput> | null
  }

  export type ProductSettingOrderByWithRelationInput = {
    id?: SortOrder
    devopsId?: SortOrder
    config?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    product?: ProductOrderByWithRelationInput
    detail?: ProductSettingDetailOrderByWithRelationInput
  }

  export type ProductSettingWhereUniqueInput = {
    id?: string
    devopsId?: number
  }

  export type ProductSettingOrderByWithAggregationInput = {
    id?: SortOrder
    devopsId?: SortOrder
    config?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: ProductSettingCountOrderByAggregateInput
    _avg?: ProductSettingAvgOrderByAggregateInput
    _max?: ProductSettingMaxOrderByAggregateInput
    _min?: ProductSettingMinOrderByAggregateInput
    _sum?: ProductSettingSumOrderByAggregateInput
  }

  export type ProductSettingScalarWhereWithAggregatesInput = {
    AND?: ProductSettingScalarWhereWithAggregatesInput | ProductSettingScalarWhereWithAggregatesInput[]
    OR?: ProductSettingScalarWhereWithAggregatesInput[]
    NOT?: ProductSettingScalarWhereWithAggregatesInput | ProductSettingScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    devopsId?: IntWithAggregatesFilter | number
    config?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type ProductSettingDetailWhereInput = {
    AND?: ProductSettingDetailWhereInput | ProductSettingDetailWhereInput[]
    OR?: ProductSettingDetailWhereInput[]
    NOT?: ProductSettingDetailWhereInput | ProductSettingDetailWhereInput[]
    id?: StringFilter | string
    config?: StringFilter | string
    devopsId?: IntFilter | number
    productSettingId?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
    productSetting?: XOR<ProductSettingRelationFilter, ProductSettingWhereInput>
  }

  export type ProductSettingDetailOrderByWithRelationInput = {
    id?: SortOrder
    config?: SortOrder
    devopsId?: SortOrder
    productSettingId?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    productSetting?: ProductSettingOrderByWithRelationInput
  }

  export type ProductSettingDetailWhereUniqueInput = {
    id?: string
    devopsId?: number
    productSettingId?: string
  }

  export type ProductSettingDetailOrderByWithAggregationInput = {
    id?: SortOrder
    config?: SortOrder
    devopsId?: SortOrder
    productSettingId?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: ProductSettingDetailCountOrderByAggregateInput
    _avg?: ProductSettingDetailAvgOrderByAggregateInput
    _max?: ProductSettingDetailMaxOrderByAggregateInput
    _min?: ProductSettingDetailMinOrderByAggregateInput
    _sum?: ProductSettingDetailSumOrderByAggregateInput
  }

  export type ProductSettingDetailScalarWhereWithAggregatesInput = {
    AND?: ProductSettingDetailScalarWhereWithAggregatesInput | ProductSettingDetailScalarWhereWithAggregatesInput[]
    OR?: ProductSettingDetailScalarWhereWithAggregatesInput[]
    NOT?: ProductSettingDetailScalarWhereWithAggregatesInput | ProductSettingDetailScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    config?: StringWithAggregatesFilter | string
    devopsId?: IntWithAggregatesFilter | number
    productSettingId?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type UpdaterVersionWhereInput = {
    AND?: UpdaterVersionWhereInput | UpdaterVersionWhereInput[]
    OR?: UpdaterVersionWhereInput[]
    NOT?: UpdaterVersionWhereInput | UpdaterVersionWhereInput[]
    id?: StringFilter | string
    version?: StringFilter | string
    approvedVersion?: StringFilter | string
    downloads?: IntFilter | number
    isActive?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
  }

  export type UpdaterVersionOrderByWithRelationInput = {
    id?: SortOrder
    version?: SortOrder
    approvedVersion?: SortOrder
    downloads?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type UpdaterVersionWhereUniqueInput = {
    id?: string
    version?: string
  }

  export type UpdaterVersionOrderByWithAggregationInput = {
    id?: SortOrder
    version?: SortOrder
    approvedVersion?: SortOrder
    downloads?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: UpdaterVersionCountOrderByAggregateInput
    _avg?: UpdaterVersionAvgOrderByAggregateInput
    _max?: UpdaterVersionMaxOrderByAggregateInput
    _min?: UpdaterVersionMinOrderByAggregateInput
    _sum?: UpdaterVersionSumOrderByAggregateInput
  }

  export type UpdaterVersionScalarWhereWithAggregatesInput = {
    AND?: UpdaterVersionScalarWhereWithAggregatesInput | UpdaterVersionScalarWhereWithAggregatesInput[]
    OR?: UpdaterVersionScalarWhereWithAggregatesInput[]
    NOT?: UpdaterVersionScalarWhereWithAggregatesInput | UpdaterVersionScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    version?: StringWithAggregatesFilter | string
    approvedVersion?: StringWithAggregatesFilter | string
    downloads?: IntWithAggregatesFilter | number
    isActive?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type CustomerWhereInput = {
    AND?: CustomerWhereInput | CustomerWhereInput[]
    OR?: CustomerWhereInput[]
    NOT?: CustomerWhereInput | CustomerWhereInput[]
    id?: StringFilter | string
    name?: StringFilter | string
    assistantUrl?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
  }

  export type CustomerOrderByWithRelationInput = {
    id?: SortOrder
    name?: SortOrder
    assistantUrl?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type CustomerWhereUniqueInput = {
    id?: string
    name?: string
    assistantUrl?: string
  }

  export type CustomerOrderByWithAggregationInput = {
    id?: SortOrder
    name?: SortOrder
    assistantUrl?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: CustomerCountOrderByAggregateInput
    _max?: CustomerMaxOrderByAggregateInput
    _min?: CustomerMinOrderByAggregateInput
  }

  export type CustomerScalarWhereWithAggregatesInput = {
    AND?: CustomerScalarWhereWithAggregatesInput | CustomerScalarWhereWithAggregatesInput[]
    OR?: CustomerScalarWhereWithAggregatesInput[]
    NOT?: CustomerScalarWhereWithAggregatesInput | CustomerScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    name?: StringWithAggregatesFilter | string
    assistantUrl?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type AssistantMonitoringWhereInput = {
    AND?: AssistantMonitoringWhereInput | AssistantMonitoringWhereInput[]
    OR?: AssistantMonitoringWhereInput[]
    NOT?: AssistantMonitoringWhereInput | AssistantMonitoringWhereInput[]
    id?: StringFilter | string
    monitoringId?: StringFilter | string
    name?: StringFilter | string
    content?: StringFilter | string
    description?: StringFilter | string
    interval?: IntFilter | number
    isActive?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
  }

  export type AssistantMonitoringOrderByWithRelationInput = {
    id?: SortOrder
    monitoringId?: SortOrder
    name?: SortOrder
    content?: SortOrder
    description?: SortOrder
    interval?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type AssistantMonitoringWhereUniqueInput = {
    id?: string
    monitoringId?: string
  }

  export type AssistantMonitoringOrderByWithAggregationInput = {
    id?: SortOrder
    monitoringId?: SortOrder
    name?: SortOrder
    content?: SortOrder
    description?: SortOrder
    interval?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: AssistantMonitoringCountOrderByAggregateInput
    _avg?: AssistantMonitoringAvgOrderByAggregateInput
    _max?: AssistantMonitoringMaxOrderByAggregateInput
    _min?: AssistantMonitoringMinOrderByAggregateInput
    _sum?: AssistantMonitoringSumOrderByAggregateInput
  }

  export type AssistantMonitoringScalarWhereWithAggregatesInput = {
    AND?: AssistantMonitoringScalarWhereWithAggregatesInput | AssistantMonitoringScalarWhereWithAggregatesInput[]
    OR?: AssistantMonitoringScalarWhereWithAggregatesInput[]
    NOT?: AssistantMonitoringScalarWhereWithAggregatesInput | AssistantMonitoringScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    monitoringId?: StringWithAggregatesFilter | string
    name?: StringWithAggregatesFilter | string
    content?: StringWithAggregatesFilter | string
    description?: StringWithAggregatesFilter | string
    interval?: IntWithAggregatesFilter | number
    isActive?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type NotificationWhereInput = {
    AND?: NotificationWhereInput | NotificationWhereInput[]
    OR?: NotificationWhereInput[]
    NOT?: NotificationWhereInput | NotificationWhereInput[]
    id?: StringFilter | string
    title?: StringFilter | string
    description?: StringFilter | string
    status?: StringFilter | string
    userId?: StringFilter | string
    isAlreadyRead?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
  }

  export type NotificationOrderByWithRelationInput = {
    id?: SortOrder
    title?: SortOrder
    description?: SortOrder
    status?: SortOrder
    userId?: SortOrder
    isAlreadyRead?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type NotificationWhereUniqueInput = {
    id?: string
  }

  export type NotificationOrderByWithAggregationInput = {
    id?: SortOrder
    title?: SortOrder
    description?: SortOrder
    status?: SortOrder
    userId?: SortOrder
    isAlreadyRead?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    _count?: NotificationCountOrderByAggregateInput
    _max?: NotificationMaxOrderByAggregateInput
    _min?: NotificationMinOrderByAggregateInput
  }

  export type NotificationScalarWhereWithAggregatesInput = {
    AND?: NotificationScalarWhereWithAggregatesInput | NotificationScalarWhereWithAggregatesInput[]
    OR?: NotificationScalarWhereWithAggregatesInput[]
    NOT?: NotificationScalarWhereWithAggregatesInput | NotificationScalarWhereWithAggregatesInput[]
    id?: StringWithAggregatesFilter | string
    title?: StringWithAggregatesFilter | string
    description?: StringWithAggregatesFilter | string
    status?: StringWithAggregatesFilter | string
    userId?: StringWithAggregatesFilter | string
    isAlreadyRead?: StringWithAggregatesFilter | string
    createdAt?: DateTimeWithAggregatesFilter | Date | string
    updatedAt?: DateTimeWithAggregatesFilter | Date | string
  }

  export type ServerCreateInput = {
    id?: string
    name: string
    protocol?: string
    host: string
    port?: number
    isActive?: string
    deployEnabled?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type ServerUncheckedCreateInput = {
    id?: string
    name: string
    protocol?: string
    host: string
    port?: number
    isActive?: string
    deployEnabled?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type ServerUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    protocol?: StringFieldUpdateOperationsInput | string
    host?: StringFieldUpdateOperationsInput | string
    port?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    deployEnabled?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ServerUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    protocol?: StringFieldUpdateOperationsInput | string
    host?: StringFieldUpdateOperationsInput | string
    port?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    deployEnabled?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ServerUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    protocol?: StringFieldUpdateOperationsInput | string
    host?: StringFieldUpdateOperationsInput | string
    port?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    deployEnabled?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ServerUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    protocol?: StringFieldUpdateOperationsInput | string
    host?: StringFieldUpdateOperationsInput | string
    port?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    deployEnabled?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductCreateInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    config?: ProductSettingCreateNestedOneWithoutProductInput
    requiredProducts?: ProductCreateNestedManyWithoutRequiredByProductsInput
    requiredByProducts?: ProductCreateNestedManyWithoutRequiredProductsInput
  }

  export type ProductUncheckedCreateInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    config?: ProductSettingUncheckedCreateNestedOneWithoutProductInput
    requiredProducts?: ProductUncheckedCreateNestedManyWithoutRequiredByProductsInput
    requiredByProducts?: ProductUncheckedCreateNestedManyWithoutRequiredProductsInput
  }

  export type ProductUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    config?: ProductSettingUpdateOneWithoutProductNestedInput
    requiredProducts?: ProductUpdateManyWithoutRequiredByProductsNestedInput
    requiredByProducts?: ProductUpdateManyWithoutRequiredProductsNestedInput
  }

  export type ProductUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    config?: ProductSettingUncheckedUpdateOneWithoutProductNestedInput
    requiredProducts?: ProductUncheckedUpdateManyWithoutRequiredByProductsNestedInput
    requiredByProducts?: ProductUncheckedUpdateManyWithoutRequiredProductsNestedInput
  }

  export type ProductUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
  }

  export type ProductUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
  }

  export type ProductSettingCreateInput = {
    id?: string
    config: string
    createdAt?: Date | string
    updatedAt?: Date | string
    product: ProductCreateNestedOneWithoutConfigInput
    detail?: ProductSettingDetailCreateNestedOneWithoutProductSettingInput
  }

  export type ProductSettingUncheckedCreateInput = {
    id?: string
    devopsId: number
    config: string
    createdAt?: Date | string
    updatedAt?: Date | string
    detail?: ProductSettingDetailUncheckedCreateNestedOneWithoutProductSettingInput
  }

  export type ProductSettingUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    product?: ProductUpdateOneRequiredWithoutConfigNestedInput
    detail?: ProductSettingDetailUpdateOneWithoutProductSettingNestedInput
  }

  export type ProductSettingUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    detail?: ProductSettingDetailUncheckedUpdateOneWithoutProductSettingNestedInput
  }

  export type ProductSettingUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductSettingUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductSettingDetailCreateInput = {
    id?: string
    config: string
    devopsId: number
    createdAt?: Date | string
    updatedAt?: Date | string
    productSetting: ProductSettingCreateNestedOneWithoutDetailInput
  }

  export type ProductSettingDetailUncheckedCreateInput = {
    id?: string
    config: string
    devopsId: number
    productSettingId: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type ProductSettingDetailUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    productSetting?: ProductSettingUpdateOneRequiredWithoutDetailNestedInput
  }

  export type ProductSettingDetailUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productSettingId?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductSettingDetailUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductSettingDetailUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productSettingId?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type UpdaterVersionCreateInput = {
    id?: string
    version: string
    approvedVersion?: string
    downloads?: number
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type UpdaterVersionUncheckedCreateInput = {
    id?: string
    version: string
    approvedVersion?: string
    downloads?: number
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type UpdaterVersionUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    version?: StringFieldUpdateOperationsInput | string
    approvedVersion?: StringFieldUpdateOperationsInput | string
    downloads?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type UpdaterVersionUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    version?: StringFieldUpdateOperationsInput | string
    approvedVersion?: StringFieldUpdateOperationsInput | string
    downloads?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type UpdaterVersionUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    version?: StringFieldUpdateOperationsInput | string
    approvedVersion?: StringFieldUpdateOperationsInput | string
    downloads?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type UpdaterVersionUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    version?: StringFieldUpdateOperationsInput | string
    approvedVersion?: StringFieldUpdateOperationsInput | string
    downloads?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type CustomerCreateInput = {
    id?: string
    name: string
    assistantUrl: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type CustomerUncheckedCreateInput = {
    id?: string
    name: string
    assistantUrl: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type CustomerUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    assistantUrl?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type CustomerUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    assistantUrl?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type CustomerUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    assistantUrl?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type CustomerUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    assistantUrl?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type AssistantMonitoringCreateInput = {
    id?: string
    monitoringId: string
    name: string
    content: string
    description: string
    interval: number
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type AssistantMonitoringUncheckedCreateInput = {
    id?: string
    monitoringId: string
    name: string
    content: string
    description: string
    interval: number
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type AssistantMonitoringUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    monitoringId?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    content?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    interval?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type AssistantMonitoringUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    monitoringId?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    content?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    interval?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type AssistantMonitoringUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    monitoringId?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    content?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    interval?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type AssistantMonitoringUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    monitoringId?: StringFieldUpdateOperationsInput | string
    name?: StringFieldUpdateOperationsInput | string
    content?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    interval?: IntFieldUpdateOperationsInput | number
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type NotificationCreateInput = {
    id?: string
    title: string
    description: string
    status: string
    userId: string
    isAlreadyRead?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type NotificationUncheckedCreateInput = {
    id?: string
    title: string
    description: string
    status: string
    userId: string
    isAlreadyRead?: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type NotificationUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    title?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    status?: StringFieldUpdateOperationsInput | string
    userId?: StringFieldUpdateOperationsInput | string
    isAlreadyRead?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type NotificationUncheckedUpdateInput = {
    id?: StringFieldUpdateOperationsInput | string
    title?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    status?: StringFieldUpdateOperationsInput | string
    userId?: StringFieldUpdateOperationsInput | string
    isAlreadyRead?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type NotificationUpdateManyMutationInput = {
    id?: StringFieldUpdateOperationsInput | string
    title?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    status?: StringFieldUpdateOperationsInput | string
    userId?: StringFieldUpdateOperationsInput | string
    isAlreadyRead?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type NotificationUncheckedUpdateManyInput = {
    id?: StringFieldUpdateOperationsInput | string
    title?: StringFieldUpdateOperationsInput | string
    description?: StringFieldUpdateOperationsInput | string
    status?: StringFieldUpdateOperationsInput | string
    userId?: StringFieldUpdateOperationsInput | string
    isAlreadyRead?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type StringFilter = {
    equals?: string
    in?: string[] | string
    notIn?: string[] | string
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringFilter | string
  }

  export type IntFilter = {
    equals?: number
    in?: number[] | number
    notIn?: number[] | number
    lt?: number
    lte?: number
    gt?: number
    gte?: number
    not?: NestedIntFilter | number
  }

  export type DateTimeFilter = {
    equals?: Date | string
    in?: Date[] | string[] | Date | string
    notIn?: Date[] | string[] | Date | string
    lt?: Date | string
    lte?: Date | string
    gt?: Date | string
    gte?: Date | string
    not?: NestedDateTimeFilter | Date | string
  }

  export type ServerCountOrderByAggregateInput = {
    id?: SortOrder
    name?: SortOrder
    protocol?: SortOrder
    host?: SortOrder
    port?: SortOrder
    isActive?: SortOrder
    deployEnabled?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ServerAvgOrderByAggregateInput = {
    port?: SortOrder
  }

  export type ServerMaxOrderByAggregateInput = {
    id?: SortOrder
    name?: SortOrder
    protocol?: SortOrder
    host?: SortOrder
    port?: SortOrder
    isActive?: SortOrder
    deployEnabled?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ServerMinOrderByAggregateInput = {
    id?: SortOrder
    name?: SortOrder
    protocol?: SortOrder
    host?: SortOrder
    port?: SortOrder
    isActive?: SortOrder
    deployEnabled?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ServerSumOrderByAggregateInput = {
    port?: SortOrder
  }

  export type StringWithAggregatesFilter = {
    equals?: string
    in?: string[] | string
    notIn?: string[] | string
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringWithAggregatesFilter | string
    _count?: NestedIntFilter
    _min?: NestedStringFilter
    _max?: NestedStringFilter
  }

  export type IntWithAggregatesFilter = {
    equals?: number
    in?: number[] | number
    notIn?: number[] | number
    lt?: number
    lte?: number
    gt?: number
    gte?: number
    not?: NestedIntWithAggregatesFilter | number
    _count?: NestedIntFilter
    _avg?: NestedFloatFilter
    _sum?: NestedIntFilter
    _min?: NestedIntFilter
    _max?: NestedIntFilter
  }

  export type DateTimeWithAggregatesFilter = {
    equals?: Date | string
    in?: Date[] | string[] | Date | string
    notIn?: Date[] | string[] | Date | string
    lt?: Date | string
    lte?: Date | string
    gt?: Date | string
    gte?: Date | string
    not?: NestedDateTimeWithAggregatesFilter | Date | string
    _count?: NestedIntFilter
    _min?: NestedDateTimeFilter
    _max?: NestedDateTimeFilter
  }

  export type StringNullableFilter = {
    equals?: string | null
    in?: string[] | string | null
    notIn?: string[] | string | null
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringNullableFilter | string | null
  }

  export type ProductSettingRelationFilter = {
    is?: ProductSettingWhereInput | null
    isNot?: ProductSettingWhereInput | null
  }

  export type ProductListRelationFilter = {
    every?: ProductWhereInput
    some?: ProductWhereInput
    none?: ProductWhereInput
  }

  export type SortOrderInput = {
    sort: SortOrder
    nulls?: NullsOrder
  }

  export type ProductOrderByRelationAggregateInput = {
    _count?: SortOrder
  }

  export type ProductCountOrderByAggregateInput = {
    id?: SortOrder
    devopsId?: SortOrder
    productName?: SortOrder
    description?: SortOrder
    requirements?: SortOrder
    productImage?: SortOrder
    productOriginalImage?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    guideUrl?: SortOrder
  }

  export type ProductAvgOrderByAggregateInput = {
    devopsId?: SortOrder
  }

  export type ProductMaxOrderByAggregateInput = {
    id?: SortOrder
    devopsId?: SortOrder
    productName?: SortOrder
    description?: SortOrder
    requirements?: SortOrder
    productImage?: SortOrder
    productOriginalImage?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    guideUrl?: SortOrder
  }

  export type ProductMinOrderByAggregateInput = {
    id?: SortOrder
    devopsId?: SortOrder
    productName?: SortOrder
    description?: SortOrder
    requirements?: SortOrder
    productImage?: SortOrder
    productOriginalImage?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
    guideUrl?: SortOrder
  }

  export type ProductSumOrderByAggregateInput = {
    devopsId?: SortOrder
  }

  export type StringNullableWithAggregatesFilter = {
    equals?: string | null
    in?: string[] | string | null
    notIn?: string[] | string | null
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringNullableWithAggregatesFilter | string | null
    _count?: NestedIntNullableFilter
    _min?: NestedStringNullableFilter
    _max?: NestedStringNullableFilter
  }

  export type ProductRelationFilter = {
    is?: ProductWhereInput | null
    isNot?: ProductWhereInput | null
  }

  export type ProductSettingDetailRelationFilter = {
    is?: ProductSettingDetailWhereInput | null
    isNot?: ProductSettingDetailWhereInput | null
  }

  export type ProductSettingCountOrderByAggregateInput = {
    id?: SortOrder
    devopsId?: SortOrder
    config?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ProductSettingAvgOrderByAggregateInput = {
    devopsId?: SortOrder
  }

  export type ProductSettingMaxOrderByAggregateInput = {
    id?: SortOrder
    devopsId?: SortOrder
    config?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ProductSettingMinOrderByAggregateInput = {
    id?: SortOrder
    devopsId?: SortOrder
    config?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ProductSettingSumOrderByAggregateInput = {
    devopsId?: SortOrder
  }

  export type ProductSettingDetailCountOrderByAggregateInput = {
    id?: SortOrder
    config?: SortOrder
    devopsId?: SortOrder
    productSettingId?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ProductSettingDetailAvgOrderByAggregateInput = {
    devopsId?: SortOrder
  }

  export type ProductSettingDetailMaxOrderByAggregateInput = {
    id?: SortOrder
    config?: SortOrder
    devopsId?: SortOrder
    productSettingId?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ProductSettingDetailMinOrderByAggregateInput = {
    id?: SortOrder
    config?: SortOrder
    devopsId?: SortOrder
    productSettingId?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type ProductSettingDetailSumOrderByAggregateInput = {
    devopsId?: SortOrder
  }

  export type UpdaterVersionCountOrderByAggregateInput = {
    id?: SortOrder
    version?: SortOrder
    approvedVersion?: SortOrder
    downloads?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type UpdaterVersionAvgOrderByAggregateInput = {
    downloads?: SortOrder
  }

  export type UpdaterVersionMaxOrderByAggregateInput = {
    id?: SortOrder
    version?: SortOrder
    approvedVersion?: SortOrder
    downloads?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type UpdaterVersionMinOrderByAggregateInput = {
    id?: SortOrder
    version?: SortOrder
    approvedVersion?: SortOrder
    downloads?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type UpdaterVersionSumOrderByAggregateInput = {
    downloads?: SortOrder
  }

  export type CustomerCountOrderByAggregateInput = {
    id?: SortOrder
    name?: SortOrder
    assistantUrl?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type CustomerMaxOrderByAggregateInput = {
    id?: SortOrder
    name?: SortOrder
    assistantUrl?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type CustomerMinOrderByAggregateInput = {
    id?: SortOrder
    name?: SortOrder
    assistantUrl?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type AssistantMonitoringCountOrderByAggregateInput = {
    id?: SortOrder
    monitoringId?: SortOrder
    name?: SortOrder
    content?: SortOrder
    description?: SortOrder
    interval?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type AssistantMonitoringAvgOrderByAggregateInput = {
    interval?: SortOrder
  }

  export type AssistantMonitoringMaxOrderByAggregateInput = {
    id?: SortOrder
    monitoringId?: SortOrder
    name?: SortOrder
    content?: SortOrder
    description?: SortOrder
    interval?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type AssistantMonitoringMinOrderByAggregateInput = {
    id?: SortOrder
    monitoringId?: SortOrder
    name?: SortOrder
    content?: SortOrder
    description?: SortOrder
    interval?: SortOrder
    isActive?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type AssistantMonitoringSumOrderByAggregateInput = {
    interval?: SortOrder
  }

  export type NotificationCountOrderByAggregateInput = {
    id?: SortOrder
    title?: SortOrder
    description?: SortOrder
    status?: SortOrder
    userId?: SortOrder
    isAlreadyRead?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type NotificationMaxOrderByAggregateInput = {
    id?: SortOrder
    title?: SortOrder
    description?: SortOrder
    status?: SortOrder
    userId?: SortOrder
    isAlreadyRead?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type NotificationMinOrderByAggregateInput = {
    id?: SortOrder
    title?: SortOrder
    description?: SortOrder
    status?: SortOrder
    userId?: SortOrder
    isAlreadyRead?: SortOrder
    createdAt?: SortOrder
    updatedAt?: SortOrder
  }

  export type StringFieldUpdateOperationsInput = {
    set?: string
  }

  export type IntFieldUpdateOperationsInput = {
    set?: number
    increment?: number
    decrement?: number
    multiply?: number
    divide?: number
  }

  export type DateTimeFieldUpdateOperationsInput = {
    set?: Date | string
  }

  export type ProductSettingCreateNestedOneWithoutProductInput = {
    create?: XOR<ProductSettingCreateWithoutProductInput, ProductSettingUncheckedCreateWithoutProductInput>
    connectOrCreate?: ProductSettingCreateOrConnectWithoutProductInput
    connect?: ProductSettingWhereUniqueInput
  }

  export type ProductCreateNestedManyWithoutRequiredByProductsInput = {
    create?: XOR<ProductCreateWithoutRequiredByProductsInput, ProductUncheckedCreateWithoutRequiredByProductsInput> | ProductCreateWithoutRequiredByProductsInput[] | ProductUncheckedCreateWithoutRequiredByProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredByProductsInput | ProductCreateOrConnectWithoutRequiredByProductsInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
  }

  export type ProductCreateNestedManyWithoutRequiredProductsInput = {
    create?: XOR<ProductCreateWithoutRequiredProductsInput, ProductUncheckedCreateWithoutRequiredProductsInput> | ProductCreateWithoutRequiredProductsInput[] | ProductUncheckedCreateWithoutRequiredProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredProductsInput | ProductCreateOrConnectWithoutRequiredProductsInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
  }

  export type ProductSettingUncheckedCreateNestedOneWithoutProductInput = {
    create?: XOR<ProductSettingCreateWithoutProductInput, ProductSettingUncheckedCreateWithoutProductInput>
    connectOrCreate?: ProductSettingCreateOrConnectWithoutProductInput
    connect?: ProductSettingWhereUniqueInput
  }

  export type ProductUncheckedCreateNestedManyWithoutRequiredByProductsInput = {
    create?: XOR<ProductCreateWithoutRequiredByProductsInput, ProductUncheckedCreateWithoutRequiredByProductsInput> | ProductCreateWithoutRequiredByProductsInput[] | ProductUncheckedCreateWithoutRequiredByProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredByProductsInput | ProductCreateOrConnectWithoutRequiredByProductsInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
  }

  export type ProductUncheckedCreateNestedManyWithoutRequiredProductsInput = {
    create?: XOR<ProductCreateWithoutRequiredProductsInput, ProductUncheckedCreateWithoutRequiredProductsInput> | ProductCreateWithoutRequiredProductsInput[] | ProductUncheckedCreateWithoutRequiredProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredProductsInput | ProductCreateOrConnectWithoutRequiredProductsInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
  }

  export type NullableStringFieldUpdateOperationsInput = {
    set?: string | null
  }

  export type ProductSettingUpdateOneWithoutProductNestedInput = {
    create?: XOR<ProductSettingCreateWithoutProductInput, ProductSettingUncheckedCreateWithoutProductInput>
    connectOrCreate?: ProductSettingCreateOrConnectWithoutProductInput
    upsert?: ProductSettingUpsertWithoutProductInput
    disconnect?: boolean
    delete?: boolean
    connect?: ProductSettingWhereUniqueInput
    update?: XOR<ProductSettingUpdateWithoutProductInput, ProductSettingUncheckedUpdateWithoutProductInput>
  }

  export type ProductUpdateManyWithoutRequiredByProductsNestedInput = {
    create?: XOR<ProductCreateWithoutRequiredByProductsInput, ProductUncheckedCreateWithoutRequiredByProductsInput> | ProductCreateWithoutRequiredByProductsInput[] | ProductUncheckedCreateWithoutRequiredByProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredByProductsInput | ProductCreateOrConnectWithoutRequiredByProductsInput[]
    upsert?: ProductUpsertWithWhereUniqueWithoutRequiredByProductsInput | ProductUpsertWithWhereUniqueWithoutRequiredByProductsInput[]
    set?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    disconnect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    delete?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    update?: ProductUpdateWithWhereUniqueWithoutRequiredByProductsInput | ProductUpdateWithWhereUniqueWithoutRequiredByProductsInput[]
    updateMany?: ProductUpdateManyWithWhereWithoutRequiredByProductsInput | ProductUpdateManyWithWhereWithoutRequiredByProductsInput[]
    deleteMany?: ProductScalarWhereInput | ProductScalarWhereInput[]
  }

  export type ProductUpdateManyWithoutRequiredProductsNestedInput = {
    create?: XOR<ProductCreateWithoutRequiredProductsInput, ProductUncheckedCreateWithoutRequiredProductsInput> | ProductCreateWithoutRequiredProductsInput[] | ProductUncheckedCreateWithoutRequiredProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredProductsInput | ProductCreateOrConnectWithoutRequiredProductsInput[]
    upsert?: ProductUpsertWithWhereUniqueWithoutRequiredProductsInput | ProductUpsertWithWhereUniqueWithoutRequiredProductsInput[]
    set?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    disconnect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    delete?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    update?: ProductUpdateWithWhereUniqueWithoutRequiredProductsInput | ProductUpdateWithWhereUniqueWithoutRequiredProductsInput[]
    updateMany?: ProductUpdateManyWithWhereWithoutRequiredProductsInput | ProductUpdateManyWithWhereWithoutRequiredProductsInput[]
    deleteMany?: ProductScalarWhereInput | ProductScalarWhereInput[]
  }

  export type ProductSettingUncheckedUpdateOneWithoutProductNestedInput = {
    create?: XOR<ProductSettingCreateWithoutProductInput, ProductSettingUncheckedCreateWithoutProductInput>
    connectOrCreate?: ProductSettingCreateOrConnectWithoutProductInput
    upsert?: ProductSettingUpsertWithoutProductInput
    disconnect?: boolean
    delete?: boolean
    connect?: ProductSettingWhereUniqueInput
    update?: XOR<ProductSettingUpdateWithoutProductInput, ProductSettingUncheckedUpdateWithoutProductInput>
  }

  export type ProductUncheckedUpdateManyWithoutRequiredByProductsNestedInput = {
    create?: XOR<ProductCreateWithoutRequiredByProductsInput, ProductUncheckedCreateWithoutRequiredByProductsInput> | ProductCreateWithoutRequiredByProductsInput[] | ProductUncheckedCreateWithoutRequiredByProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredByProductsInput | ProductCreateOrConnectWithoutRequiredByProductsInput[]
    upsert?: ProductUpsertWithWhereUniqueWithoutRequiredByProductsInput | ProductUpsertWithWhereUniqueWithoutRequiredByProductsInput[]
    set?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    disconnect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    delete?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    update?: ProductUpdateWithWhereUniqueWithoutRequiredByProductsInput | ProductUpdateWithWhereUniqueWithoutRequiredByProductsInput[]
    updateMany?: ProductUpdateManyWithWhereWithoutRequiredByProductsInput | ProductUpdateManyWithWhereWithoutRequiredByProductsInput[]
    deleteMany?: ProductScalarWhereInput | ProductScalarWhereInput[]
  }

  export type ProductUncheckedUpdateManyWithoutRequiredProductsNestedInput = {
    create?: XOR<ProductCreateWithoutRequiredProductsInput, ProductUncheckedCreateWithoutRequiredProductsInput> | ProductCreateWithoutRequiredProductsInput[] | ProductUncheckedCreateWithoutRequiredProductsInput[]
    connectOrCreate?: ProductCreateOrConnectWithoutRequiredProductsInput | ProductCreateOrConnectWithoutRequiredProductsInput[]
    upsert?: ProductUpsertWithWhereUniqueWithoutRequiredProductsInput | ProductUpsertWithWhereUniqueWithoutRequiredProductsInput[]
    set?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    disconnect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    delete?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    connect?: ProductWhereUniqueInput | ProductWhereUniqueInput[]
    update?: ProductUpdateWithWhereUniqueWithoutRequiredProductsInput | ProductUpdateWithWhereUniqueWithoutRequiredProductsInput[]
    updateMany?: ProductUpdateManyWithWhereWithoutRequiredProductsInput | ProductUpdateManyWithWhereWithoutRequiredProductsInput[]
    deleteMany?: ProductScalarWhereInput | ProductScalarWhereInput[]
  }

  export type ProductCreateNestedOneWithoutConfigInput = {
    create?: XOR<ProductCreateWithoutConfigInput, ProductUncheckedCreateWithoutConfigInput>
    connectOrCreate?: ProductCreateOrConnectWithoutConfigInput
    connect?: ProductWhereUniqueInput
  }

  export type ProductSettingDetailCreateNestedOneWithoutProductSettingInput = {
    create?: XOR<ProductSettingDetailCreateWithoutProductSettingInput, ProductSettingDetailUncheckedCreateWithoutProductSettingInput>
    connectOrCreate?: ProductSettingDetailCreateOrConnectWithoutProductSettingInput
    connect?: ProductSettingDetailWhereUniqueInput
  }

  export type ProductSettingDetailUncheckedCreateNestedOneWithoutProductSettingInput = {
    create?: XOR<ProductSettingDetailCreateWithoutProductSettingInput, ProductSettingDetailUncheckedCreateWithoutProductSettingInput>
    connectOrCreate?: ProductSettingDetailCreateOrConnectWithoutProductSettingInput
    connect?: ProductSettingDetailWhereUniqueInput
  }

  export type ProductUpdateOneRequiredWithoutConfigNestedInput = {
    create?: XOR<ProductCreateWithoutConfigInput, ProductUncheckedCreateWithoutConfigInput>
    connectOrCreate?: ProductCreateOrConnectWithoutConfigInput
    upsert?: ProductUpsertWithoutConfigInput
    connect?: ProductWhereUniqueInput
    update?: XOR<ProductUpdateWithoutConfigInput, ProductUncheckedUpdateWithoutConfigInput>
  }

  export type ProductSettingDetailUpdateOneWithoutProductSettingNestedInput = {
    create?: XOR<ProductSettingDetailCreateWithoutProductSettingInput, ProductSettingDetailUncheckedCreateWithoutProductSettingInput>
    connectOrCreate?: ProductSettingDetailCreateOrConnectWithoutProductSettingInput
    upsert?: ProductSettingDetailUpsertWithoutProductSettingInput
    disconnect?: boolean
    delete?: boolean
    connect?: ProductSettingDetailWhereUniqueInput
    update?: XOR<ProductSettingDetailUpdateWithoutProductSettingInput, ProductSettingDetailUncheckedUpdateWithoutProductSettingInput>
  }

  export type ProductSettingDetailUncheckedUpdateOneWithoutProductSettingNestedInput = {
    create?: XOR<ProductSettingDetailCreateWithoutProductSettingInput, ProductSettingDetailUncheckedCreateWithoutProductSettingInput>
    connectOrCreate?: ProductSettingDetailCreateOrConnectWithoutProductSettingInput
    upsert?: ProductSettingDetailUpsertWithoutProductSettingInput
    disconnect?: boolean
    delete?: boolean
    connect?: ProductSettingDetailWhereUniqueInput
    update?: XOR<ProductSettingDetailUpdateWithoutProductSettingInput, ProductSettingDetailUncheckedUpdateWithoutProductSettingInput>
  }

  export type ProductSettingCreateNestedOneWithoutDetailInput = {
    create?: XOR<ProductSettingCreateWithoutDetailInput, ProductSettingUncheckedCreateWithoutDetailInput>
    connectOrCreate?: ProductSettingCreateOrConnectWithoutDetailInput
    connect?: ProductSettingWhereUniqueInput
  }

  export type ProductSettingUpdateOneRequiredWithoutDetailNestedInput = {
    create?: XOR<ProductSettingCreateWithoutDetailInput, ProductSettingUncheckedCreateWithoutDetailInput>
    connectOrCreate?: ProductSettingCreateOrConnectWithoutDetailInput
    upsert?: ProductSettingUpsertWithoutDetailInput
    connect?: ProductSettingWhereUniqueInput
    update?: XOR<ProductSettingUpdateWithoutDetailInput, ProductSettingUncheckedUpdateWithoutDetailInput>
  }

  export type NestedStringFilter = {
    equals?: string
    in?: string[] | string
    notIn?: string[] | string
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringFilter | string
  }

  export type NestedIntFilter = {
    equals?: number
    in?: number[] | number
    notIn?: number[] | number
    lt?: number
    lte?: number
    gt?: number
    gte?: number
    not?: NestedIntFilter | number
  }

  export type NestedDateTimeFilter = {
    equals?: Date | string
    in?: Date[] | string[] | Date | string
    notIn?: Date[] | string[] | Date | string
    lt?: Date | string
    lte?: Date | string
    gt?: Date | string
    gte?: Date | string
    not?: NestedDateTimeFilter | Date | string
  }

  export type NestedStringWithAggregatesFilter = {
    equals?: string
    in?: string[] | string
    notIn?: string[] | string
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringWithAggregatesFilter | string
    _count?: NestedIntFilter
    _min?: NestedStringFilter
    _max?: NestedStringFilter
  }

  export type NestedIntWithAggregatesFilter = {
    equals?: number
    in?: number[] | number
    notIn?: number[] | number
    lt?: number
    lte?: number
    gt?: number
    gte?: number
    not?: NestedIntWithAggregatesFilter | number
    _count?: NestedIntFilter
    _avg?: NestedFloatFilter
    _sum?: NestedIntFilter
    _min?: NestedIntFilter
    _max?: NestedIntFilter
  }

  export type NestedFloatFilter = {
    equals?: number
    in?: number[] | number
    notIn?: number[] | number
    lt?: number
    lte?: number
    gt?: number
    gte?: number
    not?: NestedFloatFilter | number
  }

  export type NestedDateTimeWithAggregatesFilter = {
    equals?: Date | string
    in?: Date[] | string[] | Date | string
    notIn?: Date[] | string[] | Date | string
    lt?: Date | string
    lte?: Date | string
    gt?: Date | string
    gte?: Date | string
    not?: NestedDateTimeWithAggregatesFilter | Date | string
    _count?: NestedIntFilter
    _min?: NestedDateTimeFilter
    _max?: NestedDateTimeFilter
  }

  export type NestedStringNullableFilter = {
    equals?: string | null
    in?: string[] | string | null
    notIn?: string[] | string | null
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringNullableFilter | string | null
  }

  export type NestedStringNullableWithAggregatesFilter = {
    equals?: string | null
    in?: string[] | string | null
    notIn?: string[] | string | null
    lt?: string
    lte?: string
    gt?: string
    gte?: string
    contains?: string
    startsWith?: string
    endsWith?: string
    not?: NestedStringNullableWithAggregatesFilter | string | null
    _count?: NestedIntNullableFilter
    _min?: NestedStringNullableFilter
    _max?: NestedStringNullableFilter
  }

  export type NestedIntNullableFilter = {
    equals?: number | null
    in?: number[] | number | null
    notIn?: number[] | number | null
    lt?: number
    lte?: number
    gt?: number
    gte?: number
    not?: NestedIntNullableFilter | number | null
  }

  export type ProductSettingCreateWithoutProductInput = {
    id?: string
    config: string
    createdAt?: Date | string
    updatedAt?: Date | string
    detail?: ProductSettingDetailCreateNestedOneWithoutProductSettingInput
  }

  export type ProductSettingUncheckedCreateWithoutProductInput = {
    id?: string
    config: string
    createdAt?: Date | string
    updatedAt?: Date | string
    detail?: ProductSettingDetailUncheckedCreateNestedOneWithoutProductSettingInput
  }

  export type ProductSettingCreateOrConnectWithoutProductInput = {
    where: ProductSettingWhereUniqueInput
    create: XOR<ProductSettingCreateWithoutProductInput, ProductSettingUncheckedCreateWithoutProductInput>
  }

  export type ProductCreateWithoutRequiredByProductsInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    config?: ProductSettingCreateNestedOneWithoutProductInput
    requiredProducts?: ProductCreateNestedManyWithoutRequiredByProductsInput
  }

  export type ProductUncheckedCreateWithoutRequiredByProductsInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    config?: ProductSettingUncheckedCreateNestedOneWithoutProductInput
    requiredProducts?: ProductUncheckedCreateNestedManyWithoutRequiredByProductsInput
  }

  export type ProductCreateOrConnectWithoutRequiredByProductsInput = {
    where: ProductWhereUniqueInput
    create: XOR<ProductCreateWithoutRequiredByProductsInput, ProductUncheckedCreateWithoutRequiredByProductsInput>
  }

  export type ProductCreateWithoutRequiredProductsInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    config?: ProductSettingCreateNestedOneWithoutProductInput
    requiredByProducts?: ProductCreateNestedManyWithoutRequiredProductsInput
  }

  export type ProductUncheckedCreateWithoutRequiredProductsInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    config?: ProductSettingUncheckedCreateNestedOneWithoutProductInput
    requiredByProducts?: ProductUncheckedCreateNestedManyWithoutRequiredProductsInput
  }

  export type ProductCreateOrConnectWithoutRequiredProductsInput = {
    where: ProductWhereUniqueInput
    create: XOR<ProductCreateWithoutRequiredProductsInput, ProductUncheckedCreateWithoutRequiredProductsInput>
  }

  export type ProductSettingUpsertWithoutProductInput = {
    update: XOR<ProductSettingUpdateWithoutProductInput, ProductSettingUncheckedUpdateWithoutProductInput>
    create: XOR<ProductSettingCreateWithoutProductInput, ProductSettingUncheckedCreateWithoutProductInput>
  }

  export type ProductSettingUpdateWithoutProductInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    detail?: ProductSettingDetailUpdateOneWithoutProductSettingNestedInput
  }

  export type ProductSettingUncheckedUpdateWithoutProductInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    detail?: ProductSettingDetailUncheckedUpdateOneWithoutProductSettingNestedInput
  }

  export type ProductUpsertWithWhereUniqueWithoutRequiredByProductsInput = {
    where: ProductWhereUniqueInput
    update: XOR<ProductUpdateWithoutRequiredByProductsInput, ProductUncheckedUpdateWithoutRequiredByProductsInput>
    create: XOR<ProductCreateWithoutRequiredByProductsInput, ProductUncheckedCreateWithoutRequiredByProductsInput>
  }

  export type ProductUpdateWithWhereUniqueWithoutRequiredByProductsInput = {
    where: ProductWhereUniqueInput
    data: XOR<ProductUpdateWithoutRequiredByProductsInput, ProductUncheckedUpdateWithoutRequiredByProductsInput>
  }

  export type ProductUpdateManyWithWhereWithoutRequiredByProductsInput = {
    where: ProductScalarWhereInput
    data: XOR<ProductUpdateManyMutationInput, ProductUncheckedUpdateManyWithoutRequiredProductsInput>
  }

  export type ProductScalarWhereInput = {
    AND?: ProductScalarWhereInput | ProductScalarWhereInput[]
    OR?: ProductScalarWhereInput[]
    NOT?: ProductScalarWhereInput | ProductScalarWhereInput[]
    id?: StringFilter | string
    devopsId?: IntFilter | number
    productName?: StringFilter | string
    description?: StringNullableFilter | string | null
    requirements?: StringNullableFilter | string | null
    productImage?: StringNullableFilter | string | null
    productOriginalImage?: StringNullableFilter | string | null
    isActive?: StringFilter | string
    createdAt?: DateTimeFilter | Date | string
    updatedAt?: DateTimeFilter | Date | string
    guideUrl?: StringNullableFilter | string | null
  }

  export type ProductUpsertWithWhereUniqueWithoutRequiredProductsInput = {
    where: ProductWhereUniqueInput
    update: XOR<ProductUpdateWithoutRequiredProductsInput, ProductUncheckedUpdateWithoutRequiredProductsInput>
    create: XOR<ProductCreateWithoutRequiredProductsInput, ProductUncheckedCreateWithoutRequiredProductsInput>
  }

  export type ProductUpdateWithWhereUniqueWithoutRequiredProductsInput = {
    where: ProductWhereUniqueInput
    data: XOR<ProductUpdateWithoutRequiredProductsInput, ProductUncheckedUpdateWithoutRequiredProductsInput>
  }

  export type ProductUpdateManyWithWhereWithoutRequiredProductsInput = {
    where: ProductScalarWhereInput
    data: XOR<ProductUpdateManyMutationInput, ProductUncheckedUpdateManyWithoutRequiredByProductsInput>
  }

  export type ProductCreateWithoutConfigInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    requiredProducts?: ProductCreateNestedManyWithoutRequiredByProductsInput
    requiredByProducts?: ProductCreateNestedManyWithoutRequiredProductsInput
  }

  export type ProductUncheckedCreateWithoutConfigInput = {
    id?: string
    devopsId: number
    productName: string
    description?: string | null
    requirements?: string | null
    productImage?: string | null
    productOriginalImage?: string | null
    isActive?: string
    createdAt?: Date | string
    updatedAt?: Date | string
    guideUrl?: string | null
    requiredProducts?: ProductUncheckedCreateNestedManyWithoutRequiredByProductsInput
    requiredByProducts?: ProductUncheckedCreateNestedManyWithoutRequiredProductsInput
  }

  export type ProductCreateOrConnectWithoutConfigInput = {
    where: ProductWhereUniqueInput
    create: XOR<ProductCreateWithoutConfigInput, ProductUncheckedCreateWithoutConfigInput>
  }

  export type ProductSettingDetailCreateWithoutProductSettingInput = {
    id?: string
    config: string
    devopsId: number
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type ProductSettingDetailUncheckedCreateWithoutProductSettingInput = {
    id?: string
    config: string
    devopsId: number
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type ProductSettingDetailCreateOrConnectWithoutProductSettingInput = {
    where: ProductSettingDetailWhereUniqueInput
    create: XOR<ProductSettingDetailCreateWithoutProductSettingInput, ProductSettingDetailUncheckedCreateWithoutProductSettingInput>
  }

  export type ProductUpsertWithoutConfigInput = {
    update: XOR<ProductUpdateWithoutConfigInput, ProductUncheckedUpdateWithoutConfigInput>
    create: XOR<ProductCreateWithoutConfigInput, ProductUncheckedCreateWithoutConfigInput>
  }

  export type ProductUpdateWithoutConfigInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    requiredProducts?: ProductUpdateManyWithoutRequiredByProductsNestedInput
    requiredByProducts?: ProductUpdateManyWithoutRequiredProductsNestedInput
  }

  export type ProductUncheckedUpdateWithoutConfigInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    requiredProducts?: ProductUncheckedUpdateManyWithoutRequiredByProductsNestedInput
    requiredByProducts?: ProductUncheckedUpdateManyWithoutRequiredProductsNestedInput
  }

  export type ProductSettingDetailUpsertWithoutProductSettingInput = {
    update: XOR<ProductSettingDetailUpdateWithoutProductSettingInput, ProductSettingDetailUncheckedUpdateWithoutProductSettingInput>
    create: XOR<ProductSettingDetailCreateWithoutProductSettingInput, ProductSettingDetailUncheckedCreateWithoutProductSettingInput>
  }

  export type ProductSettingDetailUpdateWithoutProductSettingInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductSettingDetailUncheckedUpdateWithoutProductSettingInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductSettingCreateWithoutDetailInput = {
    id?: string
    config: string
    createdAt?: Date | string
    updatedAt?: Date | string
    product: ProductCreateNestedOneWithoutConfigInput
  }

  export type ProductSettingUncheckedCreateWithoutDetailInput = {
    id?: string
    devopsId: number
    config: string
    createdAt?: Date | string
    updatedAt?: Date | string
  }

  export type ProductSettingCreateOrConnectWithoutDetailInput = {
    where: ProductSettingWhereUniqueInput
    create: XOR<ProductSettingCreateWithoutDetailInput, ProductSettingUncheckedCreateWithoutDetailInput>
  }

  export type ProductSettingUpsertWithoutDetailInput = {
    update: XOR<ProductSettingUpdateWithoutDetailInput, ProductSettingUncheckedUpdateWithoutDetailInput>
    create: XOR<ProductSettingCreateWithoutDetailInput, ProductSettingUncheckedCreateWithoutDetailInput>
  }

  export type ProductSettingUpdateWithoutDetailInput = {
    id?: StringFieldUpdateOperationsInput | string
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    product?: ProductUpdateOneRequiredWithoutConfigNestedInput
  }

  export type ProductSettingUncheckedUpdateWithoutDetailInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    config?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
  }

  export type ProductUpdateWithoutRequiredByProductsInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    config?: ProductSettingUpdateOneWithoutProductNestedInput
    requiredProducts?: ProductUpdateManyWithoutRequiredByProductsNestedInput
  }

  export type ProductUncheckedUpdateWithoutRequiredByProductsInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    config?: ProductSettingUncheckedUpdateOneWithoutProductNestedInput
    requiredProducts?: ProductUncheckedUpdateManyWithoutRequiredByProductsNestedInput
  }

  export type ProductUncheckedUpdateManyWithoutRequiredProductsInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
  }

  export type ProductUpdateWithoutRequiredProductsInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    config?: ProductSettingUpdateOneWithoutProductNestedInput
    requiredByProducts?: ProductUpdateManyWithoutRequiredProductsNestedInput
  }

  export type ProductUncheckedUpdateWithoutRequiredProductsInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
    config?: ProductSettingUncheckedUpdateOneWithoutProductNestedInput
    requiredByProducts?: ProductUncheckedUpdateManyWithoutRequiredProductsNestedInput
  }

  export type ProductUncheckedUpdateManyWithoutRequiredByProductsInput = {
    id?: StringFieldUpdateOperationsInput | string
    devopsId?: IntFieldUpdateOperationsInput | number
    productName?: StringFieldUpdateOperationsInput | string
    description?: NullableStringFieldUpdateOperationsInput | string | null
    requirements?: NullableStringFieldUpdateOperationsInput | string | null
    productImage?: NullableStringFieldUpdateOperationsInput | string | null
    productOriginalImage?: NullableStringFieldUpdateOperationsInput | string | null
    isActive?: StringFieldUpdateOperationsInput | string
    createdAt?: DateTimeFieldUpdateOperationsInput | Date | string
    updatedAt?: DateTimeFieldUpdateOperationsInput | Date | string
    guideUrl?: NullableStringFieldUpdateOperationsInput | string | null
  }



  /**
   * Aliases for legacy arg types
   */
    /**
     * @deprecated Use ProductCountOutputTypeDefaultArgs instead
     */
    export type ProductCountOutputTypeArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = ProductCountOutputTypeDefaultArgs<ExtArgs>
    /**
     * @deprecated Use ServerDefaultArgs instead
     */
    export type ServerArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = ServerDefaultArgs<ExtArgs>
    /**
     * @deprecated Use ProductDefaultArgs instead
     */
    export type ProductArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = ProductDefaultArgs<ExtArgs>
    /**
     * @deprecated Use ProductSettingDefaultArgs instead
     */
    export type ProductSettingArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = ProductSettingDefaultArgs<ExtArgs>
    /**
     * @deprecated Use ProductSettingDetailDefaultArgs instead
     */
    export type ProductSettingDetailArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = ProductSettingDetailDefaultArgs<ExtArgs>
    /**
     * @deprecated Use UpdaterVersionDefaultArgs instead
     */
    export type UpdaterVersionArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = UpdaterVersionDefaultArgs<ExtArgs>
    /**
     * @deprecated Use CustomerDefaultArgs instead
     */
    export type CustomerArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = CustomerDefaultArgs<ExtArgs>
    /**
     * @deprecated Use AssistantMonitoringDefaultArgs instead
     */
    export type AssistantMonitoringArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = AssistantMonitoringDefaultArgs<ExtArgs>
    /**
     * @deprecated Use NotificationDefaultArgs instead
     */
    export type NotificationArgs<ExtArgs extends $Extensions.InternalArgs = $Extensions.DefaultArgs> = NotificationDefaultArgs<ExtArgs>

  /**
   * Batch Payload for updateMany & deleteMany & createMany
   */

  export type BatchPayload = {
    count: number
  }

  /**
   * DMMF
   */
  export const dmmf: runtime.BaseDMMF
}